Cartographer = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceDB-2.0", "AceModuleCore-2.0", "AceHook-2.1")
local Cartographer = Cartographer
Cartographer.revision = tonumber(string.sub("$Revision: 25761 $", 12, -3))
Cartographer.version = "r" .. Cartographer.revision
Cartographer.date = string.sub("$Date: 2007-01-22 06:07:23 -0500 (Mon, 22 Jan 2007) $", 8, 17)

local Dewdrop = AceLibrary("Dewdrop-2.0")

local L = AceLibrary("AceLocale-2.2"):new("Cartographer")
local Crayon = AceLibrary("Crayon-2.0")
local BZ = AceLibrary("Babble-Zone-2.2")
local Tablet = AceLibrary("Tablet-2.0")
local Tourist = AceLibrary("Tourist-2.0")

BINDING_HEADER_CARTOGRAPHER = "Cartographer"
BINDING_NAME_CARTOGRAPHER_OPENALTERNATEMAP = "Open alternate map"

L:RegisterTranslations("enUS", function() return {
	["Active"] = "Enabled", -- remove in a while (2006-12-08)
	["Enabled"] = true,
	["Suspend/resume this module."] = true,
	
	["Right-Click on map to zoom out"] = true,
	["Left-Click on map to zoom in"] = true,
	
	["Go to %s"] = true,
	
	["Open Cartographer menu"] = true,
	["Open location menu"] = true,
	
	["Distance:"] = true,
} end)

L:RegisterTranslations("deDE", function() return {
	["Enabled"] = "Aktiviert",
	["Suspend/resume this module."] = "Aktiviert/Deaktiviert dieses Modul",
	
	["Right-Click on map to zoom out"] = "Rechtsklick auf die Karte verkleinert die Ansicht",
	["Left-Click on map to zoom in"] = "Linksklick auf die Karte vergr\195\182\195\159ert die Ansicht",
	
	["Go to %s"] = "Gehe zu %s",
	
	["Open Cartographer menu"] = "Cartographer-Men\195\188 \195\182ffnen",
	["Open location menu"] = "Positionsmen\195\188 \195\182ffnen",
	
--	["Distance:"] = true,
} end)

L:RegisterTranslations("frFR", function() return {
	["Active"] = "Activé",
	["Enabled"] = "Activé",
	["Suspend/resume this module."] = "Active ou non ce module.",

	["Right-Click on map to zoom out"] = "Clic-droit sur la carte pour effectuer un zoom arrière",
	["Left-Click on map to zoom in"] = "Clic-gauche sur la carte pour effectuer un zoom avant",

	["Go to %s"] = "Allez à %s",

	["Open Cartographer menu"] = "Ouvrir le menu Cartographer",
	["Open location menu"] = "Ouvrir le menu de situation",
	
--	["Distance:"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Active"] = "활성화",
	["Enabled"] = "활성화",
	["Suspend/resume this module."] = "모듈을 켜거나 끔니다.",
	
	["Right-Click on map to zoom out"] = "오른쪽-클릭 : 축소",
	["Left-Click on map to zoom in"] = "왼쪽-클릭 : 확대",
	
	["Go to %s"] = "%s 바로가기",
	
	["Open Cartographer menu"] = "Cartographer 메뉴 열기",
	["Open location menu"] = "위치 메뉴 열기",

	["Distance:"] = "거리:",
} end)

L:RegisterTranslations("zhCN", function() return {
--	["Enabled"] = true,
--	["Suspend/resume this module."] = true,
	
--	["Right-Click on map to zoom out"] = true,
--	["Left-Click on map to zoom in"] = true,
	
--	["Go to %s"] = true,
	
--	["Open Cartographer menu"] = true,
--	["Open location menu"] = true,

--	["Distance:"] = true,
} end)

L:RegisterTranslations("zhTW", function() return {
	["Enabled"] = "開啟",
	["Suspend/resume this module."] = "暫停/回復此模組.",
	
	["Right-Click on map to zoom out"] = "右鍵點擊放大地圖",
	["Left-Click on map to zoom in"] = "左鍵點擊縮小地圖",
	
	["Go to %s"] = "到%s",
	
	["Open Cartographer menu"] = "開啟Cartographer選單",
	["Open location menu"] = "開啟位置選單",

--	["Distance:"] = true,
} end)

L:RegisterTranslations("esES", function() return {
	["Active"] = "Activo", -- remove in a while (2006-12-08)
	["Enabled"] = "Activado",
	["Suspend/resume this module."] = "Parar/Continuar este m\195\179dulo",
	
	["Right-Click on map to zoom out"] = "Clic-Derecho en el mapa para alejarte",
	["Left-Click on map to zoom in"] = "Clic-Izquierdo en el mapa para acercarte",

	["Go to %s"] = "Ir a %s",
	
	["Open Cartographer menu"] = "Abrir el men\195\186 de Cartographer",
	["Open location menu"] = "Abrir el men\195\186 de lugares",

--	["Distance:"] = true,
} end)

local PLAYER = PLAYER or "PLAYER"
local PARTY = PARTY or "PARTY"
local RAID = RAID or "RAID"
local RANK = RANK or "RANK"
local GUILD = GUILD or "GUILD"
local CLASS = CLASS or "CLASS"
local RACE = RACE or "RACE"
local LEVEL = LEVEL or "LEVEL"

local yardString = GetLocale() == "enUS" and "%.0f yd" or "%.0f m"

Cartographer:RegisterDB("CartographerDB")

Cartographer.options = {
	type = 'group',
	args = {
	},
}
Dewdrop:InjectAceOptionsTable(Cartographer, Cartographer.options)
Cartographer.options.args.standby = nil

function Cartographer:OnInitialize()
	self.gotoOptions = {
		type = 'group',
		args = {
			player = {
				name = string.format(L["Go to %s"], GetRealZoneText()),
				desc = string.format(L["Go to %s"], GetRealZoneText()),
				type = 'execute',
				func = function()
					SetMapToCurrentZone()
				end,
				order = 1
			}
		},
	}
	
	for i,continent in ipairs { GetMapContinents() } do
		local i = i
		local validate = { GetMapZones(i) }
		self.gotoOptions.args[string.gsub(continent, " ", "-")] = {
			name = continent,
			desc = continent,
			type = 'text',
			validate = validate,
			get = function() return self:GetCurrentInstance() or GetCurrentMapContinent() == i and validate[GetCurrentMapZone()] end,
			set = function(text)
				for j,v in ipairs(validate) do
					if v == text then
						SetMapZoom(i, j)
						break
					end
				end
			end,
		}
	end
end

local magnifyingGlassTexts = { L["Right-Click on map to zoom out"], L["Left-Click on map to zoom in"] }
local currentLeftSide, currentRightSide
local dummyFrame
function Cartographer:OnEnable()
	WorldMapContinentDropDown:Hide()
	WorldMapZoneDropDown:Hide()
	
	local CartographerOptionsButton = CreateFrame("Button", "CartographerOptionsButton", WorldMapFrame, "UIPanelButtonTemplate")
	CartographerOptionsButton:SetText("Cartographer")
	local width = CartographerOptionsButton:GetTextWidth() + 30
	if width < 110 then
		width = 110
	end
	CartographerOptionsButton:SetWidth(width)
	CartographerOptionsButton:SetHeight(22)
	WorldMapZoomOutButton:Hide()
	CartographerOptionsButton:SetScript("OnClick", function()
		Dewdrop:Register(this,
			'children', self.options,
			'dontHook', true,
			'point', "TOPRIGHT",
			'relativePoint', "BOTTOMRIGHT"
		)
		this:SetScript("OnClick", function()
			if Dewdrop:IsOpen(this) then
				Dewdrop:Close()
			else
				Dewdrop:Open(this)
			end
		end)
		this:GetScript("OnClick")()
	end)
	CartographerOptionsButton:SetScript("OnEnter", function(this)
		GameTooltip_SetDefaultAnchor(GameTooltip, this)
		GameTooltip:SetText(L["Open Cartographer menu"], HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b)
		GameTooltip:Show()
	end)
	CartographerOptionsButton:SetScript("OnLeave", function(this)
		GameTooltip:Hide()
	end)
	self:AddMapButton(CartographerOptionsButton, 1)
	
	local CartographerGoToButton = CreateFrame("Button", "CartographerGoToButton", WorldMapFrame, "UIPanelButtonTemplate")
	CartographerGoToButton:SetText(UNKNOWN)
	local width = CartographerGoToButton:GetTextWidth() + 30
	if width < 220 then
		width = 220
	end
	CartographerGoToButton:SetWidth(width)
	CartographerGoToButton:SetHeight(22)
	CartographerGoToButton:SetScript("OnClick", function()
		Dewdrop:Register(this,
			'children', self.gotoOptions,
			'dontHook', true,
			'point', "TOPRIGHT",
			'relativePoint', "BOTTOMRIGHT"
		)
		this:SetScript("OnClick", function()
			if Dewdrop:IsOpen(this) then
				Dewdrop:Close()
			else
				Dewdrop:Open(this)
			end
		end)
		this:GetScript("OnClick")()
	end)
	CartographerGoToButton:SetScript("OnEnter", function(this)
		GameTooltip_SetDefaultAnchor(GameTooltip, this)
		GameTooltip:SetText(L["Open location menu"], HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b)
		GameTooltip:Show()
	end)
	CartographerGoToButton:SetScript("OnLeave", function(this)
		GameTooltip:Hide()
	end)
	self:AddMapButton(CartographerGoToButton, 0)
	
	self:Hook(WorldMapFrame, "Hide", "WorldMapFrame_Hide", true)
	self:Hook(WorldMapFrame, "Show", "WorldMapFrame_Show", true)
	self:RegisterEvent("Cartographer_MapOpened")
	self:RegisterEvent("Cartographer_MapClosed")
	self:RegisterEvent("Cartographer_ChangeZone")
	self:RegisterEvent("WORLD_MAP_UPDATE")
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	self:RegisterEvent("MINIMAP_ZONE_CHANGED")
	self:RegisterEvent("AceEvent_FullyInitialized")
	self:Cartographer_ChangeZone(self:GetCurrentEnglishZoneName(), self:GetCurrentLocalizedZoneName())
	
	WorldMapMagnifyingGlassButton:SetText(table.concat(magnifyingGlassTexts, "\n"))
	
	if (not GetBindingAction("ALT-M") or GetBindingAction("ALT-M") == "") and not GetBindingKey("CARTOGRAPHER_OPENALTERNATEMAP") then
		SetBinding("ALT-M", "CARTOGRAPHER_OPENALTERNATEMAP")
	end
	
	for i = 1, 2 do
		local side = i == 1 and "LEFT" or "RIGHT"
		local s = "Cartographer_" .. side .. "Side"
		Tablet:Register(s,
			'data', {},
			'children', side == "LEFT" and function()
				if currentLeftSide then
					currentLeftSide:OnCartographerLeftTabletRequest()
				end
			end or function()
				if currentRightSide then
					currentRightSide:OnCartographerRightTabletRequest()
				end
			end,
			'clickable', true,
			'dontHook', true,
			'cantAttach', true,
			'frameLevel', 11,
			'movable', false,
			'hideWhenEmpty', true,
			'parent', WorldMapFrame,
			'showTitleWhenDetached', true,
			'showHintWhenDetached', true,
			'positionFunc', side == "LEFT" and function(this)
				this:SetPoint("TOPLEFT", WorldMapDetailFrame, "TOPLEFT")
				this:SetPoint("BOTTOMLEFT", WorldMapDetailFrame, "BOTTOMLEFT")
			end or function(this)
				this:SetPoint("TOPRIGHT", WorldMapDetailFrame, "TOPRIGHT")
				this:SetPoint("BOTTOMRIGHT", WorldMapDetailFrame, "BOTTOMRIGHT")
			end
		)
		if WorldMapFrame:IsShown() then
			Tablet:Open(s)
		end
	end
	
	local old = WorldMapParty1:GetScript("OnLeave")
	function WorldMapUnit_OnLeave()
		old(this)
	end
	local function func(this, ...)
		WorldMapUnit_OnLeave()
	end
	WorldMapPlayer:SetScript("OnLeave", func)
	function WorldMapPlayer:OnTabletRequest()
		local kind = ""
		if self.unit == "player" then
			kind = PLAYER .. ": "
		elseif self.unit:find("^party") then
			kind = PARTY .. ": "
		elseif self.unit:find("^raid") then
			kind = RAID .. ": "
		end
		local name, server = self.name
		if not name then 
			name, server = UnitName(self.unit)
		end
		if server then
			name = name .. '-' .. server
		end
		Tablet:SetTitle(kind .. name)
		if self.unit then
			local cat = Tablet:AddCategory('columns', 2)
			local class, filename = UnitClass(self.unit)
			local color = RAID_CLASS_COLORS[filename]
			cat:AddLine(
				'text', CLASS .. ":",
				'text2', class,
				'text2R', color.r,
				'text2G', color.g,
				'text2B', color.b
			)
			local level = UnitLevel(self.unit)
			local playerlevel = UnitLevel('player')
			local r, g, b = Crayon:GetThresholdColorTrivial(level, playerlevel + 6, playerlevel - 6)
			cat:AddLine(
				'text', LEVEL .. ":",
				'text2', level,
				'text2R', r,
				'text2G', g,
				'text2B', b
			)
			cat:AddLine(
				'text', RACE .. ":",
				'text2', (UnitRace(self.unit)),
				'text2R', UnitRace(self.unit) == UnitRace('player') and 0 or 1,
				'text2G', 1,
				'text2B', 0
			)
			local gname, grank, granknum = GetGuildInfo(self.unit)
			if gname then
				local mygname, mygrank, mygranknum = GetGuildInfo('player')
				local r, g, b = 1, 1, 0
				if mygname == gname then
					r, g, b = 0, 1, 0
				end
				cat:AddLine(
					'text', GUILD .. ":",
					'text2', "<" .. gname .. ">",
					'text2R', r,
					'text2G', g,
					'text2B', b
				)
				if mygname == gname then
					local grankdiff = mygranknum - granknum
					if grankdiff >= 2 then
						r, g, b = 0, 1, 0
					elseif grankdiff == 1 then
						r, g, b = 0.5, 1, 0
					elseif grankdiff == 0 then
						r, g, b = 1, 1, 0
					elseif grankdiff == -1 then
						r, g, b = 1, 0.5, 0
					else
						r, g, b = 1, 0, 0
					end
				end
				cat:AddLine(
					'text', RANK .. ":",
					'text2', grank,
					'text2R', r,
					'text2G', g,
					'text2B', b
				)
			end	
			local x, y = GetPlayerMapPosition(self.unit)
			local dist = Cartographer:GetDistanceToPoint(x, y, Cartographer:GetCurrentLocalizedZoneName())
			
			if dist and dist >= 1 then
				cat:AddLine(
					'text', L["Distance:"],
					'text2', yardString:format(dist)
				)
			end
		end
	end
	WorldMapParty1.OnTabletRequest = WorldMapPlayer.OnTabletRequest
	WorldMapRaid1.OnTabletRequest = WorldMapPlayer.OnTabletRequest
	local tmp = {}
	function WorldMapPlayer:OnLineRequest(cat)
		if self.unit == "player" then
			tmp[#tmp+1] = PLAYER .. ": "	
		elseif self.unit:find("^party") then
			tmp[#tmp+1] = PARTY .. ": "
		elseif self.unit:find("^raid") then
			tmp[#tmp+1] = RAID .. ": "
		end
		if self.name then
			tmp[#tmp+1] = self.name
		else
			local name, server = UnitName(self.unit)
			tmp[#tmp+1] = name
			if server then
				tmp[#tmp+1] = "-"
				tmp[#tmp+1] = server
			end
			tmp[#tmp+1] = " - |cff"
			local level = UnitLevel(self.unit)
			local playerlevel = UnitLevel('player')
			tmp[#tmp+1] = Crayon:GetThresholdHexColorTrivial(level, playerlevel + 6, playerlevel - 6)
			tmp[#tmp+1] = tostring(level)
			tmp[#tmp+1] = "|r |cff"
			local class, filename = UnitClass(self.unit)
			local color = RAID_CLASS_COLORS[filename]
			tmp[#tmp+1] = ("%02x%02x%02x"):format(color.r*255, color.g*255, color.b*255)
			tmp[#tmp+1] = class
			tmp[#tmp+1] = "|r"
			local gname = GetGuildInfo(self.unit)
			if gname then
				local mygname = GetGuildInfo('player')
				tmp[#tmp+1] = " - |cff"
				if gname == mygname then
					tmp[#tmp+1] = "00ff00"
				else
					tmp[#tmp+1] = "ffff00"
				end
				tmp[#tmp+1] = "<"
				tmp[#tmp+1] = gname
				tmp[#tmp+1] = ">|r"
			end
		end
		local text = table.concat(tmp, "")
		for i = 1, #tmp do
			tmp[i] = nil
		end
		return 'text', text
	end
	WorldMapPlayer:SetFrameLevel(WorldMapPlayer:GetFrameLevel()+3)
	WorldMapParty1.OnLineRequest = WorldMapPlayer.OnLineRequest
	WorldMapRaid1.OnLineRequest = WorldMapPlayer.OnLineRequest
	for i = 1, 4 do
		local poi = _G["WorldMapParty" .. i]
		poi:SetScript("OnLeave", func)
		poi.OnTabletRequest = WorldMapParty1.OnTabletRequest
		poi.OnLineRequest = WorldMapParty1.OnLineRequest
		poi:SetFrameLevel(poi:GetFrameLevel()+3)
	end
	for i = 1, 40 do
		local poi = _G["WorldMapRaid" .. i]
		poi:SetScript("OnLeave", func)
		poi.OnTabletRequest = WorldMapRaid1.OnTabletRequest
		poi.OnLineRequest = WorldMapRaid1.OnLineRequest
		poi:SetFrameLevel(poi:GetFrameLevel()+3)
	end
	
	dummyFrame = CreateFrame("Frame")
	self.pois = {}
	local tmp = {}
	self.tooltipData = {}
	Tablet:Register(dummyFrame,
		'children', function()
			-- Check player
			if MouseIsOver(WorldMapPlayer) then
				tmp[#tmp+1] = WorldMapPlayer
			end
			
			-- Check party
			for i=1, MAX_PARTY_MEMBERS do
				local unitButton = _G["WorldMapParty"..i]
				if unitButton:IsVisible() and MouseIsOver(unitButton) then
					tmp[#tmp+1] = unitButton
				end
			end
			
			--Check Raid
			for i=1, MAX_RAID_MEMBERS do
				local unitButton = _G["WorldMapRaid"..i]
				if unitButton:IsVisible() and MouseIsOver(unitButton) then
					tmp[#tmp+1] = unitButton
				end
			end
			
			for frame in pairs(self.pois) do
				if frame:IsVisible() and MouseIsOver(frame) then
					tmp[#tmp+1] = frame
				end
			end
			
			if #tmp == 1 then
				tmp[1]:OnTabletRequest()
				tmp[1] = nil
			elseif #tmp > 1 then
				local cat = Tablet:AddCategory()
				for i = 1, #tmp do
					cat:AddLine(tmp[i]:OnLineRequest())
					tmp[i] = nil
				end
			end
		end,
		'point', function(parent)
			local x, y = GetCursorPosition()
			local cx, cy = GetScreenWidth()/2, GetScreenHeight()/2
			if x > cx then
				if y < cy then
					return "BOTTOMRIGHT"
				else
					return "TOPRIGHT"
				end
			else
				if y < cy then
					return "BOTTOMLEFT"
				else
					return "TOPLEFT"
				end
			end
		end,
		'relativePoint', function(parent)
			local x, y = GetCursorPosition()
			local cx, cy = GetScreenWidth()/2, GetScreenHeight()/2
			if x > cx then
				if y < cy then
					return "TOPLEFT"
				else
					return "BOTTOMLEFT"
				end
			else
				if y < cy then
					return "TOPRIGHT"
				else
					return "BOTTOMRIGHT"
				end
			end
		end,
		'dontHook', true,
		'data', self.tooltipData
	)
	self:Hook("WorldMapUnit_OnEnter", true)
	self:Hook("WorldMapUnit_OnLeave")
	self:ScheduleRepeatingEvent(self.UpdateTooltip, 1, self)
	
	self:configureYards()
end

local isOpen = false
function Cartographer:WorldMapUnit_OnEnter()
	if not Dewdrop:IsOpen(this) then
		isOpen = true
		Tablet:Open(this, dummyFrame)
	end
end

function Cartographer:WorldMapUnit_OnLeave()
	isOpen = false
	Tablet:Close()
end

function Cartographer:UpdateTooltip()
	self:GetCurrentPlayerPosition()
	if isOpen then
		Tablet:Refresh(dummyFrame)
	end
end

function Cartographer:AddPOI(frame)
	self.pois[frame] = true
end

function Cartographer:WorldMapFrame_Hide(this)
	local shown = WorldMapFrame:IsShown()
	self.hooks[this].Hide(this)
	if shown then
		self:TriggerEvent("Cartographer_MapClosed")
	end
end

function Cartographer:WorldMapFrame_Show(this)
	local shown = WorldMapFrame:IsShown()
	self.hooks[this].Show(this)
	if not shown then
		self:TriggerEvent("Cartographer_MapOpened")
	end
end

function Cartographer:WORLD_MAP_UPDATE()
	self:GetCurrentPlayerPosition()
	self:TriggerEvent("Cartographer_ChangeZone", self:GetCurrentEnglishZoneName(), self:GetCurrentLocalizedZoneName())
end

local function func(self)
	if currentLeftSide then
		Tablet:Open("Cartographer_LEFTSide")
--		Tablet:Refresh("Cartographer_LEFTSide")
	end
	if currentRightSide then
		Tablet:Open("Cartographer_RIGHTSide")
	end
end

function Cartographer:Cartographer_MapOpened()
	self:ScheduleEvent(func, 0, self)
	Tablet:Refresh("Cartographer_LEFTSide")
	Tablet:Refresh("Cartographer_RIGHTSide")
end

function Cartographer:Cartographer_MapClosed()
	if Dewdrop:IsOpen(CartographerGoToButton) or Dewdrop:IsOpen(CartographerOptionsButton) then
		Dewdrop:Close()
	end
	SetMapToCurrentZone()
end

local continents = { GetMapContinents() }
continents[0] = BZ["Azeroth"]
continents[-1] = BZ["Cosmic map"]

function Cartographer:Cartographer_ChangeZone(zone, localZone)
	if localZone then
		CartographerGoToButton:SetText(localZone)
		Cartographer.gotoOptions.args.player.name = string.format(L["Go to %s"], GetRealZoneText())
		Cartographer.gotoOptions.args.player.desc = Cartographer.gotoOptions.args.player.name
	else
		CartographerGoToButton:SetText(continents[GetCurrentMapContinent()] or UNKNOWN)
	end
end

function Cartographer:OnProfileEnable(alpha, bravo)
	for _,module in self:IterateModules() do
		if self:IsModuleActive(module) and type(module.OnProfileEnable) == "function" then
			module:OnProfileEnable(alpha, bravo)
		end
	end
end

function Cartographer:AddToMagnifyingGlass(text)
	for _,v in ipairs(magnifyingGlassTexts) do
		if v == text then
			error(string.format("Cannot add %q to magnifying glass, it already exists", text), 2)
		end
	end
	table.insert(magnifyingGlassTexts, text)
	WorldMapMagnifyingGlassButton:SetText(table.concat(magnifyingGlassTexts, "\n"))
end

function Cartographer:RemoveFromMagnifyingGlass(text)
	local id
	for i,v in ipairs(magnifyingGlassTexts) do
		if v == text then
			id = i
			break
		end
	end
	if not id then
		error(string.format("Cannot remove %q from magnifying glass, it does not exist", text), 2)
	end
	table.remove(magnifyingGlassTexts, id)
	
	WorldMapMagnifyingGlassButton:SetText(table.concat(magnifyingGlassTexts, "\n"))
end

local mapButtons = {}

local function my_sort(alpha, bravo)
	if not alpha or not bravo then
		return false
	end
	return mapButtons[alpha] < mapButtons[bravo]
end

local tmp = {}
local function refreshMapButtons()
	for k in pairs(mapButtons) do
		table.insert(tmp, k)
	end
	
	table.sort(tmp, my_sort)
	
	local width = -10
	for _,frame in ipairs(tmp) do
		width = width + frame:GetWidth() + 10
	end
	
	local last = tmp[1]
	last:SetPoint("BOTTOM", WorldMapZoomOutButton, "BOTTOM", 0, 0)
	last:SetPoint("LEFT", WorldMapDetailFrame, "CENTER", -width/2, 0)
	for i = 2, #tmp do
		local this = tmp[i]
		this:SetPoint("LEFT", last, "RIGHT", 10, 0)
		last = this
	end
	
	for k in pairs(tmp) do
		tmp[k] = nil
	end
end

function Cartographer:AddMapButton(frame, order)
	if mapButtons[frame] then
		error(string.format("Cannot add %q to map buttons, it already exists", frame:GetName() or "anonymous frame"), 2)
	end
	mapButtons[frame] = order
	
	refreshMapButtons()
end

function Cartographer:RemoveMapButton(frame)
	if not mapButtons[frame] then
		error(string.format("Cannot remove %q from map buttons, it does not exist", frame:GetName() or "anonymous frame"), 2)
	end
	mapButtons[frame] = nil
	
	refreshMapButtons()
end

local currentInstance
function Cartographer:SetCurrentInstance(zone)
	if currentInstance ~= zone then
		currentInstance = zone
		self:TriggerEvent("Cartographer_SetCurrentInstance", zone)
		self:TriggerEvent("Cartographer_ChangeZone", self:GetCurrentEnglishZoneName(), self:GetCurrentLocalizedZoneName())
	end
end

function Cartographer:GetCurrentInstance()
	return currentInstance
end

local instanceWorldMapButton
function Cartographer:RegisterInstanceWorldMapButton(frame)
	instanceWorldMapButton = frame
	self:TriggerEvent("Cartographer_RegisterInstanceWorldMapButton", frame)
end

function Cartographer:GetInstanceWorldMapButton()
	return instanceWorldMapButton
end

local mapZones = setmetatable({}, {__index = function(self, key)
	self[key] = { GetMapZones(key) }
	return self[key]
end })

function Cartographer:GetCurrentLocalizedZoneName()
	if currentInstance then
		return BZ[currentInstance]
	end
	local z = mapZones[GetCurrentMapContinent()][GetCurrentMapZone()]
	if z then
		return z
	else
		local map = GetMapInfo()
		if map == "WarsongGulch" then
			return BZ["Warsong Gulch"]
		elseif map == "ArathiBasin" then
			return BZ["Arathi Basin"]
		elseif map == "AlteracValley" then
			return BZ["Alterac Valley"]
		elseif map == "NetherstormArena" then
			return BZ["Eye of the Storm"]
		elseif map == "Azeroth" then
			return BZ["Eastern Kingdoms"]
		elseif map == "Kalimdor" then
			return BZ["Kalimdor"]
		elseif map == "Expansion01" then
			return BZ["Outland"]
		end
		if GetCurrentMapZone() == 0 then
			if GetCurrentMapContinent() == 0 then
				return BZ["Azeroth"]
			elseif GetCurrentMapContinent() == -1 then
				return BZ["Cosmic map"]
			end
		end
		return nil
	end
end

function Cartographer:GetCurrentEnglishZoneName()
	if currentInstance then
		return currentInstance
	end
	local z = mapZones[GetCurrentMapContinent()][GetCurrentMapZone()]
	if z then
		return BZ:GetReverseTranslation(z)
	else
		local map = GetMapInfo()
		if map == "WarsongGulch" then
			return "Warsong Gulch"
		elseif map == "ArathiBasin" then
			return "Arathi Basin"
		elseif map == "AlteracValley" then
			return "Alterac Valley"
		elseif map == "NetherstormArena" then
			return "Eye of the Storm"
		elseif map == "Azeroth" then
			return "Eastern Kingdoms"
		elseif map == "Kalimdor" then
			return "Kalimdor"
		elseif map == "Expansion01" then
			return "Outland"
		end
		if GetCurrentMapZone() == 0 then
			if GetCurrentMapContinent() == 0 then
				return "Azeroth"
			elseif GetCurrentMapContinent() == -1 then
				return "Cosmic map"
			end
		end
		return nil
	end
end

function Cartographer:OpenAlternateMap()
	if self:GetProfile() == "Default" or self:GetProfile() == "Alternate" then
		self:SetProfile(self:GetProfile() == "Default" and "Alternate" or "Default")
	end
	
	if not WorldMapFrame:IsShown() then
		ToggleWorldMap()
	end
end

function Cartographer:AcquireSideTablet(side, id)
	if side ~= "LEFT" and side ~= "RIGHT" then
		error('Argument #2 to `AcquireSideTablet\' must either be "LEFT" or "RIGHT".', 2)
	end
	AceLibrary.argCheck(self, id, 3, "table")
	if side == "LEFT" then
		if type(id.OnCartographerLeftTabletRequest) ~= "function" then
			error("Argument #3 must include the method `OnCartographerLeftTabletRequest'.", 2)
		end
		currentLeftSide = id
	else -- RIGHT
		if type(id.OnCartographerRightTabletRequest) ~= "function" then
			error("Argument #3 must include the method `OnCartographerRightTabletRequest'.", 2)
		end
		currentRightSide = id
	end
	local s = "Cartographer_" .. side .. "Side"
	if WorldMapFrame:IsShown() then
		Tablet:Refresh(s)
	end
end

function Cartographer:ReleaseSideTablet(side, id)
	if side ~= "LEFT" and side ~= "RIGHT" then
		error('Argument #2 to `AcquireSideTablet\' must either be "LEFT" or "RIGHT".', 2)
	end
	AceLibrary.argCheck(self, id, 3, "table")
	if side == "LEFT" then
		if id == currentLeftSide then
			currentLeftSide = nil
		else
			return
		end
	else -- RIGHT
		if id == currentRightSide then
			currentRightSide = nil
		else
			return
		end
	end
	Tablet:Refresh("Cartographer_" .. side .. "Side")
end

function Cartographer:GetCurrentSideTabletHandler(side)
	if side ~= "LEFT" and side ~= "RIGHT" then
		error('Argument #2 to `AcquireSideTablet\' must either be "LEFT" or "RIGHT".', 2)
	end
	if side == "LEFT" then
		return currentLeftSide
	else -- RIGHT
		return currentRightSide
	end
end

function Cartographer:RefreshSideTablet(side, id)
	if not side then
		self:RefreshSideTablet("LEFT", id)
		self:RefreshSideTablet("RIGHT", id)
		return
	end
	if side ~= "LEFT" and side ~= "RIGHT" then
		error('Argument #2 to `AcquireSideTablet\' must either be "LEFT" or "RIGHT".', 2)
	end
	AceLibrary.argCheck(self, id, 3, "table", "nil")
	local s = "Cartographer_" .. side .. "Side"
	--if not Tablet:IsRegistered(s) then
	--	return
	--end
	if side == "LEFT" then
		if id and id ~= currentLeftSide then
			return
		end
	else -- RIGHT
		if id and id ~= currentRightSide then
			return
		end
	end
	Tablet:Open(s)
end

function Cartographer:ZONE_CHANGED_NEW_AREA()
	if not WorldMapFrame:IsShown() then
		SetMapToCurrentZone()
	end
end

local currentYardWidth, currentYardHeight = 1000, 1000 * 2/3

do
	local x, y
	function Cartographer:GetCurrentPlayerPosition()
		local px, py = GetPlayerMapPosition("player")
		if px == 0 or py == 0 or ((IsInInstance() or Cartographer:GetCurrentInstance()) and select(IsInInstance(), 2) ~= "pvp") then
			return x, y
		end
		px, py = Tourist:TransposeZoneCoordinate(px, py, Cartographer:GetCurrentLocalizedZoneName(), GetRealZoneText())
		if px and py then
			x, y = px, py
		end
		
		return x, y
	end
end

function Cartographer:PointToYards(x, y, zone, transposeZone)
	local w, h
	if not zone or zone == GetRealZoneText() then
		w, h = currentYardWidth, currentYardHeight
	else
		w, h = Tourist:GetZoneYardSize(zone)
		if not w then
			w, h = 1000, 1000 * 2/3
		end
	end
	if x then
		return x * w, y * h
	end
	if transposeZone and transposeZone ~= zone then
		
	end
	return nil, nil
end

function Cartographer:GetDistanceToPoint(x, y, zone, px, py, pzone)
	if not px then
		px, py = self:GetCurrentPlayerPosition()
		pzone = GetRealZoneText()
	end
	if px == 0 or py == 0 then
		return nil
	end
	if not zone then
		zone = GetRealZoneText()
	end
	if not pzone then
		pzone = zone
	end
	local dist = Tourist:GetYardDistance(zone, x, y, pzone, px, py)
	return dist
end

function Cartographer:configureYards()
	currentYardWidth, currentYardHeight = Tourist:GetZoneYardSize(GetRealZoneText())
	if not currentYardWidth then
		currentYardWidth, currentYardHeight = 1000, 1000 * 2/3
	end
end
Cartographer.MINIMAP_ZONE_CHANGED = Cartographer.configureYards
Cartographer.AceEvent_FullyInitialized = Cartographer.configureYards