﻿local Cartographer = Cartographer
local revision = tonumber(string.sub("$Revision: 25754 $", 12, -3))
if revision > Cartographer.revision then
	Cartographer.version = "r" .. revision
	Cartographer.revision = revision
	Cartographer.date = string.sub("$Date: 2007-01-22 04:30:40 -0500 (Mon, 22 Jan 2007) $", 8, 17)
end

local L = AceLibrary("AceLocale-2.2"):new("Cartographer-GuildPositions")

L:RegisterTranslations("enUS", function() return {
	["Guild Positions"] = true,
	["Module which shows you your fellow guild members' positions, as well as allowing them to see you."] = true,
} end)

L:RegisterTranslations("deDE", function() return {
	["Guild Positions"] = "Gilden Positionen",
	["Module which shows you your fellow guild members' positions, as well as allowing them to see you."] = "Modul das dir die Position der Gildenmitglieder anzeigt, sowie auch ihnen erlaubt deine zu sehn.",
} end)

L:RegisterTranslations("frFR", function() return {
	["Guild Positions"] = "Positions guilde",
	["Module which shows you your fellow guild members' positions, as well as allowing them to see you."] = "Module affichant la position des membres de votre guilde, et leur permettant de voir la votre.",
} end)

L:RegisterTranslations("koKR", function() return {
	["Guild Positions"] = "길드원 위치",
	["Module which shows you your fellow guild members' positions, as well as allowing them to see you."] = "당신의 위치를 길드원에게 표시하거나 길드원의 위치를 표시하는 모듈을 제공합니다.",
} end)

L:RegisterTranslations("zhCN", function() return {
--	["Guild Positions"] = true,
--	["Module which shows you your fellow guild members' positions, as well as allowing them to see you."] = true,
} end)

L:RegisterTranslations("zhTW", function() return {
--	["Guild Positions"] = true,
--	["Module which shows you your fellow guild members' positions, as well as allowing them to see you."] = true,
} end)

L:RegisterTranslations("esES", function() return {
--	["Guild Positions"] = true,
--	["Module which shows you your fellow guild members' positions, as well as allowing them to see you."] = true,
} end)

Cartographer_GuildPositions = Cartographer:NewModule("GuildPositions", "AceEvent-2.0", "AceComm-2.0")
local Cartographer_GuildPositions = Cartographer_GuildPositions
local _G = getfenv(0)

local BC = AceLibrary("Babble-Class-2.2")
local BZ = AceLibrary("Babble-Zone-2.2")
local Roster = AceLibrary("Roster-2.1")
local AceEvent = AceLibrary("AceEvent-2.0")
local Tablet = AceLibrary("Tablet-2.0")

function Cartographer_GuildPositions:OnInitialize()
	self.name = L["Guild Positions"]
	self.title = L["Guild Positions"]
	Cartographer.options.args.GuildPositions = {
		name = L["Guild Positions"],
		desc = L["Module which shows you your fellow guild members' positions, as well as allowing them to see you."],
		type = 'group',
		args = {
			toggle = {
				name = AceLibrary("AceLocale-2.2"):new("Cartographer")["Enabled"],
				desc = AceLibrary("AceLocale-2.2"):new("Cartographer")["Suspend/resume this module."],
				type = "toggle",
				order = -1,
				get = function() return Cartographer:IsModuleActive(self) end,
				set = function() Cartographer:ToggleModuleActive(self) end
			},
		},
		handler = self,
	}
	
	self:SetCommPrefix("Cartographer_GuildPositions")
	local memoizations = {
		"CLEAR", "POSITION"
	}
	for zone in BZ:GetIterator() do
		table.insert(memoizations, zone)
	end
	self:RegisterMemoizations(memoizations)
	
	local poiCache = {}
	
	local function OnEnter(this)
		WorldMapUnit_OnEnter()
	end
	local function OnLeave(this)
		WorldMapUnit_OnLeave()
	end
	local function OnLineRequest(this)
		return 'text', this.name
	end
	local function OnTabletRequest(this)
		Tablet:AddCategory():AddLine(this:OnLineRequest())
	end
	
	local num = 0
	self.zones = {}
	self.x = {}
	self.y = {}
	self.classes = {}
	self.pois = setmetatable({del = function(self, key)
		if key == "del" then
			return
		end
		local poi = rawget(self, key)
		if not poi then
			return
		end
		self[key] = nil
		poiCache[poi] = true
		poi:Hide()
	end}, {__index = function(self, key)
		if not key then
			return nil
		end
		local poi = next(poiCache)
		if poi then
			poiCache[poi] = nil
			self[key] = poi
			poi:Show()
			poi.name = key
			return poi
		end
		num = num + 1
		poi = CreateFrame("Frame", "CartographerGuildPositions" .. num, WorldMapButton)
		poi:SetWidth(16)
		poi:SetHeight(16)
		poi:SetPoint("CENTER")
		local tex = poi:CreateTexture(nil, "OVERLAY")
		poi.tex = tex
		tex:SetTexture("Interface\\AddOns\\Cartographer\\GroupColorsArtwork\\Guild")
		tex:SetAllPoints(poi)
		poi:SetFrameLevel(poi:GetFrameLevel() + 1)
		poi:SetScript("OnEnter", OnEnter)
		poi:SetScript("OnLeave", OnLeave)
		poi:EnableMouse(true)
		Cartographer:AddPOI(poi)
		poi.name = key
		poi.OnLineRequest = OnLineRequest
		poi.OnTabletRequest = OnTabletRequest
		self[key] = poi
		return poi
	end})
	
	self.playersOnline = 120 -- default
	AceEvent:RegisterEvent("AceEvent_FullyInitialized", function()
		if not self:IsBucketEventRegistered("GUILD_ROSTER_UPDATE") then
			self:RegisterBucketEvent("GUILD_ROSTER_UPDATE", 1)
		end
		GuildRoster()
	end)
	AceEvent:ScheduleEvent("Cartographer_GuildPositions_SendMessage", self.SendPositionToGuild, 5, self)
end

function Cartographer_GuildPositions:OnEnable()
	self:RegisterEvent("PLAYER_GUILD_UPDATE")
	if IsInGuild() then
		self:ScheduleRepeatingEvent("Cartographer_GuildPositions_GuildRoster", GuildRoster, 60)
		if not self:IsBucketEventRegistered("GUILD_ROSTER_UPDATE") then
			self:RegisterBucketEvent("GUILD_ROSTER_UPDATE", 1)
		end
		GuildRoster()
		
		self:RegisterEvent("Cartographer_MapClosed")
		self:RegisterEvent("Cartographer_ChangeZone")
	end
	
	self:RegisterComm(self.commPrefix, "GUILD")
end

local function clear(person)
	if Cartographer_GuildPositions.zones[person] then
		Cartographer_GuildPositions.zones[person] = nil
		Cartographer_GuildPositions.x[person] = nil
		Cartographer_GuildPositions.y[person] = nil
		Cartographer_GuildPositions.classes[person] = nil
		Cartographer_GuildPositions.pois:del(person)
	end
end

function Cartographer_GuildPositions:OnDisable()
	for k in pairs(self.pois) do
		if k ~= "del" then
			clear(k)
		end
	end
end

function Cartographer_GuildPositions:Cartographer_MapClosed()
	for k in pairs(self.pois) do
		self.pois:del(k)
	end
end

local function showGuy(name)
	if Roster:GetUnitIDFromName(name) then
		Cartographer_GuildPositions.pois:del(name)
		return
	end
	local x, y = Cartographer_GuildPositions.x[name], Cartographer_GuildPositions.y[name]
	local w, h = WorldMapButton:GetWidth(), WorldMapButton:GetHeight()
	local poi = Cartographer_GuildPositions.pois[name]
	poi:SetPoint("CENTER", WorldMapButton, "TOPLEFT", w*x, -h*y)
	local class = Cartographer_GuildPositions.classes[name]
	if class then
		poi.tex:SetVertexColor(BC:GetColor(class))
	else
		poi.tex:SetVertexColor(1, 1, 1)
	end
end

function Cartographer_GuildPositions:Cartographer_ChangeZone(zone)
	for k in pairs(self.pois) do
		self.pois:del(k)
	end
	for name, z in pairs(self.zones) do
		if z == zone then
			showGuy(name)
		end
	end
end

function Cartographer_GuildPositions:PLAYER_GUILD_UPDATE(arg1)
	if arg1 and arg1 ~= "player" then
		return
	end
	
	if IsInGuild() then
		if not self:IsBucketEventRegistered("GUILD_ROSTER_UPDATE") then
			self:ScheduleRepeatingEvent("Cartographer_GuildPositions_GuildRoster", GuildRoster, 60)
			self:RegisterBucketEvent("GUILD_ROSTER_UPDATE", 1)
		end
		GuildRoster()
		
		self:RegisterEvent("Cartographer_MapClosed")
		self:RegisterEvent("Cartographer_ChangeZone")
	else
		if self:IsBucketEventRegistered("GUILD_ROSTER_UPDATE") then
			self:CancelScheduledEvent("Cartographer_GuildPositions_GuildRoster")
			self:UnregisterBucketEvent("GUILD_ROSTER_UPDATE")
		end	
		
		if self:IsEventRegistered("Cartographer_MapClosed") then
			self:UnregisterEvent("Cartographer_MapClosed")
			self:UnregisterEvent("Cartographer_ChangeZone")
		end
		
		for k in pairs(self.zones) do
			if not tmp[k] then
				clear(k)
			end
		end
	end
end

local tmp = {}
function Cartographer_GuildPositions:GUILD_ROSTER_UPDATE()
	local playersOnline = 0
	if IsInGuild() then
		local numGuildMembers = GetNumGuildMembers(true)
		for i = 1, numGuildMembers do
			local name, _, _, _, class, _, _, _, online = GetGuildRosterInfo(i)
			if online then
				playersOnline = playersOnline + 1
				tmp[name] = true
				self.classes[name] = class
			else
				clear(name)
			end
		end
		for k in pairs(self.zones) do
			if not tmp[k] then
				clear(k)
			end
		end
		for k in pairs(tmp) do
			tmp[k] = nil
		end
	else
		for k in pairs(self.zones) do
			if not tmp[k] then
				clear(k)
			end
		end
	end
	self.playersOnline = playersOnline
	if not Cartographer:IsModuleActive(self) then
		self:UnregisterBucketEvent("GUILD_ROSTER_UPDATE")
	end
end

local lastClear = true
function Cartographer_GuildPositions:SendPositionToGuild()
	AceEvent:ScheduleEvent("Cartographer_GuildPositions_SendMessage", self.SendPositionToGuild, math.max(5, self.playersOnline / 10), self)
	
	if not IsInGuild() then
		return
	end
	
	if GetRealZoneText() ~= Cartographer:GetCurrentLocalizedZoneName() then
		return
	end
	
	if self.playersOnline == 1 then
		-- all by my lonesome
		return
	end
	
	local zone = Cartographer:GetCurrentEnglishZoneName()
	local px, py = GetPlayerMapPosition("player")
	if IsInInstance() or px == 0 or py == 0 or Cartographer:GetCurrentInstance() then
		if lastClear then
			return
		end
		self:SendCommMessage("GUILD", "CLEAR")
		lastClear = true
		return
	end
	lastClear = false
	
	self:SendCommMessage("GUILD", "POSITION", zone, px, py)
end

Cartographer_GuildPositions.OnCommReceive = {
	CLEAR = function(self, prefix, sender, distibution)
		clear(sender)
	end,
	POSITION = function(self, prefix, sender, distribution, zone, x, y)
		if type(zone) ~= "string" or type(x) ~= "number" or type(y) ~= "number" or x < 0 or x > 1 or y < 0 or y > 1 then
			clear(sender)
			return
		end
		self.zones[sender] = zone
		self.x[sender] = x
		self.y[sender] = y
		if zone == Cartographer:GetCurrentEnglishZoneName() then
			showGuy(sender)
		end
	end
}
