﻿local Cartographer = Cartographer
local revision = tonumber(string.sub("$Revision: 25792 $", 12, -3))
if revision > Cartographer.revision then
	Cartographer.version = "r" .. revision
	Cartographer.revision = revision
	Cartographer.date = string.sub("$Date: 2007-01-22 16:52:34 -0500 (Mon, 22 Jan 2007) $", 8, 17)
end

local L = AceLibrary("AceLocale-2.2"):new("Cartographer-InstanceMaps")

L:RegisterTranslations("enUS", function() return {
	["Instance Maps"] = true,
	["Module which provides maps of instances."] = true,
	
	["Instances"] = true,
} end)

L:RegisterTranslations("deDE", function() return {
	["Instance Maps"] = "Instanzkarten",
	["Module which provides maps of instances."] = "Modul, das Instanzkarten zur Verfügung stellt.",
  
	["Instances"] = "Instanzen",
} end)

L:RegisterTranslations("frFR", function() return {
	["Instance Maps"] = "Cartes d'instance",
	["Module which provides maps of instances."] = "Module fournissant des cartes pour les instances.",

	--["Instances"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Instance Maps"] = "인스턴스 던전",
	["Module which provides maps of instances."] = "인스턴스 던전을 보여줍니다.",
	
	["Instances"] = "인스턴스",
} end)

L:RegisterTranslations("zhTW", function() return {
	["Instance Maps"] = "副本地圖",
	["Module which provides maps of instances."] = "提供副本地圖的模組。",

--	["Instances"] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
--	["Instance Maps"] = true,
--	["Module which provides maps of instances."] = true,

--	["Instances"] = true,
} end)

L:RegisterTranslations("esES", function() return {
	["Instance Maps"] = "Mapas de Instancia",
	["Module which provides maps of instances."] = "M\195\179dulo que provee mapas de instancias",
	
	["Instances"] = "Instancias",
} end)

local MapData, Rotations

Cartographer_InstanceMaps = Cartographer:NewModule("InstanceMaps", "AceHook-2.1")
local Cartographer_InstanceMaps = Cartographer_InstanceMaps

local BZ = AceLibrary("Babble-Zone-2.2")
local Tourist = AceLibrary("Tourist-2.0")

local instanceToTexture = {
	["Blackrock Depths"] = "BlackrockDepths",
	["Blackwing Lair"] = "BlackwingLair",
	["Dire Maul (East)"] = "DireMaulEast", -- ?
	["Dire Maul (North)"] = "DireMaulNorth", -- ?
	["Dire Maul (West)"] = "DireMaulWest", -- ?
	["Hellfire Ramparts"] = "HCRamparts",
	["Scarlet Monastery"] = "ScarletMonastery",
	["Scholomance"] = "Scholomance",
	["Shadowfang Keep"] = "ShadowfangKeep",
	["Ruins of Ahn'Qiraj"] = "RuinsofAhnQiraj",
	["The Shattered Halls"] = "HCShatteredHalls",
	["The Steamvault"] = "TheSteamvault",
	["The Underbog"] = "TheUnderbog",
	["Zul'Farrak"] = "ZulFarrak",
	["Zul'Gurub"] = "ZulGurub",
}

function Cartographer_InstanceMaps:OnInitialize()
	self.name = L["Instance Maps"]
	self.title = L["Instance Maps"]
	Cartographer.options.args.InstanceMaps = {
		name = L["Instance Maps"],
		desc = L["Module which provides maps of instances."],
		type = 'group',
		args = {
			toggle = {
				name = AceLibrary("AceLocale-2.2"):new("Cartographer")["Enabled"],
				desc = AceLibrary("AceLocale-2.2"):new("Cartographer")["Suspend/resume this module."],
				type = "toggle",
				order = -1,
				get = function() return Cartographer:IsModuleActive(self) end,
				set = function() Cartographer:ToggleModuleActive(self) end
			},
		},
		handler = self,
	}
	
	local validate = {}
	for k,v in pairs(instanceToTexture) do
		validate[k] = BZ[k]
	end
	for k,v in pairs(MapData) do
		validate[k] = BZ[k]
	end
	
	Cartographer.gotoOptions.args.Instances = {
		name = L["Instances"],
		desc = L["Instances"],
		type = 'text',
		get = function()
			return Cartographer:GetCurrentInstance()
		end,
		set = "ShowInstance",
		validate = validate,
		handler = self,
		hidden = function() return not Cartographer:IsModuleActive(self) end
	}
end

local CartographerInstanceFrame
function Cartographer_InstanceMaps:OnEnable()
	self:SecureHook("SetMapZoom")
	self:Hook("SetMapToCurrentZone", true)
end

function Cartographer_InstanceMaps:OnDisable()
	self:HideInstanceFrame()
end

function Cartographer_InstanceMaps:SetMapToCurrentZone()
	local zoneText = GetRealZoneText()
	if zoneText == BZ["Blackrock Spire"] then
		zoneText = BZ["Upper Blackrock Spire"]
	end
	if IsInInstance() and BZ:HasReverseTranslation(zoneText) and (instanceToTexture[BZ:GetReverseTranslation(zoneText)] or MapData[BZ:GetReverseTranslation(zoneText)]) then
		self:ShowInstance(BZ:GetReverseTranslation(zoneText))
	else
		self:HideInstanceFrame()
		return self.hooks.SetMapToCurrentZone()
	end
end

function Cartographer_InstanceMaps:ShowInstanceFrame()
	if not CartographerInstanceFrame then
		CartographerInstanceFrame = CreateFrame("Button", "CartographerInstanceFrame", WorldMapFrame)
		CartographerInstanceFrame:SetPoint("CENTER", WorldMapButton, "CENTER")
		CartographerInstanceFrame:SetWidth(WorldMapButton:GetWidth())
		CartographerInstanceFrame:SetHeight(WorldMapButton:GetHeight())
		CartographerInstanceFrame:Hide()
		CartographerInstanceFrame:RegisterForClicks("LeftButtonUp", "RightButtonUp")
		CartographerInstanceFrame:SetScript("OnClick", function()
			if arg1 == "RightButton" then
				local zone = BZ[Cartographer:GetCurrentInstance()]
				if Tourist:IsInKalimdor(zone) then
					SetMapZoom(1)
				elseif Tourist:IsInEasternKingdoms(zone) then
					SetMapZoom(2)
				elseif Tourist:IsInOutland(zone) then
					SetMapZoom(3)
				else
					SetMapZoom(0)
				end
			end
		end)
		local bgf = CreateFrame("Frame", nil, WorldMapFrame)
		local bg = bgf:CreateTexture(nil, "BACKGROUND")
		CartographerInstanceFrame.backgroundframe = bgf
		bgf:Hide()
		CartographerInstanceFrame.background = bg
		bg:SetTexture(0,0,0)
		bg:SetPoint("CENTER", CartographerInstanceFrame, "CENTER")
		bg:SetWidth(CartographerInstanceFrame:GetWidth())
		bg:SetHeight(CartographerInstanceFrame:GetHeight())
		local texture = CartographerInstanceFrame:CreateTexture(nil, "ARTWORK")
		CartographerInstanceFrame.texture = texture
		texture:SetPoint("CENTER", CartographerInstanceFrame, "CENTER")
		Cartographer:RegisterInstanceWorldMapButton(CartographerInstanceFrame)
	end
	if CartographerInstanceFrame:IsShown() then
		return
	end
	CartographerInstanceFrame:Show()
	CartographerInstanceFrame.backgroundframe:Show()
	WorldMapDetailFrame:Hide()
	WorldMapButton:Hide()
	ShowWorldMapArrowFrame(nil)
end

function Cartographer_InstanceMaps:HideInstanceFrame()
	Cartographer:SetCurrentInstance(nil)
	if not CartographerInstanceFrame or not CartographerInstanceFrame:IsShown() then
		return
	end
	CartographerInstanceFrame:Hide()
	CartographerInstanceFrame.backgroundframe:Hide()
	WorldMapDetailFrame:Show()
	WorldMapButton:Show()
	ShowWorldMapArrowFrame(1)
end

local num_tiles = 0
function Cartographer_InstanceMaps:ShowInstance(realZone)
	if not instanceToTexture[realZone] and not MapData[realZone] then
		return
	end
	local id = this and this:GetID() or 0
	local zone = BZ[realZone]
	if Tourist:IsInKalimdor(zone) then
		SetMapZoom(1, 1)
	elseif Tourist:IsInEasternKingdoms(zone) then
		SetMapZoom(2, 1)
	elseif Tourist:IsInOutland(zone) then
		SetMapZoom(3, 1)
	else
		SetMapZoom(0)
	end
	Cartographer_InstanceMaps:ShowInstanceFrame()
	Cartographer:SetCurrentInstance(realZone)
	if MapData[realZone] then
		CartographerInstanceFrame.texture:Hide()
		self:ShowSpecialInstance(realZone)
		return
	end
	for i,tex in ipairs(CartographerInstanceFrame) do
		tex:SetTexture(nil)
		tex:Hide()
	end
	CartographerInstanceFrame.texture:Show()
	CartographerInstanceFrame.texture:SetWidth(0)
	CartographerInstanceFrame.texture:SetHeight(0)
	CartographerInstanceFrame.texture:SetTexture("Interface\\AddOns\\Cartographer\\Instances\\" .. instanceToTexture[realZone])
	local currWidth, currHeight = CartographerInstanceFrame.texture:GetWidth(), CartographerInstanceFrame.texture:GetHeight()
	if currWidth == 0 then
		currWidth, currHeight = 512, 512
	end
	local newHeight = CartographerInstanceFrame:GetHeight()/CartographerInstanceFrame:GetScale() * 0.95
	local newWidth = currWidth*newHeight/currHeight
	CartographerInstanceFrame.texture:SetWidth(newWidth)
	CartographerInstanceFrame.texture:SetHeight(newHeight)
end

local cos, sin, abs = cos, sin, math.abs
local function smallRotate(angle, x, y)
	local A = cos(angle)
	local B = sin(angle)
	return x * A - y * B, x * B + y * A
end

local function rotate(angle)
	local A = cos(angle)
	local B = sin(angle)
	local ULx, ULy = -0.5 * A - -0.5 * B, -0.5 * B + -0.5 * A
	local LLx, LLy = -0.5 * A - 0.5 * B, -0.5 * B + 0.5 * A
	local URx, URy = 0.5 * A - -0.5 * B, 0.5 * B + -0.5 * A
	local LRx, LRy = 0.5 * A - 0.5 * B, 0.5 * B + 0.5 * A
	return ULx+0.5, ULy+0.5, LLx+0.5, LLy+0.5, URx+0.5, URy+0.5, LRx+0.5, LRy+0.5
end

local initializeMapData
function Cartographer_InstanceMaps:ShowSpecialInstance(realZone)
	initializeMapData(realZone)
	local map = MapData[realZone]
	
	local angle = Rotations[realZone] or 0
	angle = angle - 90
	local ULx, ULy, LLx, LLy, URx, URy, LRx, LRy = rotate(angle)
	
	for i,v in ipairs(map) do
		local tex
		if i > num_tiles then
			num_tiles = num_tiles + 1
			tex = CartographerInstanceFrame:CreateTexture("CartographerInstanceFrameTexture" .. i, "ARTWORK")
			CartographerInstanceFrame[i] = tex
		else
			tex = CartographerInstanceFrame[i]
		end
		local file, x, y, w, h = unpack(v)
		tex:SetTexture("textures\\Minimap\\" .. file)
		local A, B = abs(cos(angle)), abs(sin(angle))
		w, h = w*A + h*B, w*B + h*A
		tex:SetWidth(w)
		tex:SetHeight(h)
		tex:SetPoint("CENTER", CartographerInstanceFrame, "CENTER", smallRotate(angle, x, y))
		tex:SetTexCoord(ULx, ULy, LLx, LLy, URx, URy, LRx, LRy)
		tex:Show()
	end
	for i = #map+1, num_tiles do
		local tex = CartographerInstanceFrame[i]
		tex:SetTexture(nil) -- get rid of memory
		tex:Hide()
	end
end

local initialized = {}
local initializeTex
function initializeMapData(zone)
	if initialized[zone] then
		return
	end
	initialized[zone] = true
	if num_tiles == 0 then
		num_tiles = 1
		CartographerInstanceFrame[1] = CartographerInstanceFrame:CreateTexture("CartographerInstanceFrameTexture1", "ARTWORK")
	end
	initializeTex = CartographerInstanceFrame[1]
	local tex = initializeTex
	local left, right, top, bottom = nil
	for i,v in ipairs(MapData[zone]) do
		tex:SetWidth(0)
		tex:SetHeight(0)
		tex:SetTexture("textures\\Minimap\\" .. v[1])
		local width = tex:GetWidth()
		local height = tex:GetHeight()
		v[4] = width
		v[5] = height
		tex:SetTexture(nil)
		local left_p = v[2]
		local bottom_p = v[3]
		local right_p = left_p + width
		local top_p = bottom_p + height
		v[2] = left_p + width/2
		v[3] = bottom_p + height/2
		if not left or left_p < left then
			left = left_p
		end
		if not bottom or bottom_p < bottom then
			bottom = bottom_p
		end
		if not right or right_p > right then
			right = right_p
		end
		if not top or top_p > top then
			top = top_p
		end
	end
	local map_width = right - left
	local map_height = top - bottom
	
	local x_p = left + map_width/2
	local y_p = bottom + map_height/2
	local scale_x = map_width / (980 * 2/3)
	local scale_y = map_height / 980
	local scale = math.max(scale_x, scale_y)
	
	for i,v in ipairs(MapData[zone]) do
		v[2] = v[2] - x_p
		v[3] = v[3] - y_p
		v[2] = v[2] / scale
		v[3] = v[3] / scale
		v[4] = v[4] / scale
		v[5] = v[5] / scale
	end
end

function Cartographer_InstanceMaps:SetMapZoom()
	self:HideInstanceFrame()
end

Rotations = {
	-- currently only 90*k degree rotations are supported since in-between cases causes texture bleeding.
	["Dire Maul"] = 180,
}

MapData = {
	["Ahn'Qiraj"] = {
		{"def8cbe14914a5ae0a8ade0c51b0dd27", -6.563436, -211.277954},
		{"1d9d09ec55e6c4023e4522ba4ceaa627", -6.563436, 44.722046},
		{"2ea8cd9f8e0cb08d8a1997909abf6f8f", 249.436564, -211.277954},
		{"45414af2e96c98764b7864c6293f15ae", 261.112762, 14.907022},
		{"8643ccea6354d72213d82746e21c7d3e", 333.104614, 583.342407},
		{"a50a5694cb3214ef3a678aa51a87785e", 333.104614, 839.342407},
		{"6d36126857f88bac9242ce60418623f0", 333.104614, 1095.342407},
		{"d554adf8601b51b2176be893bb39dba7", 589.104614, 583.342407},
		{"f8979a731a88ffbe95f1111d2eb21bba", 589.104614, 839.342407},
		{"36eb01e6d116979bc3a6f73ca4401753", 589.104614, 1095.342407},
		{"0cb71d7ec4552392888e54c82945a36d", 33.478271, 270.837769},
		{"ddf87f9191eda9613d71e7d15a3715f2", 33.478271, 526.837769},
		{"05b89113acecf7fcc1bee130805f6ace", 289.478271, 270.837769},
		{"d040cc2a45c17b9b383d86b4a04526f0", 289.478271, 526.837769},
		{"4888361ad428437e35d5684bf2fdcf5f", 545.478271, 270.837769},
		{"eab81e879220872b005b2586cb3c2689", 545.478271, 526.837769},
		{"270f9ddbe09713ddb88216107e76feba", 777.138367, 505.693329},
		{"da59821b463cacfb036192c2393bc253", 777.138367, 761.693329},
		{"24a4f77a90754cc0ee69bbef7cdf0390", 1033.138367, 505.693329},
		{"3c90cbac445b363cb62b6eda93e0bff4", 1033.138367, 761.693329},
		{"d733a518e2f2bb6eba52c68ed35181eb", 546.232422, 448.496613},
		{"a05adb457728524b04835929840702e6", 546.232422, 704.496613},
		{"db47f2b0c0bad6178198cb0273ddcacf", 802.232422, 448.496613},
		{"4d58934fb3e890a82e71ff198ac09a43", 1330.556152, 20.945675},
		{"62102373f9f975d60b619f8d896710d8", 1330.556152, 276.945675},
		{"8b33fa4f6401b51eb851a1e280883980", 1330.556152, 532.945675},
		{"b7ec22ffa75fa09c70c84fddc19cdcaf", 1330.556152, 788.945675},
		{"02aa57141f0bc01a6aee7fc149345130", 1586.556152, 20.945675},
		{"8e9ba7fb3fca0e1bc0989f90bbc397fd", 1586.556152, 276.945675},
		{"7a79acd878362ad9cb2679e63a923819", 1586.556152, 532.945675},
		{"7c799f1873931a4455623c5140eee848", 1099.014404, -113.040703},
		{"889f5c54faca7fc1a72cae99b9d3f3f4", 1355.014404, -113.040703},
		{"0da7197e2368b23bc95f905b3ebbe740", 842.565430, -273.924500},
		{"78b024f80ec838ccfb861da05dd80c0f", 842.565430, -17.924500},
		{"5a8bd750aac98919155d0ce8041840e0", 1098.565430, -273.924500},
		{"a4c998c81e44ae5cd66c4dee597c9f3c", 1098.565430, -17.924500},
		{"5c719b0e391b06b2058b44cfa123c78e", 652.060974, -105.742455},
		{"a84f02b3c2f180bfffcf3227491ea0fb", 1017.852966, 728.192505},
		{"e1b1070508ac202d3d0dee60a3df6569", 1017.852966, 984.192505},
		{"3b7c4f4e89c3a46f63a8586f33be37be", 1017.852966, 1240.192505},
		{"e0525f82d690ddb2db8ee6c96a4cecb3", 1273.852966, 728.192505},
		{"f303e9811d24622abe5a5c2ac809fd8b", 1273.852966, 984.192505},
		{"274fc50488a383d393aa6740787b9b21", 1273.852966, 1240.192505},
		{"0469862cb27b64fc9a66135cd782d5d0", 1529.852966, 984.192505},
		{"ab6ed25f6971c030ee9f744b5e58b445", 1529.852966, 1240.192505},
		{"5a9121bd6f6e0d5dbe5de8133ae3b1d7", -478.062042, 569.693054},
		{"c723e705852cda06e9ffec68d5b6e9c0", -478.062042, 825.693054},
		{"46dc943ccd2d713620dc4313474e2e59", -222.062042, 569.693054},
		{"3381878c00c948fb74f67cf179534a55", -222.062042, 825.693054},
		{"c8a8976cba13f2a4424d8836c52501ad", -516.438416, 1642.326660},
		{"2a1304505e2b871bd75aae59d0673943", -516.438416, 1898.326660},
		{"f7c35bb6a7230324848bb58913263a8a", -260.438416, 1642.326660},
		{"4ce50e82f2531972289b8a72ab3d76a9", -260.438416, 1898.326660},
		{"13cdcadb89534a05d4b895652f969416", -377.848969, 121.631065},
		{"6c4bbf1137dff64d9ea33ea2573335a0", -377.848969, 377.631065},
		{"72d0bf82caa3d19af3490ce3df5b7024", -864.000671, 1273.567261},
		{"ef38132bc0cbe1268f2ad795fbb0ca1e", -864.000671, 1529.567261},
		{"b6cf603a900ec739ce0b819eb6062f71", -864.000671, 1785.567261},
		{"95ea43b71c6b5193d0a04f67d203e39d", -608.000671, 1529.567261},
		{"b9ba21cd0571e625cf62e461509c8ee2", -608.000671, 1785.567261},
		{"9e6bbb3632668592713412ec5b912985", -811.081421, 844.123901},
		{"a78b0edb414a9401160d1dc5f2ddf393", -811.081421, 1100.123901},
		{"eff45df2ab0abbb88b10be51be9d9f14", -555.081421, 844.123901},
		{"441baac5bba9b3f3c415293234eddf52", -555.081421, 1100.123901},
		{"3751053994b9827f0f34384dc590f1e5", -183.644882, 1293.087646},
		{"d317bddb1e114272259a86fb700c8e3b", -183.644882, 1549.087646},
		{"3fbaa7dc5b62d43ed47936b24f72df92", -505.256622, 1948.516724},
		{"93e55220a7f881bc49699281ea9dc068", -505.256622, 2204.516724},
		{"bc7f8aa84815794dd8f16c25bd2d889c", -249.256622, 1948.516724},
		{"c805aad96c07c1ab3e102c91365a87b1", -247.586639, -93.357079},
		{"66a9b3e284b083f28d913beb8a44321f", -197.838593, -149.032013},
		{"1af228b77646b972e05fa511ef346c3e", -197.838593, 106.967987},
		{"d51b2ebc3551e86884aa19f9ed414265", -33.706699, 125.604576},
		{"67e95476a7dedaa5742329edeafa2fb2", 7.478103, -132.046921},
		{"43ea02f2fd5dba9f38f10c272ed04176", 62.567692, 66.264061},
		{"089837ee965c052e5e908946d9d794f9", 959.104431, -357.536896},
		{"c8407dcd9440159b2d4c9114edfe4e6e", -269.597229, 2004.805176},
		{"9149264dbff0682e54cf5d70de87a6a9", -422.297028, 2207.600342},
		{"74a6c24b2d1e1c73f7cf6107f495cc52", -422.297028, 2463.600342},
		{"b36ef1f0f313aad3e3c63737f6e1ce31", -166.297028, 2207.600342},
		{"5f4776ffa3fd9e1097f3a833ac9dc81e", -166.297028, 2463.600342},
		{"682624018e451fc13f8f376f1d55349e", 261.112762, -70.986183},
		{"bef64fa37000750e3f90d69aed036845", 7.612481, -205.549866},
		{"39437f9eac296007f48bfee7c41e4de4", 139.417175, -173.186508},
		{"a0a99c96abf7671641b36c416409546f", -73.765114, -135.567215},
		{"1c17888f5021433d9b378630f7722e20", -100.926910, -134.159851},
		{"92022affaa14a5c0add3b8936fa6ecc8", -100.926910, 121.840149},
		{"15b3236eb9f2f9dfb806c252831ee1e7", 15.828024, 1103.004517},
		{"f0bf157c642a659720469ea976ebc25c", 15.828024, 1359.004517},
		{"8cc8574fe310aaca1c87933fd05737e5", 271.828024, 1103.004517},
		{"b209791d442b60c301d1b5025cc8ab5a", 271.828024, 1359.004517},
		{"4840d54d933c911a79b402df0c46eebe", 159.528015, -237.014465},
		{"e25f1bff25b13b4f16bd26989413349b", 415.528015, -237.014465},
		{"ba8c744394c3bb8c0e9a9ac93282be29", 671.528015, -237.014465},
		{"b7b6ede87ccce5ded4b840bbd8b141e7", -183.698578, -406.681488},
		{"3f2e35a8123dca99a464f7d6a27dd511", -183.698578, -150.681488},
		{"3a98b7f42cc506169ed34320a2f1bed3", 72.301422, -406.681488},
		{"65eec9a4af89ee9bd83997acef6ae58b", 72.301422, -150.681488},
		{"14be5c667166787b72afb44583d3a751", 690.730652, -915.679260},
		{"92f80f2bdec1bff2f8a8e292420efdb1", 690.730652, -659.679260},
		{"8a262c74eed4be24eb0775abc6262c26", 690.730652, -403.679260},
		{"2c4a5078437432cbe86c04cc21357482", 946.730652, -915.679260},
		{"25f61185c5e672eed74047a2b401794c", 946.730652, -659.679260},
		{"ad56be44451b811e19e74bf112fb8851", 946.730652, -403.679260},
		{"55b2d10ce3982a6bd01904d53ba234f5", 1202.730652, -915.679260},
		{"3e723c929d30792505e542077379a0ba", 1202.730652, -659.679260},
		{"0cf9a53a86c82a55afad0d7591e04925", 1202.730652, -403.679260},
		{"c7f553ab0dae4739b22244788b7f5a93", 1458.730652, -915.679260},
		{"2b109bea1fde44fa378bb9cef898ba4f", 1458.730652, -659.679260},
		{"c1d5144858e80677b26dd84ee303191b", -432.271484, -104.683365},
		{"53eaaf0b549b9fd0a4e08f548efedcae", -432.271484, 151.316635},
		{"1e69d624685b9aa3ba19d3fe57ec0e53", -176.271484, -104.683365},
		{"5dcb494bc7a69ca3ba8020bb2f7c49ce", -348.482025, -100.667854},
		{"124dc57c465c2dad6df193b5ffe8e93b", -133.565857, -140.163284},
		{"a08d59e72856b8c58e84cd740c414d9f", -133.565857, 115.836716},
		{"3f29b9a65bd3a6102c3ac364b84538af", 122.434143, -140.163284},
		{"0f0e93c04c45ac35d5df979d7ea88659", 122.434143, 115.836716},
		{"a3ba26ee1e7b577b5b6470cfa7d2afa7", -190.386871, -129.472549},
	},
	["Blackfathom Deeps"] = {
		{"5956b196160a34cda9e2f6bb7a6c63df", 153.635635, -344.078674},
		{"9649f54b6b9d9e09f3ae1bff89ddea06", 269.008270, -256.863617},
		{"8f40426718d4593ea0181bd9fe08d23b", 365.638802, -109.817551},
		{"78f78df8378824f0e64b9f252e5dfdf0", 322.915558, -158.676758},
		{"1355774216da3a658c0eb23a4190977a", 806.659973, -706.924988},
		{"defda8a635a26fc00c04716427d8db30", 806.659973, -450.924988},
		{"361711a5f4854697ed6e482a5eb0fdbb", 806.659973, -194.924988},
		{"f82fe7ccbe7264c3bc5ed3fa1b4f8074", 1062.659973, -706.924988},
		{"f3c74c5af20f3050b52ca797a5ed1a1d", 1062.659973, -450.924988},
		{"1c08cda9753cf031eb101ad15130270b", 603.590698, -714.121887},
		{"70bd476daf9bf89fdd263581c3a37f83", 603.590698, -458.121887},
		{"32b59b6688febae29779e08a3b510722", 603.590698, -202.121887},
		{"c7db2111705c118ae2e977162f7508db", 859.590698, -714.121887},
		{"3142420b82e684b1dc1f969e7b601111", 859.590698, -458.121887},
		{"145012be7c6fd68e0b4b7d3a2e58e7e1", 859.590698, -202.121887},
		{"2d6bc321a7f4a8eb8a820ec23dfe7a9f", 560.706421, -299.979218},
		{"ebc5a727a5cd482d1a6aacc5ea774889", 359.297943, -175.263733},
		{"61b0d5f77fded5711b423e2d5a34f4f4", 615.297943, -175.263733},
		{"2863d12a872925460f5d6927b7c7eb3e", 615.297943, 80.736267},
		{"110bef3aa668db8db75863611ea02424", 572.883179, -848.048523},
		{"09337b5dad28ad1e095d6bf149cc4eac", 1174.124146, -516.374512},
		{"ddac70385cac8ed859d4ad192dbc6c16", 1213.740356, -295.249756},
		{"140d1b17944d58e41fccff660415b34b", 1144.706909, -129.106674},
		{"7582bcf6fb287a80b81a8ee722e480d5", 1055.830933, -51.953846},
		{"f0ee2bd8ff192f80c45c10f9dc2456ac", 783.428223, -224.002090},
		{"a6daef63649ae345d25a0c4c98ce6001", 783.428223, 31.997910},
		{"49f74496e6215d938d25569a88a52548", 1039.428223, -224.002090},
		{"46657de8ffe5523fd9f1ffa0fb1e963f", 1039.428223, 31.997910},
		{"56c831d088281e7ea5938056f77d181a", 869.810608, 38.214508},
		{"c6568b5d481db57f09e29e1044929fb4", 1054.411743, 43.699295},
		{"bd0797903ccb54ecf62bdea415e0b88e", 1183.728516, 2.454933},
		{"b0a0a547beb7e7652b3a7e16159542e6", 1292.364746, -105.981758},
		{"7d5f3569014bc7f575cfd966a67280a8", 1347.622803, -44.949120},
		{"8caddcbfe53268a8fbdea6e285163877", 1347.622803, 211.050880},
		{"1fb665b140ff8db78392ae6aa44a75a6", 1471.679077, 33.109715},
		{"6fad6b8b063e8640ae100abdd30d6aec", 1727.679077, 33.109715},
		{"ed739c9694bab6a9192d092bae520756", 1529.095825, 155.690063},
		{"94b5e8319484a8e906275bb75a7b1326", 1386.338867, 241.631042},
		{"1700cd072a0bc5cf6814885b7b781660", 1558.108154, 388.811646},
		{"85ceebf41c6cda4786ecb94f6e6fd7f2", 1558.108154, 644.811646},
		{"385687b575b0dcc3f344060d17df5e74", 1558.108154, 900.811646},
		{"e5b06191e385e3496bb35d432819d4cc", 273.490845, -417.350464},
		{"310ebc31ba5be21557857fabe4d7f60d", 571.676086, -735.518066},
	},
	["Blackwing Lair"] = {
		{"e97c1c831e3b4b043c440cad9024f01b", -675.209229, 1195.778198},
		{"6cd554a5ae587d0696bcdce14ceeebf9", -419.209229, 1195.778198},
		{"e6da9447c554b83829be872b2c7cf6e4", -387.342316, 719.268738},
		{"40f6e1f8acf5b7755aa9af7a246109d5", -217.066742, 918.053650},
		{"2248e899dfa070ffffa87101ed7b1034", -251.295135, 938.644775},
		{"8d63b4d8ed2f79d00a6ada93b3a75b35", -584.552856, 1131.139038},
		{"dd568020402c7fec19f4105d98a362bc", -154.640305, 938.558960},
		{"f13b6c3f23034cef237ca676e87418f4", -439.521088, 935.369507},
		{"ccc260bb017071e571bbf2c7db00b269", -668.795593, 835.832458},
		{"1e84aab969c569f09e5fe484ad1d08da", -688.646851, 939.984741},
		{"ab220cc712fe25738745fc2ce9987560", -861.794617, 906.467957},
		{"c36e657e0ff3800e8167acc49ce4b9a0", -738.450562, 648.433533},
		{"8e41c7434da173fd1f637e4b9312cdba", -666.787720, 691.566650},
		{"8867a93ebb77539f30c4379695c6abf2", -666.787720, 947.566650},
		{"c2079e03589c5a624c6d09a96da62798", -410.787720, 691.566650},
		{"4fd06c29cd6d664be5fc77a262031771", -410.787720, 947.566650},
		{"8e222290f0ed1faf1cea59b331d84a86", -665.161560, 869.729919},
		{"b986e49f7459a4659081a67f29f9fbff", -108.445801, 878.870117},
		{"2988e4674665bb091fc30ec470eb7341", -399.062897, 1131.139038},
		{"421bc9ffb5123c5082be5e7cf4bae325", -879.560608, 878.677673},
		{"d031be303b3c9cb543dc5093953072be", -904.665039, 802.551941},
		{"77fc205a177963df6f302bb310849285", -1040.549927, 767.587463},
		{"4588c52ba3049751fb24335c25b46dbb", -1040.549927, 1023.587463},
		{"bfa977c1c7fed7c45d053b04fdec9bda", -1086.917969, 1037.666748},
		{"918e9c494b20b9039c661ae9bcf65028", -830.917969, 1037.666748},
		{"bac96d2d12a973cae890223c0c5b9601", -822.659363, 962.095154},
		{"057479dbd614afc9473357c46f7518ed", -742.988281, 1196.297607},
		{"dcf94cbf86b75d17ea016cfe17a687e1", -668.808960, 1218.392578},
		{"897a0cd0ca89f0cee5302a000510848d", -874.589783, 694.812500},
	},
	["Blackrock Depths"] = {
		{"0218f5f564d96748e1655dc615fe6736", -859.542542, 78.113625},
		{"45f58e48034102543640e71b548bc755", -603.542542, 78.113625},
		{"b8578d04d32c37bfe1d03d750dae0ff3", -603.542542, 334.113625},
		{"c51fc00a25dd19a4633aadecb68ed508", -905.052856, 280.015350},
		{"c91edccbf7a535e566b76b8b1fab4dca", -649.052856, 280.015350},
		{"1a878d1777dda631e6e00951dea6745c", -1109.109009, 328.755493},
		{"d1d5d4df2d3e9f010044ce1e7287dfae", -1334.353760, 433.194122},
		{"70a79a96d7e338e2c45592be05dd1e93", -1078.353760, 433.194122},
		{"77d170b4efeec9e0ad6d96b9ae26e240", -1350.446655, 219.208313},
		{"e02bb7dc2bdd2f172a220758fa381a11", -894.077209, 182.559952},
		{"b74fbc80b287c17548da2fe90cb41959", -638.077209, 182.559952},
		{"a33724c6863781e4586410b32e09a7f3", -1277.937134, 66.179703},
		{"780016c3248555b3062452a67409bfd9", -1257.890015, 312.994629},
		{"95b9ac1c1e7dd53aff42e2bcf1b132b7", -1381.503418, 212.991196},
		{"73205a07eb1e318766be3df8b4e4b58f", -1381.503418, 468.991196},
		{"cdba8ed43794e58b26d6852d445ad133", -1125.503418, 212.991196},
		{"fee09f472e789aab36e2e955f49221e9", -1125.503418, 468.991196},
		{"05819f3965d98f66319207dd793395be", -1180.757568, 208.928528},
		{"a65d93baa375ed0c1a360ba7065a7902", -1282.989868, 462.537720},
		{"7991720ce95522bca3810e1aac25290b", -1291.675903, 463.241730},
		{"9efd8b1674987bc538b5de55f061c5de", -1035.675903, 463.241730},
		{"230be86dccca3394abc7cb09b9fe9ad8", -1386.661621, 233.858948},
		{"b941fb2f27e4a66ef289a3bf1cc28091", -1523.784912, -530.572266},
		{"e9ecccd873fcbc355f20176aa2c4f3df", -1523.784912, -274.572266},
		{"810eaab9c0c38d59af5ea4ed14c57b39", -1523.784912, -18.572266},
		{"b1c881f783fc273b5a79c67e9ef62aef", -1267.784912, -274.572266},
		{"01d81986b64d15c0295fa8c390e94a65", -1267.784912, -18.572266},
		{"caed76d83665b9219e531f1a02f3d0aa", -2177.481201, -29.818264},
		{"9480947239d970d0c459409d7ff087d7", -2177.481201, 226.181736},
		{"c21728512b6bd57a87fc1fdfaaa227c3", -1921.481201, -29.818264},
		{"98bcf710aafb3691bcd7ecf68107274c", -1921.481201, 226.181736},
		{"fdf9b9136acf62720bd2da26e4e70635", -1921.481201, 738.181736},
		{"aaa6b2064eb4b4b23049b33e4edb30ad", -1921.481201, 994.181736},
		{"97e65614ce0e39ed9fbb68751cc181b0", -1665.481201, -29.818264},
		{"623416b0baf2299e15c8adb26a796088", -1665.481201, 226.181736},
		{"bfe465f091bbe99ebadd113eb33847e8", -1665.481201, 482.181736},
		{"ff1ece15f069d3d9b5c5e1be283cdc4d", -1665.481201, 738.181736},
		{"030d746c3ae62c772033f3d220aa9214", -1665.481201, 994.181736},
		{"83098780c356fe70cf560b9d8b375a78", -1409.481201, -29.818264},
		{"ad520a39ec72560a3a516ccfe0cffdd8", -1409.481201, 226.181736},
		{"b27a374ec6dfd381fb28f6c5590ea78b", -1409.481201, 482.181736},
		{"1746ff3f79068655d6fd5ca37343770e", -1409.481201, 738.181736},
		{"49545d416652efa42010970c1bb04655", -1482.338989, -127.355392},
		{"27efce68942f5e9b4fa06521907965b2", -1918.172485, 410.265442},
		{"400d990135c7c867fbb580f48beacf4b", -1918.172485, 666.265442},
		{"314a636abb674224ef5bf88c1ba0df98", -1662.172485, 410.265442},
		{"42d4f1b8a647f9899ba42a84f96f4915", -1860.447510, 256.747162},
		{"60e82af2038b01cbccd3e4d7e378d0fd", -1748.107910, 444.828217},
		{"3ee4bf65a942cfca692e424582d0f005", -1712.469238, 241.358398},
		{"cb5e6dd3ebeee4645e2d524881acd466", -1868.337402, 224.499802},
		{"f3bf080278445f85199aa859e6920db7", -1658.965332, 480.780792},
		{"a657a915b0cafbc557d1e0fbb3e8aad4", -1697.737793, 446.265259},
		{"bb5066db9775dfeb0ee2c6ab5b169b5f", -1640.298096, 412.678741},
		{"0a6251564bc8159314a0c398611226aa", -1724.284424, 602.087158},
		{"065cf8a5833b4b5533f00b269c46de61", -2039.609985, 630.056335},
		{"014e81536b620d2363ea71cf6c85fe6f", -2039.609985, 886.056335},
		{"f413590aa96de98b923bb9100a47234f", -1783.609985, 630.056335},
		{"40e05a709efb29c469bd8f8dc7d97a3d", -1804.046631, 657.083557},
		{"df7f1690a34fce9c24988e613b9b51b5", -1940.134521, 399.830048},
		{"3d73a565c76777f8a4285bd127a7621b", -2390.613281, 337.068878},
		{"e33c4fd04313b687993e7edd08aeed74", -2390.613281, 593.068878},
		{"fb62d6d1524e2380f231ca741fa4443f", -2134.613281, 337.068878},
		{"8a3b4ff2c491c37195bc517db3647fdb", -2134.613281, 593.068878},
		{"d8d13445eeca1b229c8287111c224532", -1878.613281, 337.068878},
		{"1cbf927818114e3ae91ed260b0b2e803", -1999.549438, 452.561279},
		{"263113fa659a3c788703673eaf94f84d", -1999.549438, 708.561279},
		{"f71510a7c31734ae759986c203d727da", -1743.549438, 452.561279},
		{"24cd3101606af5abd5fc028db2c8d628", -1743.549438, 708.561279},
		{"701e7c96fa71583024ea00f39e5bca78", -2465.963135, 221.228607},
		{"e57a818069bd0529ade8cf7992d817fd", -2465.963135, 477.228607},
		{"d21a389c0a942ecb2992a02e2cc809ff", -2209.963135, 221.228607},
		{"d6cc9f2a53adb805ea82693fb1c6bc2a", -2666.110352, 553.257141},
		{"25b78fce75a1794294bac8e604a314cb", -2666.110352, 809.257141},
		{"641529bbcb032a4565257c4c6e95689c", -2666.110352, 1065.257141},
		{"1c208e3285f6887a603277cdff9f5c06", -2410.110352, 553.257141},
		{"6fa42b0c7e57d2344fbb196721bdb41d", -2410.110352, 809.257141},
		{"167a0802f397febd8d52ff0e74777f0f", -2570.443359, 582.396973},
		{"b49fec537a017579d2a482cf2355e1d7", -2629.463135, 612.082214},
		{"9fcbe842ea609cc539119eb7d3bc2ff1", -2829.871826, 1114.800415},
		{"fa79f4b9ff896af7264611c55a7bf70b", -2829.871826, 1370.800415},
		{"3cc499e99f5b6b9cfb23e93acf4350ca", -2859.297607, 1416.010376},
		{"0169fcdf281c592e73f837a32ba97c80", -2859.297607, 1672.010376},
		{"3b71aac1925580871995b43b46290817", -2240.435059, 896.248962},
		{"86164732cfc9c7990402011b3f2f888c", -2468.810303, 971.399109},
		{"09469b3d4c5a8f9f02efff91c5de533e", -2468.810303, 1227.399109},
		{"26aeb74c5555d2549355e70a9f1fb49c", -2212.810303, 971.399109},
		{"c1c9f5d5dcdcdad25817aacbc9479e32", -2212.810303, 1227.399109},
		{"e7430eeb8d4afebc8a215dcf3f728342", -1956.810303, 971.399109},
		{"e825cc9d5c6e830c33999e51cbfcfe12", -1652.160767, -129.949615},
		{"2dfa6717d12e703816156878d54dfce0", -1739.614746, -90.598099},
		{"834987b35ece95a14091496e29b00b01", -1646.617920, 80.343033},
		{"1d55922e0cd8dc66a4f2b227ba604f96", -2654.039062, 301.893127},
		{"3b9278fd1d58b658a2e071b9ce0e6b5d", -2654.039062, 557.893127},
		{"2dba442581e7213b43a46ec1d89662bd", -2398.039062, 301.893127},
		{"3814e5287ce0faf578dce307210eb4b3", -2973.353027, 610.367554},
		{"ad7f926992da09fa2557f9f1e47c0c0e", -2973.353027, 866.367554},
		{"64dfcf77e8c2ebed85c0e95edb1d47ce", -2717.353027, 610.367554},
		{"9fd482909c49f941b9c59d911e76c7fc", -2717.353027, 866.367554},
		{"e7481a76a55e2a28813e9065eb84e3cf", -1706.153809, 305.076202},
		{"fa078f77ac8215ae34058bb9d3df4ebf", -1541.629272, 2.230281},
		{"b11e677617ce83affbf62a8aee6c9257", -942.028625, -245.845810},
		{"88c0d749cb7c5c911572999a48e0dcba", -942.028625, 10.154190},
		{"9676c1eecc932dd9e5c5901edca3c53c", -686.028625, -245.845810},
		{"468d2d1985b719c892de35259e0a3c99", -1171.647827, -78.488434},
		{"36d818faa2678c2c761b816c8d8d1129", -1171.647827, 177.511566},
		{"342a08d984bc58ce3c3a06ae30a33538", -915.647827, -78.488434},
		{"e5f7e035cba05ae0ad3a4e6520b687d1", -915.647827, 177.511566},
		{"8e1588bdce77163c602e9d738ad8e462", -1667.077515, 656.232361},
	},
	["Dire Maul"] = {
		{"cbaa312cc395f0b9d3d643720ff6810e", -435.554657, 16.542398},
		{"b04aefeecc206e8829b2b503acc52ac4", -422.192413, 131.017822},
		{"672b62bfdfa4814b3dc6eea541dbe86c", -423.038818, -27.667997},
		{"5bd5eccba10a874ba4cc78ad8d3844f3", 493.348602, -71.925217},
		{"2ad58fc4d1221f607e09e37cb825d043", 502.853577, -26.629761},
		{"075df96172d00a4e2943b68c23f72713", 488.993713, 15.786147},
		{"96776c1c8a6e683669408b4ff593534b", 502.090027, 130.729813},
		{"f97f11601c48b7e40efef7adc691570a", 493.348541, 166.543335},
		{"e8c6f053679afd5d3d3d15d6671b5d7d", 857.046570, 274.602783},
		{"e8c6f053679afd5d3d3d15d6671b5d7d", 738.977112, 274.604279},
		{"e8c6f053679afd5d3d3d15d6671b5d7d", 618.942322, 274.603973},
		{"a836a1941db3fadd0b3d97bf299c6d5d", 601.809570, 434.060211},
		{"61ce844bf601edd35f1509d34c6db958", 639.066589, 304.933411},
		{"2fc73ab627b074e7ccb45e66f3d0b92f", 692.318787, 172.497665},
		{"11b2a65624d70d0fbd46372c25aeabba", 1244.262451, 760.751282},
		{"e3b5ca648da46a3a8ffedc488f204eef", 1244.262451, 1016.751282},
		{"36222e993438109a4ae6f0ebe4ebf0d2", 1500.262451, 760.751282},
		{"bbe7bbe71871cfc37f24102889ed5875", 1500.262451, 1016.751282},
		{"e37319d8da5b1296685c82d07687220a", 1756.262451, 760.751282},
		{"c4505c2ecb8a7bc4dab21f7a0834c51b", 1756.262451, 1016.751282},
		{"fdd2719ba534f7a4521d90b901bd4430", 740.782288, 965.957153},
		{"faa1b35c2ca00d71665b313dc1b02e21", 1048.149780, 924.848755},
		{"8866126b49557de7504e6534ca209e5e", 731.602234, 752.320312},
		{"bf11ffe12724c6b80ae3a30ca03ff6e1", 602.736938, 580.501831},
		{"795cd362cf7fc31055bec4678bdd660b", 909.056580, 1078.046753},
		{"d6c1d1755832308cbdbabc231ee6d4fe", 927.919312, 1037.673584},
		{"017494d784efb1a6271647e8e44e6901", 1183.919312, 1037.673584},
		{"311c8877fbc04e2425a76418be53ac55", 970.741882, 952.181763},
		{"f49c21c4889ccdb3b55cf13c94fcfa02", 83.593445, -351.298737},
		{"a8c09dffe68157084bd54de99a50cd0c", 26.074097, -318.223419},
		{"efa382ebcde2bbb30b8793d29a2bc162", -152.029083, -330.987915},
		{"22d25ca8f14d9f73a8920291b04e0e25", 261.166931, -1230.355957},
		{"e172665131fee168c62766330cac77f0", 261.166931, -974.355957},
		{"9df4b13eea7a2ae10dece580c2baeff9", 261.166931, -718.355957},
		{"ac5092d7f22dc27f8e9a4618e6a9c156", 517.166931, -1230.355957},
		{"a7ab1f78c3603d1e00e7b7f58835b51c", 517.166931, -974.355957},
		{"2bae92fe8632e16bd3333e1c2a069a67", 517.166931, -718.355957},
		{"ef539e08ea0a942f6dee94c05131aaee", 773.166931, -974.355957},
		{"37051a8032756dd822f0bc797cfc3a73", -248.078323, -949.485352},
		{"e7b1ea2ec00cdc79e6619128267ced6b", 7.921677, -949.485352},
		{"2fc958dcd0209c7d5af30795ce7469e3", -240.295715, -956.394409},
		{"aa42457433d5f9bdf0aa35cde14ad7a9", 15.704285, -956.394409},
		{"52fe8388f0e473bad02bfe3a55499bb3", 149.423599, -427.531921},
		{"c67448ad9e0c5eb07f530fbb5f89e8c5", 312.194550, -500.405212},
		{"67d0b7ad1c2dcc0ef10dda6171b197f4", 388.198120, -540.173096},
		{"659bf6ff5feeeada15986d801dd7dfd7", 479.681427, -619.318970},
		{"00cde19f745aa51d3ce453936d5aaa5d", 531.696167, -708.442505},
		{"14d4b4e17e80f1418537628932b44303", 490.140045, -776.920654},
		{"12c6f8d0d1bdaf44f0874e854a6a6e27", -375.943634, -779.965454},
		{"53dc062770506cdcec52a7f38ae7a0b3", -375.943634, -523.965454},
		{"d14acaf64b2c43eb77bbbf8a70984dd3", -119.943634, -779.965454},
		{"2752bced300e14ddfec9cc31998fed04", -119.943634, -523.965454},
		{"f5123cb7f7c0733825f0ce6907a92080", 136.056366, -779.965454},
		{"63cb702e6cf0120a5d2e549ea83dde0b", 136.056366, -523.965454},
		{"92882b1ccb17a592c8e5b70e6df1d30f", -442.281250, -641.397583},
		{"7d0afe0b8d15121882c3042ae1c15990", -416.175140, -689.847046},
		{"5b77a64aad0c11548136a0f33e7c4a60", -303.018829, -823.742371},
		{"75fcf371f78b8fa6d34946359a247dd0", -295.892548, -760.075562},
		{"ff30fd46d8d2dee23dff0b96fa04a28c", -321.048431, -1035.393555},
		{"bc0c780f270df9bdb46d048414b70fdc", 52.907536, -994.519226},
		{"579e327e5a91a9f7a50c29272dca5d66", -11.786288, -994.337341},
		{"d7106ee4895949cbe357e752ca0f4129", -265.114502, -814.203186},
		{"bd0e8b59100515413819370273beecf9", 203.701752, -954.843750},
		{"38d32dd7597a919a332d5b695f383a10", 176.965942, -908.640625},
		{"6ffff19bb1a66391254d0d546b7b4006", -46.373837, -1742.689697},
		{"dbe0d0e7ea813b62b5858f9c0e286941", 94.058266, -1632.119751},
		{"7f7925dbd7c88d471fe65d655b0dd251", 94.293739, -1171.918701},
		{"cd72ef26e3f4cbf13f2372458a9dec86", -7.275587, -1592.717407},
		{"47c170235fc3b301f7ff602121604b64", -7.275587, -1336.717407},
		{"e6f9857d5b49821a482d25f169e982e9", 213.597015, -1061.038452},
		{"b332271436e2fa3ff93ac4a56bf0124d", 185.650848, -1100.378052},
		{"70203f839d86b43f171a5ec816af229e", 157.426895, -1096.060913},
		{"7b58b813bb98f8f9e854cd30d662e148", 89.976402, -1132.519043},
		{"3d92014ecbeaf785100cfaddec3b8eeb", 42.576946, -1684.615845},
		{"f5212ecd729be2e5c14462c7a45c6cc8", -53.088413, -1734.344971},
		{"1f4bb8faba3d84d94a91c9d1986ed159", 14.577161, -1680.298584},
		{"ecf758bb33c233604b7da441b17f90ea", 366.479034, -568.412781},
		{"a85786433bc40abfa196f8bd60b77785", 468.174866, -614.080383},
		{"7265c4094160597684608caf78ef1463", 513.744629, -657.140442},
		{"793581bdaea5751229c584dbdbf8f874", 261.884064, -568.404053},
		{"5cd96d2b24fe407d81853a27afcdcd76", -321.013153, -747.059448},
		{"580d7104a5d92b10621016848a2d30d3", -321.013153, -491.059448},
		{"768a50199a9842710dc23312bc246912", -65.013153, -747.059448},
		{"e39e52c26f62a126bb6d4f30c59eaa03", -65.013153, -491.059448},
		{"f4ca878f76874e579ae0ec3a25a05a27", 190.986847, -747.059448},
		{"a43ee50e02083ad865ead845a67b2b84", 190.986847, -491.059448},
		{"54c9718cfce631dfd1c5fe30646fabdf", -459.158966, -960.019897},
		{"6956513817c69d58751a1ff6c5c5d69d", -459.158966, -448.019897},
		{"430a74c624ab5b5355bbdeb2c91d7c55", -203.158966, -960.019897},
		{"eddf76651536484328188e17f3ae4c5f", 308.841034, -1472.019897},
		{"89228d746e2017c51e719b9e06ae6f34", 308.841034, -704.019897},
		{"2a4f9355b68e09bff9253d238b3697cd", 564.841034, -960.019897},
		{"ac65861a2c99ea32619a13596304f00e", 564.841034, -704.019897},
		{"d5ed1fb515acffd05dcfa56a1275f63c", 564.841034, -448.019897},
		{"687ebcdeb9305d88704d747ba270782b", 820.841034, -960.019897},
		{"374e4d098265da88afb3fbdb78cb9046", 26.304102, 311.090302},
		{"6e09797d1c35f5193d581c25443ab1d1", -88.653725, 298.014313},
		{"8465cfe5981178f6747ed3c6dd6ec6ac", 56.681194, 301.896545},
		{"65ba48159e234359d9b0b8580833019f", -166.845581, 302.690918},
		{"78d6e86be0c5013dce455fd45a3e44ce", -119.030884, 311.887970},
		{"640ea447d88d49d97a4dbaed16554e0c", 210.418610, 866.652771},
		{"43ca5f097b64e12446a59acfa85abb37", 210.418610, 1122.652771},
		{"d80bbd0b51f1bb3ce07fb31a85ea2e99", 122.716362, 1236.315063},
		{"11780a3d7282e1b2de95bf1a2858e67f", 346.647369, 847.563721},
		{"68820381313f686b76443be1b23bd7a0", 326.273590, 826.059814},
		{"d3c8f5b224d178bb386a989a498ed51b", 505.202179, 732.532166},
		{"52e83facf549a5a4583414ed1061c3f0", -236.338760, 739.385376},
		{"53f94a311aa387feaaa1e5b7c509cf84", -236.338760, 995.385376},
		{"3620b777d53a9eee4d21277da37b0181", 19.661240, 739.385376},
		{"94a497964a26ce7e353e0b2588481836", 19.661240, 995.385376},
		{"c29792dd487fdbc2e0b45603da08ed54", 275.661240, 739.385376},
		{"a9a7c745076bd0193e4c1ed0a85f157e", 275.661240, 995.385376},
		{"20b80bd9deec7ebd775c7b4f6d08e67b", 87.265984, 996.076111},
		{"8390f3567f50d121402b8ebc37bde8a1", 43.743031, 1049.213379},
		{"1b29b18b0ce62b17fc77353be1fd0000", -99.822365, 1088.910156},
		{"880f815ec32d8dc9d46632f3567d7818", -99.822556, 1174.239014},
		{"dd2fd5de21588f8062dae21104f91126", -416.442413, 1198.817261},
		{"82e418d6e81ad64bca22b9e0a2ad8799", -416.442413, 1454.817261},
		{"6a85132f66a5646afbabc0eb5162813d", -416.442413, 1710.817261},
		{"5b586b57a759a5f0ed063ebf77212a35", -160.442413, 1198.817261},
		{"b1d174eb3ffdcc8cdfd856dc8c6c948e", -160.442413, 1454.817261},
		{"512826c0efe2ae6674c119a17b9380a3", -160.442413, 1710.817261},
		{"3aa699bd6b00a1c26c3c2dfff3fd88d3", 95.557587, 1198.817261},
		{"b58f9dec55d32d326ce0828995e062f2", 95.557587, 1454.817261},
		{"4b159e1c7a65ff70860dfcbee3091d69", 95.557587, 1710.817261},
		{"96857eb6ecbc7c87b71f2e157844d266", -243.474579, 349.167725},
		{"cd2fc5abec650a126c231ea1d9e364f1", -243.474579, 605.167725},
		{"74cb5197ac0f146bd281cb10f27012fb", 12.525421, 349.167725},
		{"49e38e8a522a6518ea82e791f9f6cb00", 12.525421, 605.167725},
		{"0956b0645ddcbdc1dbf17976b04ae12a", 268.525421, 349.167725},
		{"470c20a83955f370cc8c58936ee616b0", 268.525421, 605.167725},
		{"ccfe69eb18a151a4047d62a03a0ef6db", -237.247482, 903.189880},
		{"6e94f8bb638d77f4f9d28e8720e1b3eb", -237.247482, 1159.189880},
		{"2b71d021c1077586daa816fc30f7aa6d", -20.077671, 828.154358},
		{"f2b31aeca225c77c940e8c0085ccb328", -20.077671, 1084.154358},
		{"2b020dd28b6a53b239c0ea28cf3d5b80", 235.922329, 828.154358},
		{"b8beb85b614ff4a30fd895778eea01e0", 235.922329, 1084.154358},
		{"35c5720d158afbf3ddd535261a32e9ee", 191.101486, 741.835022},
		{"1c9e59df4965c9f13563c2d0dd2099cb", -205.226639, 741.823120},
		{"6cd314ac97704d0bf9b8b529ce123152", -775.464600, 377.387238},
		{"e46819495d2976f4df6a0b799836cf17", -775.464600, 633.387238},
		{"ad6ef9fca02584337a412b4e6173e8cd", -775.464600, 889.387238},
		{"7c8c812436dccd6f95f7c8ccd075e0d6", -775.464600, 1145.387238},
		{"a0a692ecd7a148ceda02e36e2e0bdd6b", -519.464600, 633.387238},
		{"167888ec1630170a7ca2c56db7b8c32e", -519.464600, 889.387238},
		{"2e3c8dd2b51649ad2ced2986106ab45c", 248.535400, 377.387238},
		{"9a6648312fcaf91b82d7b0800070b837", 248.535400, 633.387238},
		{"546fbcd52a1ca79dd42b507ef4e3345f", 248.535400, 889.387238},
		{"cf5cd4532184c9d0e92d57297e6e78c9", 248.535400, 1145.387238},
		{"a3ab61969b284cd5afa0b96f7fba6631", 504.535400, 633.387238},
		{"9789414c3c5e7599a8bd06a3ed20cdc6", 504.535400, 889.387238},
		{"6656ae79705e57c58988e14da5d1b196", -69.369026, -38.825489},
		{"1d2a72e428142a475606617f4c5319bf", -4.955119, 138.720032},
		{"cd2af5ed1e3d2ea929eafff92fb2c993", -26.846699, 198.681976},
		{"f28d9ea0061d8fe3fb5081a77b073cdb", 20.901194, 54.068909},
		{"49d8f9f9b9ca1cc5e84e7cef31957198", 21.071270, 110.502907},
		{"4ed23023fd103b3d26c9e1eed191cd4e", -60.223507, 245.454315},
		{"9458fe956006fdf54f048d864d17ec2e", -26.846996, 133.091492},
		{"a7c03ed1895e8017428b39c533ddce45", 60.741028, 166.118439},
		{"ed6858fc58b54323014365f581a8862d", -61.805672, 267.158386},
		{"3e7737499d981e1f561eb2c49e73e8ac", -101.950020, 301.315582},
		{"5ca5dfa71d28ce902265151604e191e6", -166.500031, 327.982086},
		{"f6cb770df89dee58aa71bb870a077e67", -186.370102, 276.534882},
		{"32ccf52c7cedf91fc7cfee641e61a170", 539.472351, -273.647308},
		{"5a1e808152601aee1d1e29bca57637bb", 539.472351, -17.647308},
		{"b5c7b1a8e694b6ae20374d19bd18bc98", 539.472351, 238.352692},
		{"3b693d34ea9a30872a39a1095f6045d4", 795.472351, -273.647308},
		{"0f55dee37d6cf687498029301ef91694", 795.472351, -17.647308},
		{"84d5e9c18c79e4b829286fdf9ce1a29a", 795.472351, 238.352692},
		{"88cdc7b615821d825c9232eba0e63e69", 531.121094, 304.518463},
		{"5ec18c31de4a7cf2e86c1efb877256cc", 531.121094, 560.518463},
		{"55f76b9aff184fd0cfd74b0362051fab", 787.121094, 304.518463},
		{"b15f1dbc5664f94871cce0ef03bf596d", 787.121094, 560.518463},
		{"7a61dc6b626d94e0d888410a0a042126", 474.696808, 162.024872},
		{"379f79ba6699c8f1142cdb1b5b6b1f4c", 730.696808, -349.975128},
		{"c721b4cfe16f652ccf7f2754ffa66466", 730.696808, 674.024872},
		{"eab82136051de92aa871020e2f15bf32", 986.696808, 162.024872},
		{"ee9394d10f9692962c7513f5766ca717", 1498.696808, 418.024872},
		{"8d27d74709d2a166aa1fe083f371341c", 1498.696808, 674.024872},
		{"cd1a1db34e62288403e594d2cba5f6e1", 1498.696808, 1186.024872},
		{"35199d327b769de35c825ebb1dfd105f", 1754.696808, 930.024872},
	},
	["Gnomeregan"] = {
		{"0df0e0e1e00d12a1344658a52945a1e2", 884.914124, -1512.321777},
		{"60fede6dae1d07f24eb75675a4e80b63", 884.914124, -1256.321777},
		{"c40aeb17298544ea3eb3ec872c12358f", 1140.914124, -1512.321777},
		{"d7d2546076a2bbd945596e927cbf10d3", 1140.914124, -1256.321777},
		{"c283387629004c8b11cf0c8c472933a1", 826.810547, -555.285339},
		{"764f9465392c9cd63121c5a163430a45", 857.738220, -591.148926},
		{"e0cd29c9a2175d51b69446e90c9e3a78", 936.956177, -591.153076},
		{"11358614fb0ae813ca61764d35ecb5be", 1025.032349, -597.034973},
		{"36ea2e67b02210ccad87f972cc127bb4", 1046.430298, -616.290527},
		{"b76836dc18b331bcdf3f9f1cdeaa66f4", 1056.586670, -705.079895},
		{"e1bcaf01b755b5274a9904dd466cf2e6", 1031.397705, -789.270691},
		{"64918e02e1685d91ac49ce6d5ac69e80", 1029.736084, -71.625153},
		{"f084f7916e2501b6720ffd5452f72fc8", 937.444153, 95.380089},
		{"f38b3dc8ab84394de12cb4ba457604e7", 967.790588, -133.747406},
		{"421ad6929ccc03e94440778dacf6f2e2", 713.341248, -381.050934},
		{"f9ddd1a42ef877a833c52c3922e7d8fc", 713.341248, -125.050934},
		{"3b76ec6d52095d93b769a3112861847d", 969.341248, -381.050934},
		{"76f6968a5093d8857001ecb07fb548a3", 969.341248, -125.050934},
		{"c9a14b1f907730938556663d24e92553", 1084.536011, -333.716095},
		{"6c5105d2a1392092df68dad248f633ff", 1189.838135, -335.793213},
		{"702e0befe92af6d97ed43dc75be45508", 1134.342773, -466.197296},
		{"c1e3ccbba54422f3250e11f0813d20a4", 1048.243896, -327.960327},
		{"36b284b26d11ec0c75ff610fd755523d", 1048.243896, -71.960327},
		{"dd8e4241b991594e188d96ef9aa373a5", 960.021729, -481.528137},
		{"e438a8876cae58c238b4ef7aa0a22d84", 1120.244751, -122.913689},
		{"fcbffeb04ee1b7a128969fc5e66d1875", 1151.517456, -79.770622},
		{"f2e8c36c102aef51ece0757996cea874", 1068.764648, -487.364624},
		{"ec1d00b5e7b6ced6984b203cffd4e805", 980.366028, -399.291565},
		{"983416ffc40fdfc643dbd781f36c5296", 707.226013, -393.018311},
		{"246bb69bc1a9bb774f231695f63b6374", 707.226013, -137.018311},
		{"23d1ab99d3c12311f815169c0e709a69", 963.226013, -393.018311},
		{"1387d048ad5f9fef7992acecb13ec57f", 963.226013, -137.018311},
		{"d470c6cdb446943675614ee8018eefc4", 1224.952637, -312.396057},
		{"50eeb8c1f5de98170a34ed06e0498847", 1062.071899, -122.913673},
		{"428cb1e2f0cb61e8085c6bab4a7b62aa", 1076.874390, -79.770630},
		{"0fad785d2b1937af846a2ae2dbfdd469", 1330.327026, -1113.641968},
		{"31b98d9c09a3908f8941be3af3a87ed0", 1213.325317, -826.834595},
		{"7316e82cdb8dfd0290b065e50bf75eae", 1258.555420, -777.095947},
		{"1f7cad503490e39017eebcf2d91852f3", 1268.759155, -875.863770},
		{"8357ee7db91449b55261b33dec41741e", 1237.476440, -744.841675},
		{"1d076a1645e10a52266cf5dc89c8153f", 1541.209717, -837.892761},
		{"b44097170990e5d1b8036b4779a77a4e", 1720.162842, -846.577332},
		{"9278015130cd008bb6c8bef3409b7b8c", 1232.025879, -1451.167236},
		{"e4136501ce145e70127f0ba80b5e7011", 1435.673950, -1363.357910},
		{"940b3ffb7f164331894d1ea164dea225", 1449.918579, -1307.073486},
		{"e6f59077ae1d6f780d3b51d060b123f5", 1464.166870, -1250.785889},
		{"ec1da740dc9703555b3a60e776f482e7", 1402.196533, -1138.122070},
		{"8a66179f9a8d7f25d7ee9e0fe3b76adc", 1345.918091, -1123.883911},
		{"b7c1b59c5e4c67bf22815b751ceebaf2", 1442.597534, -1210.391479},
		{"4ed59806333c08ca775acf29d8706a12", 1363.709839, -1459.900269},
		{"f9b70b4e3a98153b59358bc8f03dc843", 1637.536621, -908.716309},
		{"83032cd676c85f158a9c779b5076071a", 1535.646606, -1125.459717},
		{"e71f09572976c8170921c51be984fb37", 1499.285278, -855.595825},
		{"e9f231110b54ba3bf09db71ae26510e7", 1739.991577, -875.451355},
		{"0318b06c53de29e6889f6043cb6da3fb", 1199.772827, -952.650085},
		{"d77a87706bdbf2899d41b36fdc31136d", 1455.772827, -952.650085},
		{"a5570e87123f844f72ad484a85e6ebf8", 1446.060791, -886.584167},
		{"3a53a5ad3e07a65f5785b7f12f4fbea9", 940.704041, -1168.076294},
		{"465b8b600df791fba069524ee1719d22", 940.704041, -912.076294},
		{"c5882da9b6df6a04ae4da9324fcc5d0e", 1196.704041, -1168.076294},
		{"102cc947b5b7594c1930d3f028b6a446", 1196.704041, -912.076294},
		{"00ef814dea5184217d6cff2f22cc1c5e", 879.385315, -1231.685059},
		{"ab15036b7fe9cddc7965910ee93bcfda", 879.385315, -975.685059},
		{"42d37b9e1277da76475a9856a7979d28", 1135.385315, -1231.685059},
		{"77bb79daf629ceee35bf6b9a89d85f4b", 1135.385315, -975.685059},
		{"4508b4a0bdcaca2af8765754dd8aa98e", 1445.894409, -1322.967163},
		{"83f3e263d132a7e4a7424ac3a275bdba", 1460.142578, -1266.675537},
		{"2a28119a56de110a4bef859a9ec3e67b", 1386.304810, -1127.899292},
		{"c0b00302e64add1b59aaa0304e80157b", 1616.554443, -1042.576904},
		{"1c9abb81f1fe77e1208f9d86e75cc7f5", 646.176697, -124.250244},
		{"6508ec1b74e9f18a1db5cd1e43896274", 401.776672, -286.789429},
		{"aa7885b390f80af5f1716eadbd6b8cb7", 401.776672, -30.789429},
		{"fe846d9e54d869dce3f16683db25e44d", 1501.317017, -878.241333},
		{"a7a5358bb1f06c1e0e3170cd06fa9988", 1501.317017, -622.241333},
		{"82bdda9f164f0228f130014ce2d3d1f3", 1757.317017, -878.241333},
		{"b8a6370a676e84067a54e95334b53dc1", 1224.952759, -199.907959},
		{"a8882d0bcecff6447092efe800036e29", 1189.838135, -168.736221},
		{"313b9d204f6eed07ee87d6709f30ea0f", 1189.838135, -250.674942},
		{"4230cb00618728204652772ea72d08ef", 1601.869995, -387.257111},
		{"7d7492495cd96ff613292e79dd21265b", 1441.920654, -514.494934},
		{"1423f00c1253c8a134147fd2af588adc", 1492.426636, -563.353638},
		{"da827ed643e5b17998e1edc26081a015", 1507.971924, -207.242386},
		{"5252f6bcc84eb8b5deb23ac42b7676ef", 1565.526123, -230.089417},
		{"6b4315d58298c5a601578e7f15a7e543", 1316.486084, -26.456142},
		{"c495fc74d9954a213043e8342885cc50", 1455.903687, -41.676605},
		{"16d2cd0de687ee9100d527dce8f27527", 1496.782593, -149.138107},
		{"b96aed56fa8e05a59b38e673fc6ce9e3", 826.810547, -473.629120},
		{"e4f334f63e4a7337cab6a8a074222af0", 1523.552490, -655.208557},
		{"fae0efbed0a2ff7918736a661eb071e6", 1591.554810, -585.193726},
		{"343e33d5d33b21441d7d56b734584fae", 1724.376831, -639.168213},
		{"e70f1e9206f2285958cfe428d674b1e4", 1793.320190, -691.574463},
		{"91473f8c46985826d0f9d7c77c1aa96d", 1687.581909, -873.935608},
		{"31772ab167c75653490265f6bea32d14", 1506.083252, -787.394409},
	},
	["Mana-Tombs"] = {
		{"76d18c9d39e5b36245516301e3ab4f03", -160.141663, -103.652519},
		{"c8bb0a5368d2416e11b046cac6a428f1", 95.858337, -103.652519},
		{"cc581f6eeaab32efad6e47240e38bd6f", 112.471039, 292.965088},
		{"b49ca6955fce854af51164923387ba13", 671.814697, -41.015881},
		{"8a115dfbd3d609bff4040265c84cc968", 175.637634, -41.030453},
		{"6058b0e028213448fee66d2087a88227", 666.711731, 398.670258},
		{"ebb81c1286c8c51367efb9066b3cb448", 312.542633, 423.920227},
		{"91348011c21b48cb2d5fa24d9ab9c3ba", 723.309692, 217.412918},
		{"b30925f2338f84a96d38e0598664e94d", -84.942360, 340.870361},
		{"1f0c489c2898fe6e4bcdfaccafc4fa49", 171.057640, 340.870361},
		{"5e973a25b8a5b316765739c9fdc3f740", 15.512433, 52.317009},
		{"72019f9781f541bbfaedc3d4d9596a3a", 357.096466, 287.583038},
		{"c88c19d925a8bd9fdeb4172e1170beea", 357.096466, 543.583038},
		{"0d20c1516b12b5e6cb1b42d1d5376b20", 613.096466, 287.583038},
		{"0dd2ffd18484f0c21b82f781e84ee00e", 613.096466, 543.583038},
		{"5a2ef5f163017e8d7f6f317ac38b01c7", 316.832794, -120.011650},
		{"6d23dba19b58ca66a3b9b3cdf8f0553b", 572.832794, -120.011650},
		{"664d1ee8c1833bfc3265ecd864b661be", 520.514526, -105.881020},
		{"7db56aa9808cbca217489c024c711371", 634.832336, 76.027962},
		{"1ecdebe1b8e32513f7871d4b47e05009", 634.831970, 257.285370},
	},
	["Maraudon"] = {
		{"2ab249b4f6357048bcacf23379c219fe", -1646.207520, 1167.098022},
		{"77489de0a16abb9e1360f9997c8e0bcf", -1646.207520, 1096.958740},
		{"a9bacc81bbbd6df5d192b3d9fd323eea", -1737.142822, 838.243530},
		{"c8f1c7eb9aace5387e7efd3dc009ff7a", -1800.442017, 626.587646},
		{"5515d6aac833d6782bb46e1be11fb935", -1800.442017, 882.587646},
		{"45fdcf602df8ee4306a9a63dd1d6b42c", -1544.442017, 626.587646},
		{"88755726e7b921673a4d0fa77ab52654", -1476.807251, 587.457275},
		{"1729488e84de43c2f6a069d33f9a8dd8", -1220.807251, 587.457275},
		{"82c306868404a5bc5576f2c0015710f2", -1507.654419, 267.947784},
		{"39cc350df46ff608a96189b5a5feb17d", -1507.654419, 523.947784},
		{"3240f2508da18018420d1e6eb9502033", -1251.654419, 267.947784},
		{"6a4a01bb27b07c3459412fd869eaa4d3", -1251.654419, 523.947784},
		{"5c367e679c13a32c528e532c5601ba7b", -1403.702637, 147.908096},
		{"ed100ea1d8040876239918d27b3343bf", -1877.262329, 2.073998},
		{"e81dcb1322bb1b923de135f9bece6c24", -1877.262329, 258.073998},
		{"078cb5173ac90623a839074d50974166", -1877.262329, 514.073998},
		{"291e6f59cc4b4d46b3792c7c743c6d55", -1621.262329, 2.073998},
		{"6d93e71f23e101c832bfef7384fe1c05", -1621.262329, 258.073998},
		{"b88acba8ad237e232b37addd9ea3bc98", -1621.262329, 514.073998},
		{"3381b99aa3548684a7fe298a794d41b3", -1653.846313, 824.255310},
		{"a643461a048ad2ebecebbc7d8b1ceb5d", -1653.846313, 1080.255310},
		{"f78ecc565dbe4df4a1699df33915bb5f", -1397.846313, 824.255310},
		{"e70eac51b99aaabdb866427709a7cc8c", -1759.353149, 1254.752075},
		{"d94557a2bfd95eea0102ac7f5bb22b8e", -1759.353149, 1510.752075},
		{"883c6a53286c8c543fe0b80c84c23181", -1503.353149, 1254.752075},
		{"932a0280858db3dcd54a905ab8eda337", -1503.353149, 1510.752075},
		{"7f1c0f68bc5ddfd9f3602b3f895e7ac5", -1813.273193, 788.295410},
		{"b458fdf03461487d9ddde5256bbbd908", -2189.111572, 715.188416},
		{"218daba1035c23fdf76da6e0675880c1", -2123.980713, 621.112366},
		{"c7cfc1f19f8ee0e60762ab576a3f08bf", -2054.044922, 669.976562},
		{"e5bb908030a7ab307bb1099e5026ac56", -2030.086548, 407.502991},
		{"2500d2217f350c21d3b993ec6dda7ef4", -2030.086548, 663.502991},
		{"6f7eae1de797b5d665cee7026fe9add6", -1774.086548, 407.502991},
		{"9ed689a8cb6368f1231ee47ae3952898", -1961.911011, 165.831070},
		{"4bd6ccbaa5776d77affdaa6fd50fd816", -2011.622437, -19.032095},
		{"3b788020209d643f2cc1bfcc8bc3ee2a", -1755.622437, -19.032095},
		{"8b05deb6f2412a5230ad1d9bd56ab591", -2156.516357, 562.720825},
		{"075b1596ae0fa501c4ff9af4b8c73bfd", -2040.099121, 599.984070},
		{"1dd4dabfba34c556a2ba982aa4ff29d7", -2192.273682, 832.495117},
		{"67b2c3db2960b9de6223e44755af974d", -2016.756714, 852.746155},
		{"9a60e38fffcfa0f780fc9a1aa5af0641", -1056.788696, -249.777832},
		{"5b5d7f19fea2835011dff21f595df1ef", -1056.788696, 6.222168},
		{"afb4bacab733b79d5a2201a739d7d5da", -800.788696, -249.777832},
		{"2fffd12a1f45335fc8a161c36bc49245", -800.788696, 6.222168},
		{"96409fa63ba20d78b5bbf1f56fb6df39", -544.788696, -249.777832},
		{"3827c9098155463fafbd89214cc946b8", -544.788696, 6.222168},
		{"f3bc89a8a6d7c7d5339492bb411bd72e", -1066.076172, -313.301544},
		{"9ab41915740e97f7e874ca2248e9201b", -1066.076172, -411.533112},
		{"c01de8d4843b961461da743cd78eb961", -1086.426392, -586.719543},
		{"641e5eafc6f4dfcb3cb268c1f56718e7", -1086.426392, -330.719543},
		{"684719c460b38307e202f459867b9598", -830.426392, -586.719543},
		{"184f026f7a6cba93d4728cf70cbfd41a", -830.426392, -330.719543},
		{"b231585f8a512e515772d6c75b17e06a", -712.984680, -351.802765},
		{"87b89eb5ea485818764983e07638d461", -661.636597, -249.712753},
		{"0def2e1621e2983e77a9328a5dccef65", -480.379333, 129.635864},
		{"625f4675948b1d0d5cd9a82f4e1b4274", -718.129883, 493.728088},
		{"48fcb7df4b2ca29e88e754701fd4f3cf", -394.621613, 579.874268},
		{"35a5cae75748d98be0f533386155810f", -394.621613, 433.258606},
		{"5672a4614ac014720fe78ab46cf1adf3", -359.592224, 337.996979},
		{"461edecb8b2157e16403b91f7f15f685", -275.202179, 302.437286},
		{"5f32715ac5dbec0e1b509ec6e132c2e7", 133.215515, 466.202911},
		{"d31b09a9027913e9e4f4cca898fd3a92", -350.343842, 407.341339},
		{"4e78c00d489db6f616f9a49417c8f3ed", -544.688904, 159.497253},
		{"d60716f4cdf08d28678c04bd67025a3b", -1716.587646, -265.161346},
		{"af257fac261f0891efb91865738bd2b2", -1716.587646, -9.161346},
		{"4ff8f0e5d0df48b98fbba4dc628f1048", -1460.587646, -265.161346},
		{"6dcb801c0641c6cccaebd83fe5cc5311", -1321.148926, -294.733368},
		{"b244a49d06742c5d8ea1cfbd7536b812", -1321.148926, -38.733368},
		{"e77325b858a850bc22b07cab1d81f8bb", -1065.148926, -294.733368},
		{"ec7ca73a2d8d85273a5fa2bd8378c1de", -1065.148926, -38.733368},
		{"b63cfe3a8a13cca3497a77bcce5da5f4", -745.064087, 180.759872},
		{"351b344a17aeed60ae16022fd6abd6da", -745.064087, 436.759872},
		{"4c96f473073773f019585ef36d8bd349", -489.064087, 180.759872},
		{"67429aa70b62525e340cc201d85d5872", -489.064087, 436.759872},
		{"d7ea04d9789e27bb04b9b57daebdde51", -301.452240, -319.512146},
		{"2b6414afec08dfd4b3430329e9ded51b", -301.452240, -63.512146},
		{"101461e2c2a16b1292ad5fa1af29f4de", -301.452240, 192.487854},
		{"8930bb50eb8fbd3aa3612634eb4b0417", -301.452240, 448.487854},
		{"d4a599d6bcf835d1ba276f4ad9b85210", -45.452240, -319.512146},
		{"2de6ff3253f27a30eec986af5fd6af9b", -45.452240, -63.512146},
		{"a592d85f6735e841786688257641533b", -45.452240, 192.487854},
		{"8a56651495dced5cab78efc5ec313a55", -45.452240, 448.487854},
		{"794de91b1e4b34edd9e40c1c21007493", -45.452240, 704.487854},
		{"7844960cb45837c58572c5bd606192ca", -33.875824, 631.181335},
		{"97fa6b32b1d256f27048208a22352f5f", -33.875824, 887.181335},
		{"d8fdd682b10dd2e7a10cc62b8e2357fe", 222.124176, 631.181335},
		{"c25b87d41c16c9a1590a25bd1ac552db", -706.528748, 598.552673},
		{"72edae48a6f9a85681f63ffcea513336", -450.528748, 598.552673},
		{"26de0c4d62c2244c8c89d167b7d0b7a8", -2337.741455, 338.599182},
		{"0ea0b10e88f19c822e10335d6f9dfe5e", -2337.741455, 594.599182},
		{"177700ffed2e41990bada54413daba7e", -2081.741455, 338.599182},
	},
	["Molten Core"] = {
		{"f60a29b3a2f5ff39ddc11758c6799cf4", -2666.110352, 542.664612},
		{"701fda327fcf58f388ce9d400045f288", -2666.110352, 798.664612},
		{"b411370404c376e76345bd8ecd6363ab", -2666.110352, 1054.664612},
		{"d3a7a788f62d5ac84c9c4a3c373f216b", -2410.110352, 542.664612},
		{"360c7f76868860341e035d51263fa1fa", -2410.110352, 798.664612},
		{"115086e9ae115926fb9d9c066dc0972c", -2570.443604, 580.058411},
		{"ecb6c9a7efbfbe5697208aed8dafa846", -2240.435059, 904.925964},
		{"c0c7694eac7c8f07df8d0d04ced96da7", -2474.171875, 972.719116},
		{"06cc07f31679f5ef9f06c4b9923c3bf0", -2474.171875, 1228.719116},
		{"8ab3fabf7256b4f7801db319046e25c2", -2474.171875, 1484.719116},
		{"3cc37fed3793052cc6e9164191c43ed7", -2218.171875, 972.719116},
		{"d667d43b0958f6f39c40edee82cb6198", -2218.171875, 1228.719116},
		{"4b3568f2fc03d87f73ac61c8b32853db", -2218.171875, 1484.719116},
		{"c9dbc73b5ca548f0041d24d416dfc03d", -1962.171875, 972.719116},
		{"b0e03ac1d0cd2a66b280b021838a1505", -1962.171875, 1228.719116},
		{"f25bbacfd2b19f2897b860acaf17c4cf", -1962.171875, 1484.719116},
		{"8125c328035d6f39b3cd6c176f1270b0", -1706.171875, 972.719116},
		{"dbef6d4886edd125a23642b5379328bf", -1706.171875, 1228.719116},
		{"d38056ed437fa1a9966a30e8580a6d6d", -2138.459717, 1671.706787},
		{"8032f17c144725f5c7d19cac01d8eb60", -2159.855713, 1742.217529},
		{"06e969cfac25a1466baea9b44046ac16", -1903.855713, 1742.217529},
		{"7c6e0c7b9ba93c353a0587776271c25b", -1893.307251, 1344.457886},
		{"e718ecb0aae477cd7772291028ae279f", -1893.307251, 1600.457886},
		{"d71e9484f2b8e185e07f87d258ca8ff7", -1893.307251, 1856.457886},
		{"a871a50208d3edbbc3312d1907137fe4", -1637.307251, 1344.457886},
		{"7e27b740de13c7c65d325633bbf76697", -1637.307251, 1600.457886},
		{"896c22dfe59c837f59a8a773de998924", -1637.307251, 1856.457886},
		{"c1dc8a2e0ccbda240abdcc6e5da25360", -1616.291016, 912.413635},
		{"75b698850c556b0c683e55aab348cec3", -1616.291016, 1168.413635},
		{"77b178e054bb3de7807b9d084750efc0", -1360.291016, 912.413635},
		{"ec3467e97b0d81ac9b58221686474fa6", -1449.262085, 1195.566650},
		{"71c588a1ee4adfc467a5290f961e2737", -1480.621216, 1205.969604},
		{"7d3c3d2593cd1523968da8d732efe05f", -1480.621216, 1461.969604},
		{"d83479a881e54856223f7e4aac457487", -1480.621216, 1717.969604},
		{"4d9b0867c9a6df0de2dd87995ef72621", -1224.621216, 1205.969604},
		{"13d7208d0f2b3bda2093d0b82695e214", -1224.621216, 1461.969604},
		{"fec77fbed23793782e01a80195ceea28", -1224.621216, 1717.969604},
		{"3c742b7d2848a1f9f1fcfa2a36bd0ae9", -1841.406738, 1792.329956},
		{"ea923dee22d3cffbae61c2c3af34680f", -1841.406738, 2048.329956},
		{"8b02b2e54bdb49f912818cbbf74180bd", -1841.406738, 2304.329956},
		{"a6684031c4289594be80f8c3a4bb758b", -1585.406738, 1792.329956},
		{"d808130bfab47b1be915f933bf3c9e5f", -1585.406738, 2048.329956},
		{"1ba32da0bd98242b95882b630e65614e", -1585.406738, 2304.329956},
		{"cf2074aca45ec763d03b6da18f9dbcb3", -1329.406738, 1792.329956},
		{"9310e720dae4ec7963465e55aa31969e", -1329.406738, 2048.329956},
		{"35b6f9691bc0de0bd762f3949151a682", -1329.406738, 2304.329956},
		{"f5e3a8e3e16f30289e6ac15ad06a7a83", -1073.406738, 2048.329956},
		{"b1e75e8743c9c0b7c09f0d42e7e8d8cd", -2329.312744, 1804.760864},
		{"138547fa1286ec4f8dd6dc32a807b345", -2329.312744, 2060.760864},
		{"5ba0ee2923e365167c4e8847c3e94384", -2073.312744, 1804.760864},
		{"efb965b210a81356152d00141adb24b3", -1817.312744, 1804.760864},
	},
	["Naxxramas"] = {
		{"a21e6a73ea91dffb57866bef5bd79e1b", -154.611023, 59.850761},
		{"9e370b0b1f3f90b0da0c62364ea5c615", -396.642395, 39.705143},
		{"5b100d59d96c7ca17b76315bc0e85fc1", -675.944336, -47.655979},
		{"f3d54064fdeb0984ec53b6e914ca072e", -675.944336, 208.344021},
		{"0478cb4a92d195a88acd59d0159ac6bf", -419.944336, -47.655979},
		{"70382a5364e6f79170e6cbbe42c39f88", -453.193634, 242.883301},
		{"1deb185281f9235dae0afc202c7541bb", -327.315399, 84.817993},
		{"d75c1c8559c603b99d53c5007f40fb1f", -787.793701, 310.743286},
		{"67c6cb8e6939aa29cf2f1acd8a5593c9", -787.793701, 566.743286},
		{"8cffdaf4093b55767b9f58a22b62d28e", -531.793701, 310.743286},
		{"66f36071a4c95b484d67ec42eb88da3e", -531.793701, 566.743286},
		{"184ada8b4a154467cd77048b3c41a071", -275.793701, 566.743286},
		{"c7ad09c44e53ea38eae65fb1d6346985", -232.792236, 654.755615},
		{"a27f110f0ef8d2754313161d32e1a99d", 331.510590, 75.912079},
		{"ebb7dfd90830d6eca4e5fea512a7344b", 168.712921, 163.682693},
		{"e0039d3092237195d804e5816f21bf48", 168.712921, 419.682693},
		{"28e2a270364b9e6c976c49ab1e03863d", 424.712921, 163.682693},
		{"81aaed0a7636eb46b3e3336a518181ce", 680.712921, 163.682693},
		{"8c5163993b4db2e9eb6f8e33aee0af8f", 153.524567, 612.090210},
		{"b00cd3b795ccf3f8c61e092bd70ec93b", 409.524567, 612.090210},
		{"ce689aca91cb0f535903be5def649e87", 359.640533, 405.505157},
		{"5c1f878f3db0dc5313170c983d389a6b", 72.915527, 54.900795},
		{"c9a9a5c37e30711783d0039d90af1ea8", 328.915527, 54.900795},
		{"50e57f5e830af824c98db77af68a2b25", 519.912598, 19.073938},
		{"8ee99730c5cd2741ffa3127ed28adc64", 60.411369, -385.684113},
		{"a7a43268441ccab076d07cf1678f190a", 60.411369, -129.684113},
		{"ead810f932baf4f320c91d5cb5896d5b", 316.411369, -385.684113},
		{"e160b83b25759b68cdfd68971401db84", 92.317558, -760.318298},
		{"78398df51008ab1fa28edd1ceb928f6b", 92.317558, -504.318298},
		{"ff39afdc45b8d0decd9e65880ac43ee7", 348.317558, -760.318298},
		{"f8bcbee1bcc407b8b4337b4279d61f5f", 348.317558, -504.318298},
		{"880dfe6163d0dede3d42d4d99ce6bc36", 399.121155, -722.145081},
		{"021aba0e807b2aa8bb87298020236845", 399.121155, -466.145081},
		{"cf96d2cb4678bc425e14e925846faf24", 655.121155, -722.145081},
		{"75b4cbfcb8d469e7eeeea0a75acb001a", 655.121155, -466.145081},
		{"828b21b48127794ee0cad777ce72c3af", 401.287781, -282.178986},
		{"de14da1387c99ff5a83855d10bd96d6a", 481.645355, -295.788666},
		{"f55abe82e771a2af4995f02a6f98af75", 481.645355, -39.788666},
		{"84d308ba3f47a5f1b78a609c324d69a3", 737.645355, -295.788666},
		{"06062a967de347f41fbf07ca162dc4e9", 737.645355, -39.788666},
		{"d7ed1a1b018b0988e18d25bcc9838bd7", -403.924500, -397.371368},
		{"636ccaf0f1f24bd466192d56eb7e6cb0", -403.924500, -141.371368},
		{"4a51c4ad062cb2d6a16caa26f00ff6a8", -147.924500, -397.371368},
		{"b51ecbbd26a78e9ff5baa6e195b6c566", -696.759460, -363.925354},
		{"f42dd7e6351800ef1db5c070b5f563db", -696.759460, -107.925354},
		{"18633c9e1c5575aefee9a604eec4cf87", -440.759460, -363.925354},
		{"598644d0592efb4445961fc25de174b0", -440.759460, -107.925354},
		{"9cf4e6a0a7ce3a3540786e8a1547c21a", -695.255310, -694.196411},
		{"b16614925e1b987c36087118bb2056d0", -195.428528, -193.522308},
		{"7980c293ceaa95094e2d4ccf82ce134b", -346.394745, -538.148682},
		{"861c8d0f59267833de48ec863ddc9acf", -667.642700, -765.667603},
		{"c33d9c1d8366c1062927bf601a7d27b1", -667.642700, -509.667603},
		{"254b9f60d30bd0814b14806bfa4d27d8", -411.642700, -765.667603},
		{"7e30aeb3a5a0ae47a1535f5e5558b301", -411.642700, -509.667603},
		{"1040f0f53d94d16bf7720cd578db6471", -155.642700, -765.667603},
		{"02b5173b9cb5e025bfd6714b3c3a9b6f", -155.642700, -509.667603},
		{"6145a30f1269475613a5cb5abd47b141", -1022.282532, 488.156158},
		{"a921eda818a9b30a84bbad89f9690bc2", -1022.282532, 744.156158},
		{"41b4cb70227d2f0a67d207970dca10d1", -766.282532, 488.156158},
		{"86da3eeeb5ef081e58f0dfeb159f7d72", -486.658295, 807.425842},
		{"777063349a7dbbd55a5dd3c47cbe7f75", -985.250305, 312.976746},
		{"406aa6995eca9412de6ac1ea6ace9a93", -752.902161, 753.004150},
		{"2317b747473841722cce21757ee901f8", -752.902161, 1009.004150},
		{"48f49447c89dde91e5bbe31a15fc8ffd", -496.902161, 753.004150},
		{"1659aa0ff378cfdb7b6b6d4902e2c4ad", -917.244141, 46.812584},
		{"66e8ea0510193ff1c177567693bc5f78", -921.430237, -0.055539},
		{"1ec95d425a1484a50ae2b76426484f3c", -868.147278, 639.161316},
		{"e80a1b7bc9fa42c0900c8f796472f49c", -311.478577, 767.089111},
		{"17e890edb04f9a041455798085047008", -311.478577, 1023.089111},
		{"26330aed2788fa5a12b109939ff001ab", -106.849327, 875.431946},
		{"4acbf33f96d65f182b8cbbcd1b3d97fb", -71.444092, 871.239197},
		{"aeb894578d1c5b04e8d687a6feddf2cc", 640.609802, -868.400452},
		{"f2ecd7f54f21a7367fb97ed13d1ee9be", 314.415802, -986.798950},
		{"8fc0567090b53d1254ea57c8edda5caa", 808.980957, -488.322571},
		{"fb997352b4e73da2b2ac987126307ebf", 754.541321, -754.557678},
		{"e1eadca1245be2477274932de713da3b", 754.541321, -498.557678},
		{"93e73396888fcfe75338da4e34fe10cb", 1010.541321, -754.557678},
		{"d6545a641ee5f7d87444125284fc3e88", 773.384766, -313.142883},
		{"29bd67fa5cb02ca010ea0f8544b18303", 489.595490, -1023.835510},
		{"605edd4e060aed97c533c5850d3244df", 489.595490, -767.835510},
		{"e98c3dc3173441be37ea32f56ff11661", 745.595490, -1023.835510},
		{"5ab9fcf81f3e0d3ec49b771549096f94", 872.791260, -73.108414},
		{"e63fecc86cc4ad9875855ba0f9548c0d", 876.984009, -108.513626},
		{"d4c84bc48ac6bb1933f9166e56a06361", 69.734177, -1023.794617},
		{"da6621d16b454937e767e3d07ac93b8d", -1022.275513, -872.450928},
		{"52ddbe75a2c6666a8266fc5977316ea5", -1022.275513, -616.450928},
		{"dc37352dea5fb7ac234d4e7a4bb6da08", -766.275513, -872.450928},
		{"710caf23b20a511f5c4191770590f183", -766.275513, -616.450928},
		{"022dd252d8d7861d0a0092078a538ac0", 69.846367, 767.089111},
		{"2f6d85f935129a54864b1051c286c26c", 69.846367, 1023.089111},
		{"1304d73bef2ee05bc64abe9ef8a75d58", 48.364559, 875.431946},
		{"8cd090522fff5ab408cb4a0981890571", 1.496403, 871.239197},
		{"35cd1010c5e94a0949895337e344ff6f", 872.791260, -0.110470},
		{"2ab56d40279e5ec95161171d0197e5cb", 876.984070, 46.700253},
		{"4ab6a4d87f57119c788f3ee0f3a03185", 1.441640, -922.982605},
		{"70b4fc4b54980324ce9039c2a05db8e6", 48.252361, -918.789795},
		{"0cdc974db1f138de5bfe8c47ef01a40f", -71.556267, -922.982605},
		{"75d2f4612121cbd3d84bc4dd34170693", -106.961479, -919.060974},
		{"db71a17a1f2381c008cda42b2ec5148c", -311.678589, -1024.059814},
		{"9b848e1246756723eaf7306ee59b7c4e", -486.774719, -987.116516},
		{"c3fecaa4ce5f044fae2ea79a11e4467e", -748.426453, -1015.087219},
		{"f72a54dfe486fa1a8ac73ad59eaac8ce", -748.426453, -759.087219},
		{"f798b3b1fe9fb04061849df6fafc8296", -492.426453, -1015.087219},
		{"40b5292e68d8311fa69950acedd799dc", -985.247070, -488.209686},
		{"6f2d0c4b843d39cb70820937f849cba6", -1022.336365, -313.113525},
		{"4846968f6762ca1aab25a3de7482dd70", -917.293091, -108.401314},
		{"1bc416b869db229881e62112e28fded1", -921.430237, -72.996094},
		{"ad0c31173106596fb8d7397d7fd5749a", -1022.287415, 68.294411},
		{"4aa939a7cdecaa1f98513d6df5e8551c", 758.525085, -1133.205566},
		{"b6cfb88ebf3e365103729e04b1ae445d", 758.525085, -877.205566},
		{"6913149c7501afa377684819a9b2afb2", 1014.525085, -1133.205566},
		{"cd4f579a0b3dc4551f9eede97b43f11d", 1014.525085, -877.205566},
		{"d15a509764eafc567f3b7c38ea5254c2", 52.385590, 1026.972656},
		{"a1df990fe42965985d079f84d8de62b1", 308.385590, 1026.972656},
		{"89ff0c4ac2d8f2f7d7234628f96e65c0", -1114.312622, 794.681641},
		{"cbcd3f08bee9070ee93fdc04f5c951d9", -858.312622, 794.681641},
		{"d4dce979c6716f462c41f72c93ae6d93", -1116.749634, -1117.476074},
		{"d9254e05a8aee0b57ef66494d18f3571", -1116.749634, -861.476074},
		{"16175e93d7a2ec7c905264d6b04c25e5", -860.749634, -1117.476074},
		{"493f2713fad21b2b962e7bc41dc4a727", -860.749634, -861.476074},
		{"e4f0cb99f5eb815b2e4d57b13e0bd67c", 314.528717, 807.429138},
		{"02829834c6bd874952407ef9cc8e73c1", 489.708130, 752.989685},
		{"83a6db2331b58bd1a6135743869859c5", 489.708130, 1008.989685},
		{"76f1b670cc832e3686f8db81d550292a", 745.708130, 752.989685},
		{"25fb88ebdb4c6f672186f31b692f514b", 640.713318, 639.058105},
		{"4e3d3f0248f603812ed39284e45102bb", 754.556152, 488.043854},
		{"e10bca21cc86d3265a8997bace39c896", 754.556152, 744.043854},
		{"2c7010e8841298ba80a61c718fc9b9eb", 1010.556152, 488.043854},
		{"e1da26ff971704cd3b76721f024e89c0", 808.977844, 312.863708},
		{"3acb752f54c1bed8ffcc89ac12961b05", 768.641418, 68.182091},
		{"9370ff3df4cf954a14ad4efc63d0c798", 1024.641418, 68.182091},
		{"f078a96db062d551d4b423a8e7ebadb5", -161.656937, -161.003708},
		{"23d956ebeeaeca5db34fbc7932df04f5", -161.656937, 94.996292},
		{"1b13251c3cdb8a318885ccebb955e2dd", 94.343063, -161.003708},
	},
	["Onyxia's Lair"] = {
		{"0ec4e3776a69543205175cd0b280bf52", 253.205460, 238.053818},
		{"5d9a286b286efbf1237c8c7f5b307104", 253.205460, 494.053818},
		{"2d2fef937acd1da861871a26f4b95d5f", 160.574646, 178.510223},
		{"2d3dd748b78dbff48c7648aa9c91982f", -90.243881, 25.429382},
		{"e585104741a872a0528376ba688c7a73", -126.491890, 98.720047},
		{"1c260ea8b1732da60781d4c88afd8b1c", 48.608906, 154.818954},
		{"3a050f110f2d5642a88085e80d169d5a", 3.496235, 170.429382},
		{"e1799bb921554c95f56c65e672d267b9", -118.283951, 284.699951},
		{"cf09373273d90bf8be9b94fbb3ecc2b8", -118.283951, 540.699951},
		{"b31bd8a0e3438610b400088bf9e22011", 137.716049, 284.699951},
		{"78397ed5982e6c7c14e68fdcca735860", 137.716049, 540.699951},
	},
	["Ragefire Chasm"] = {
		{"3523132a1041d185d639491fe5ddd5ca", 133.193054, 9.382098},
		{"6ecaf15e41a190e577e25736f66c36e9", 262.514069, -98.339828},
		{"d7856cf8a6b8bf3c092908647725c853", 262.514069, 157.660172},
		{"405a610dc692a9072fe23a1c1e03ede5", 518.514069, -98.339828},
		{"e533c2164f3a4647d2a4686195a6ae52", 518.514069, 157.660172},
		{"3c43c9430cd4720ca97230922aa9ed45", 126.778221, -213.711731},
		{"c58e820d9547879a8357da904284f356", 626.517517, -550.758118},
		{"f50de18124de7c6aee554bc12f9cb16f", 626.517517, -294.758118},
		{"52cf8181be3dc8c07113f51456459d45", 322.827240, -532.126404},
		{"c6af1528cce440fbb81259cb80904961", 322.827240, -276.126404},
		{"7e0ca17a3229d30d88e63a5e9c85462e", 578.827240, -532.126404},
		{"bd6125ea09443982575bbd6a6b8fd39f", 578.827240, -276.126404},
		{"587db365eaf3e1d9d7967c5e689dee3f", -177.524628, -125.734512},
		{"7ab8cfb28914799b552932d2a7b0a74f", -126.075981, -376.497345},
		{"fcaf3a4518800d214917e7507df7ffb8", -52.245319, -372.508850},
		{"60e88665de38422620d2574fbe3757f3", -194.923798, -319.508362},
		{"887cb5b59f8e6ff68b293a789ecfd510", -205.911331, -167.370667},
		{"670257610f8dc0445dc1ef2f6da2b0c4", -198.651489, -233.210297},
		{"237342a76300787dd953aad0e856e240", -33.427898, -15.771896},
	},
	["Razorfen Downs"] = {
		{"2db384c6f58491ad9c66d42137e0755a", -433.710236, 238.130615},
		{"2a3d7003b9a4099516cd11ff2aacf9a4", -99.587128, 184.566010},
		{"427b4f034220a8f340903466606722f5", -99.587128, 440.566010},
		{"98a8931b354cf395fcada7023af829d5", 156.412872, 184.566010},
		{"20d1024b85232ce76dd3830caf79a73c", 156.412872, 440.566010},
		{"7c9213bf33fe3f16d3d5f9cf93ad6383", -433.380310, 405.724426},
		{"f5803a96c22b7f00660c25b7772f52ba", -214.798920, 599.192627},
		{"ad05baff3171a326c4ef07c219c8f405", -214.798920, 855.192627},
		{"0348c56692aafd4bd075ebec7ce0d6ee", -282.027374, 909.962402},
		{"e06672c5a361b249390ff972b80bb57e", -282.027374, 1165.962402},
		{"b5474c9d9b711386fd15c80dcd921c48", -26.027374, 909.962402},
		{"9adc2a2d33b087b18912aba3019fea0e", -354.749573, 540.740723},
		{"ff43f1a5adab24e7bbbdde623dd480d1", -354.749573, 796.740723},
		{"1aa67f4d9d72a04f8f02bdb61d187540", -367.428741, 768.598022},
		{"1f680b23a689e16b29923b723f613149", -367.428741, 1024.598022},
		{"9bc59035c9dcd9ff109b3f76e45c6f21", -111.428741, 768.598022},
		{"005eecb5eef57549068829143e8aad28", -454.791046, 826.193054},
		{"c4b8932a97e6074a82afc11bfde9bcb2", -436.687592, 170.045029},
		{"3cc0bce6682d1ed6fb747fe829c1ecff", -293.057648, 137.738251},
		{"00d68f71bb8ca428da34d170b4d0bed4", -293.057648, 393.738251},
		{"627d1b646b72cb3ddb1e5f0520c37c7a", -37.057648, 137.738251},
		{"0f9f24929a6f2f7a5085702013dbd817", -37.057648, 393.738251},
		{"55b8d997f024b48bff7544f5b7fdfab9", -37.057648, 649.738251},
		{"bc95b1dd9c1d00907a40941f9f32d98f", -306.508026, 250.736084},
		{"897ac41644d7eb6e4382f4dd431d9a1b", -306.508026, 506.736084},
		{"b7d5c17cd9037913f864005dd6b3c3a0", -50.508026, 506.736084},
	},
	["Razorfen Kraul"] = {
		{"a0266795e6e768bfd823632ccfcdff4c", 305.609802, -404.831299},
		{"b41ad8ae4d91d092eaa09b92fb2cbca5", -51.962009, -124.959717},
		{"0e84589543ba58c616925a5b751d62b4", 306.520081, -210.849701},
		{"300b467132496f0e800b85c0d8e1fe47", 709.560791, 220.553497},
		{"c70b32721c4219747aae7c61ae050c28", 714.136169, 112.129295},
		{"8207ebed316a9913b2959c6a201196ec", -90.800758, -574.078613},
		{"bf8896408a8bd54632bedfc4cfd2b02c", -90.800758, -318.078613},
		{"082a565a762054988c04b41c2302082d", 131.012497, -526.613770},
		{"f4377a4b9bd7bdaa78061bef0c2aeee4", 79.233261, -223.492447},
		{"409ed41a2b67b31b87dd4f3ad617f252", 335.233261, -223.492447},
		{"d08d20b01f120c112becb84a34d6315d", 137.346390, -52.443611},
		{"f326e8220a2e93376fa57b2bf672dcf0", 246.278290, -62.483265},
		{"e3474d45570b628149a9af3a644013f7", 439.837769, 124.067505},
		{"19741de50c745c2aa4f6b2a635b37de5", 600.758179, -79.158546},
		{"14baed26b20e121ef32db085e7c79937", 446.705688, -39.138187},
		{"b1625d0d2e28d495c40f6ce511dc4753", 446.705688, 216.861813},
		{"1c12ae78969dbaa6aa55abf3e2280def", 702.705688, -39.138187},
		{"50db950f198e39c8749191e9824949ff", 702.705688, 216.861813},
		{"72dc29fa8b735ff1569cb711ba868249", 604.911011, 432.898438},
		{"891a82258bec719df22c5178b377c413", 653.720215, 148.471756},
		{"39724c5244ed0112c3ac66ea5366bcf7", 567.930115, -124.202316},
		{"3abe03ad2ab4744043865e44ca41d438", -70.836426, -239.538010},
		{"5cfbd76dfd99f1aeb211026946cc8faf", -89.838547, -62.719532},
		{"537e4f6b9a2dd5ddb2d8e6eaf579e0cb", 34.578396, -570.911499},
		{"8ecd9c1267b79ab6e9b95f92a96e0f7d", 91.174019, -328.088379},
		{"1c76f6050eca9f5d63c9e602d86e872e", 175.933990, -316.872864},
		{"b8bce3826bc7c6584e55c4ba80ec72a1", 242.967499, -274.013397},
		{"5b23d111585e098710f83761b78178ac", 357.644989, -141.290054},
		{"f01d2b56d8b06891c6b67949bf72be52", 357.644989, 114.709946},
		{"26d83d77b8f3feb47c6b4aca9062b935", 600.804138, 202.453979},
	},
	["Shadowfang Keep"] = {
		{"b12cd59348b2073437b17c7c446fcb12", -215.734909, 28.199944},
		{"2dbb61a864e6ae450de207e16b7d6965", -128.051697, -64.027542},
		{"85c9fb62a3c653bc8d27e72edbc8075d", -40.620079, 17.630421},
		{"d4cc104e16ef91cb0b18c663f60de85e", -406.401337, -107.060371},
		{"04ac7a8cbbd12f7e80181282a4fd6f4d", -406.401337, -85.193741},
		{"211643b6c2679dbb0c7d043d00f7b5c5", -406.401306, -63.327122},
		{"9c0ef2851d104639b109acdebe5570c9", -384.535034, -63.329342},
		{"5b6ac74d4a2cf5f6c70ce8145419b3d1", -358.779358, -63.332832},
		{"cdeba07140878010dbd07e69b21318a9", -198.228806, 28.199944},
		{"1a648f7fc529162dfd5fd6f5d1e309cc", -215.734909, 45.122829},
		{"b18de18ac013afb588f78be213a058fa", -198.812027, 51.214607},
		{"3ab610b39ad279876864e5f2086918bb", -113.503418, -32.005486},
		{"11d6d5d160011dc8dc8ad609cf23932c", -113.503418, -22.716869},
		{"0917e6258967dd1ea5234e73f50d7e4d", -113.503441, -65.117722},
		{"fbb51092345d716d8ff0b5dd87650784", -84.656944, -69.853584},
		{"ff2c23298e684f07cda7880fe53e0e6f", -52.533722, 26.990248},
		{"80df60c469959729ac27fe6d531e49c5", -124.494606, 7.961989},
		{"efdbc5d4cd053a2fc4f23de84402d365", -52.533714, 26.272644},
		{"b78977f05835cc9e1e96354efa4692dc", -23.892281, -39.940262},
		{"5e714ae17f194b5d911bed9402bb39ad", -369.619232, -256.104034},
		{"115a735deb7f86e811561a634b2ef587", -419.540802, -234.237961},
		{"0f6a45cd73840f7a3611d0dc6c42749a", -358.778473, -277.974579},
		{"2e8f86b5b3936545259aa4ac46b47658", -336.911957, -277.974426},
		{"e44d40ee48000f5356810e0e8b3f3dfa", -315.046600, -212.372925},
		{"631550a100f529a781bceb4011ac41f6", -315.046539, -234.239594},
		{"ac569ad66ff489d20b2b5e341e747b0c", -315.046539, -256.106201},
		{"54d65a72bf0cf31f988f94d98bbbc2b4", -315.045227, -277.976349},
		{"f3bb78e5fa8f3bc7b249913117d6f2ab", -406.399689, -256.104553},
		{"8ffef88c55961bd2e39f5d49da26c5d1", -406.399994, -277.974731},
		{"5fd17353200943c1d74f53a8c3af80e1", -384.534241, -277.974426},
		{"36ac7ba5f3ba64bee57a411215862dd1", -315.048706, -190.506317},
		{"f8f43c88f9e4170c2bfc8eca07ec2ec1", -309.101471, -168.638092},
		{"5d6980bda32fcffc4f2b4fcd68f486b0", -259.609375, -140.630539},
		{"af0969f6a482482ee655f4601e3560f3", -254.445557, -136.490433},
		{"6f06727225051668f69be01853930320", -255.542999, -119.831978},
		{"f83484c385db23894934311ce0a7dde4", -253.346573, -99.672356},
		{"014b359f335ed1c84bb60d166374e9b5", -267.577698, -110.469742},
		{"91d01347719deedfad53c659fb804df1", -150.136627, -71.522575},
		{"06645f1c8a6bdb2bd7c3cd913f5c306b", -246.329193, 144.607376},
		{"fc456cb1f867cc98b62f531edc613370", -216.764816, 29.642120},
		{"03722bc40829c71d0a08b2432a4c7de5", -227.072083, 16.191595},
		{"c344cc495e9e48a9e207d15923a5be29", -227.072083, 35.213524},
		{"c3cb943ac144aecb5338af3a6a83115b", -227.072052, 17.684469},
		{"b2459e9cd212587f6e2b2fe3d723b5ab", -225.579208, 40.643345},
		{"7f572cfb005f1c36b9b93a27a6824c61", -213.621552, 16.191603},
		{"c60660e70d7148854dc6300e34477b7a", -246.329193, 144.607376},
		{"131792e1e1b401839863d574eebf8738", -272.733673, 125.508667},
		{"392e087edb82bf8df20c8b12d9f8c527", -279.319061, 86.997292},
		{"1b7e4d2e2794dd1322d5ff82b5785cb0", -276.361877, 56.787273},
		{"ee7246f7354af3f970c4aebd4daf2d6b", -254.413055, 45.248062},
		{"8b32184a0e7c1ef97c6fe6b469307883", -272.733673, 125.508652},
		{"1046ed7c38f6dfe57cf3666bec4a779d", -279.319031, 86.997299},
		{"0fc830a5c11699f052e06d838ef2d4ec", -276.361877, 56.787273},
		{"a97bf3846b8d1f6ca6e943c93d2bd1f2", -254.413040, 45.248081},
		{"0769d6b072a7080af00d8ef81cab505b", -248.974670, 61.970627},
		{"c0d1dcc2c82be9014509b6d9bdc9b1a7", -245.294159, 169.509232},
		{"912f27cc89b2249db807d0482f0c4608", -244.373993, 61.970634},
		{"7c181a617156089dd0512b428ad9498a", -360.899841, -101.367569},
		{"a5fc3372fcb147feb793c7cf037cf153", -318.965668, -20.448267},
		{"0a53f1342a30c0c7d6239d329e1361b4", -304.274231, -121.633316},
		{"feeae215bba2e3fc19de381535fe1635", -374.814636, -231.891739},
		{"c30ca12967d35ea4a678efa0cf87577c", -436.218079, -168.675232},
		{"ad0c1317376fe2940c60aec50c3e57ac", -335.569611, -132.722275},
		{"5fd7d8e08f4ba7c43d862c6e1a80cd92", -315.583832, -157.847260},
		{"bef8aa1552435c1fbdc875f2c7725cff", -295.598450, -182.972748},
		{"31716c6e1a4df355f05c3a4bf9d1c217", -69.225662, -96.947929},
		{"dcf7a693a03d074c7dd32d10ea2db206", -74.761894, -106.471107},
		{"1918f3276d74fc7d14977a0c2f33bcf0", -100.527267, -79.121841},
		{"e3cac2d08b086a89442da8d33aef1a6f", -30.191067, -77.468658},
		{"3968e39092ec496f27c6686366dc83fe", -253.277130, 62.341030},
		{"5ed05b27c638f2890ffb313090e8d674", -351.486755, -82.249626},
	},
	["Stratholme"] = {
		{"e6ee3a98aa0a4fe209d6178f6d061fda", -632.599915, -131.798431},
		{"4d370bb78d215c7e10d3a8c19ac5acd9", -632.599915, 124.201569},
		{"9e636054f8cab44c1085651a549e9276", -376.599915, -131.798431},
		{"c6ff9356b3e94c89b17036764e8d9dd4", -585.513672, -259.387512},
		{"1b706b4f013ad1a6f81be407b4d51f4c", -329.513672, -259.387512},
		{"51e281f86e5773caf844bac8544601c1", -566.262634, -164.369675},
		{"ea3e85507ab1ad8f1f115040ed5fb1b6", -310.262634, -164.369675},
		{"6248dc343d0d37f7c30c6976dc8f67ca", -632.751343, 52.490891},
		{"bae4d285cffcc103dca3d0bc1902c690", -655.937988, 53.416866},
		{"a5a454e41c9b4d46d440238af86db909", -622.765320, 75.076599},
		{"a97e29004121843e7815da50df9cfd36", -622.765320, 331.076599},
		{"a731461c65eaf0d7d95a89607afd2750", -366.765320, 75.076599},
		{"a82c87d0372fd0cc18d05c1d3a30f02e", -366.765320, 331.076599},
		{"b62b296ce5d68e2e51f2d4e7fb14e162", -469.333130, 91.368904},
		{"abe555087463282ccfc82b56cdc34258", -213.333130, 91.368904},
		{"60e712ff9a9d15000b60d6df7789ec6c", -469.333130, 89.009995},
		{"99c8f44a945eb6ead71fb58208fd014b", -213.333130, 89.009995},
		{"0f04636038f8ac7f19e3f9f20b971c04", -566.262634, -261.269867},
		{"9b30b53e8c3b3f9b59855423ec538bf6", -310.262634, -261.269867},
		{"68fc7fc4815e836da864a67b75ceabf6", -310.262634, -5.269867},
		{"847d148717dd95adfaa0d0d1c63dc6c5", -566.262634, -164.369675},
		{"4db112d390b06e1920710272bb8c5d08", -506.301117, -270.509827},
		{"97f40f8c746a0fed0c468157b3f9aaa1", -355.773987, 89.009995},
		{"65969b6e0763eaab6bae0fef61383022", -511.850037, 205.007751},
		{"c246aad554fb82b198f124d213a5aaa1", -699.361450, -9.967423},
		{"7c9063f6e02aa017856dc390a988c3f6", -632.751343, 65.080330},
		{"dcb9512c4af4b5accd62aab6ad43b197", -1101.816284, 505.188995},
		{"827eb327cf9379d9a58af59a1bb7271b", -1107.976807, 441.781738},
		{"5bd757c7979774a32003a94404634b09", -1107.976807, 388.055573},
		{"eaf590054552a9a691b35545bee0507e", -1110.495850, 157.298660},
		{"63dfef64e6edaff90bbd3d7826792e50", -1110.495850, 270.479034},
		{"719e00cf068d039e0988aa16d54e9b6c", -1176.967896, 282.583435},
		{"5fabb032e64b90d920846ac05c315671", -920.967896, 282.583435},
		{"822ee13ae86b0ee40f9165b16be96da5", -773.198181, 391.782196},
		{"e89a3846cf18d9d4ea04a07d8f6cc7e6", -846.970093, 365.622406},
		{"040bdd264fb059837a314753620a5b09", -773.198181, 405.093567},
		{"4e05b27bb6a8067513b6b6831673597b", -1401.057739, -210.559158},
		{"ac7f7016e904388180a3a5c8d006b90f", -1401.057739, 45.440842},
		{"6a0f1ec190e21665a36b12672f475e95", -1145.057739, -210.559158},
		{"dbdce10f160202b2982e47dece347354", -1145.057739, 45.440842},
		{"de92b0e874d46a043f67bab910237fc7", -1276.258545, 199.204178},
		{"17d45c2232bffbd800593afe52c61099", -1110.495850, 77.880554},
		{"bbd9350012bc213f95f57558dae7f1c4", -1110.495850, 333.880554},
		{"f1967bdfe14486d3289ceb4b74fd038c", -854.495850, 77.880554},
		{"1922813213806c32ad923e1433f9ba10", -854.495850, 333.880554},
		{"8235e212a2b76b774c54c1c56022ff39", -1107.976807, 277.815063},
		{"fe8143b5083ed9f502d7be1d78ba3e58", -851.976807, 277.815063},
		{"15ab9b01dae382d835d404661bbe4cfb", -851.976807, 533.815063},
		{"c5599f06e1cff779ea66873bd40bdba3", -595.976807, 277.815063},
		{"447b1fc3b6612711de47fe9db7b819d2", -1107.976807, 434.358582},
		{"6c91921f0030df0d4b099d9fc976b77d", -1107.976807, 690.358582},
		{"5fe2d8ea942de72ccb31887a8d52b0c8", -851.976807, 434.358582},
		{"ff7c2dc13521c53d5f95f7a638ac9718", -851.976807, 690.358582},
		{"6ea35f4472ee79b802d3151a02b343ac", -1354.184937, 374.848267},
		{"96e481c561fce432c83b10901265707c", -1354.184937, 630.848267},
		{"6627ca5b7e46155acc03cd77e2d04ed6", -1098.184937, 374.848267},
		{"5ad91659b782d183d734499e7eb17745", -1276.258545, 216.356873},
		{"317619ea3c02b6677ddd29d9fbcc1f42", -1020.258545, 216.356873},
		{"56efc969ee776cb09175208cb5f2d0db", -1328.812256, 205.906830},
		{"4c5ac300e4389aacfce92d5c113b6f81", -1150.975220, -467.419647},
		{"116c455053a4c878db30c585424b6366", -1150.975220, -211.419647},
		{"919a55ba9fda3bc59e1033c28b60974a", -894.975220, -467.419647},
		{"a8e8d03e76beeb2dfb2cc61205c89748", -894.975220, -211.419647},
		{"69527debe7487c00c54f840fb8b35ba0", -638.975220, -467.419647},
		{"dd3fc21c585d74d31596e04e62bcf68c", -1026.026855, 12.805107},
		{"032cf5d11d4c24b24e0957221ea57087", -1150.975220, -126.306076},
		{"da0603d29dced9648534912edbfc6465", -894.975220, -126.306076},
		{"85dc8afc90dc2379c9b96342eef88761", -1150.975220, -55.835701},
		{"4a9d6ab794d2a21fc092c5ee3d24107b", -1150.975220, -70.514137},
		{"7389fa6d6b26761f27bf6f48478be0c3", -1150.975220, -63.046612},
		{"85c1b1dc7b1859fcc7081c6836517ba5", -975.953003, 15.429086},
		{"c2bb58c4863c300b2d64b8e28b0d1a2b", -1150.975220, -77.880615},
		{"1ca42c6abe4c83ca8773b39c55c74864", -894.975220, -77.880615},
		{"64f452dac6ff77030212903cb2161fc4", -145.450317, -78.400223},
		{"4ec5f7747ae254348ba001d1359a21dc", 110.549683, -78.400223},
		{"cc3e449a402964f740a7707a1b72c5fe", -145.450317, -78.400223},
		{"39236f79c3f138d159f97c0580269f5c", -591.101807, -630.388611},
		{"91d0c4fab8c644db7e622765ff39ffc2", -591.101807, -374.388611},
		{"1d3988a1bc5f5d50b73ad6b5e157899b", -335.101807, -630.388611},
		{"b2c92b55404dbdcb5b63b867932d9b14", -335.101807, -374.388611},
		{"c9c2adc75d4ad2ef2e1839229c096cc0", -518.423523, -497.104095},
		{"75167cd7886432d85435e986dac60d85", -651.872437, -330.845581},
		{"4cdef6083aa32485eb11908033092032", -395.872437, -330.845581},
		{"10380682bc4919c2121972e88fb72203", -572.845886, 396.658844},
		{"835f71d5de7ba21c703ba12d340ee989", -312.713654, 533.991699},
		{"4e07679a8a8b52a3013ab006b6f3045d", -466.209656, 450.847443},
		{"6941d8deb733280e94f8512d0c012e52", -466.209656, 450.847443},
		{"81e44fbe02a4d269c89f4ca94d807bed", -466.209656, 450.847443},
		{"0850f6d2d88f78a315cf2702ce2885ff", -319.487579, -646.160522},
		{"00a8a44fad570cdf12237d178396bbe5", -408.131317, -567.441284},
		{"11a98a15d567df7fc2e2cf667030564d", -435.442017, -584.364685},
		{"20bef307f01d0cace6a9d3eaf75a8479", -473.154388, -536.371033},
		{"203de6531810354b3e4599fca02aea4f", -414.528198, -630.059937},
		{"16be330f05bca51c749ab34c7bd14981", -353.863953, -529.581177},
		{"ad3721aa12517b632239d8f972755deb", -272.204376, -667.739319},
		{"2f119c8c0a28a45e1c7703734aa51def", -240.222717, -647.423889},
		{"f004d394bde02a8fc586165edddd3c11", -215.228394, -635.641663},
		{"41023dba46aa98a7b312cb10d4b5bd01", -935.050537, 601.174927},
		{"2879219a9392b88fa9feee103ead20b8", -935.050537, 601.174927},
		{"a67116960070d219a4cbb08100573ae5", -919.880005, 99.677475},
		{"b5ca259bc111246ec3ca3dd78431acc0", -1005.361145, 99.677475},
		{"6d8506185ddef97e089b134a67270dba", -301.246552, -261.269867},
		{"84aa6f6669088e6a934a3ee14d23a736", -301.246552, -5.269867},
		{"957fa65e8d595a7436779e4226f4c53e", -45.246552, -261.269867},
		{"9e01bf8073dbcdd06185ae5e5b776d75", -45.246552, -5.269867},
		{"a82437a8f013e11c3f51cd6105646b67", -355.773987, 89.009995},
		{"48c5609c0ac50cff2ec8c4c86785247e", -99.773987, 89.009995},
		{"dff6527238d6f1475f54f408bbbf574f", -628.356567, 331.234192},
		{"32562016a290854faa84d1ae4d8f319d", -628.356567, 587.234192},
		{"ef974ab7ea268c4901f3203a718dd653", -372.356567, 331.234192},
		{"213e61f4a80f6a1db5a34704e2e1da13", -372.356567, 587.234192},
		{"ca8fe35429a05351f9c35dc058a4f2a9", -773.198181, 259.872803},
		{"97d23edd7f1d2de48609ec666a2093b4", -897.095154, 156.042068},
		{"2a152cffb005c4a5a79479e95a0e23a4", -893.837219, 719.348022},
		{"37e38bb61cce8098603c3e1bac5d76b4", -588.614197, -545.792786},
		{"5f49d00b5b120aad08410656ed231d5d", -588.614197, -289.792786},
		{"b0bd3e0e03dc73934aaedddc15954a25", -329.833435, -396.064362},
		{"d97cc930db73ac8a790f6957e57e6343", -511.850037, 355.615967},
		{"06c4e82f60bfb5ad96f2383cbdc7f1a7", -1354.184937, 441.330994},
		{"586882efcf4a8a2071c6d445d8ed1d05", -1354.184937, 441.330994},
		{"bb9656f4e9a3813488fa821ec5c01aeb", -1233.406738, 556.909119},
		{"6ade11787cf7c2a231874fcfdbcec134", -1374.098877, -110.557854},
		{"b916dfe93096e48b913207015ec79cce", -1118.098877, -110.557854},
		{"4e9bda7e88c2c729734f090922aa31e3", -1374.098877, -67.298882},
		{"23350975d3bba574e81475058d95dac9", -1374.098877, -67.298882},
		{"772354b64b957581522e566ee9199582", -1374.098877, -67.298882},
		{"5a058c766ca203446beb102bde0b610d", -1374.098877, -67.298882},
		{"4d433304af28a1d9cf15109d59d4dfe3", -289.827362, -902.836487},
		{"fb24b26a57bcde2cd8aa125b190eed2b", -237.216263, -702.754517},
		{"8e94cefed4dd6cb48da7877fdedfdcc4", -32.459118, -567.180542},
		{"c837c1bf1f94746b4177e468e70827ef", -192.006851, -676.653809},
		{"d7ad3ddfdfad0ff5794bdafa5e6ee430", -159.274353, -655.847168},
		{"4e475fa642aff5a5e1b4e73626982672", -134.321869, -638.371094},
		{"8513d5f9e5df0d1dd31afadfa169e282", -109.361526, -620.893677},
		{"b2cf3c057e7a64ddc0c64620a86d26af", -93.123466, -667.659241},
		{"4a68d37e4fcc28877657e8b4eb754d1a", -68.631157, -592.508484},
		{"33f8ee87b60e310286daa2ac1d6c57a6", -123.960396, -586.561646},
		{"9c2e6d348dc8f487b228682be42f7a71", 4.829518, -693.856384},
	},
	["The Blood Furnace"] = {
		{"b6c78c2fc7b0dc9b9663f601e0d49c36", -1023.845581, -301.778625},
		{"ee4966266c5a8908b16a518d758d5193", -905.057190, -81.545135},
		{"61e1a497f3d7aaa2d1436eeb336675c1", -905.057190, 174.454865},
		{"18529806e1800081a1b892cea579f10a", -649.057190, -81.545135},
		{"50f75b79d1588a08e557b2c7cba41544", -649.057190, 174.454865},
		{"cbcd72b149360812d270ce5c95051569", -393.057190, -81.545135},
		{"4786343a3ec3c5ef6d40df182c1972ed", -393.057190, 174.454865},
		{"ae0f936633d5c05db265b0ead8255943", -382.874847, -48.861145},
		{"b4ee31d3fd5a41687041937a0617f86b", -382.874847, 207.138855},
		{"2ae200ade417820cb4022373ca11bb87", -126.874847, -48.861145},
		{"6d2cf0817c91a46196809ccadfdbdfc9", -126.874847, 207.138855},
		{"abc4540bfdf89fcef06ec7e08ac50f49", -1040.629517, -65.678261},
		{"a6f111e8c580bfa79657a9696ab85dbf", -1040.629517, 190.321739},
		{"4ac0d258b4165116af2ae9b15a561955", -766.401245, -324.939178},
		{"31befacec677db25e5c1eaca0b5d7e0d", -997.287231, -426.720459},
		{"972cd92849d0095ccfe622abebb5b081", -741.287231, -426.720459},
		{"2fa45de4485b0ac938cddb58c84f7981", -1106.271606, 114.557320},
		{"796546a69f19eab4728f7d8920399f67", -882.168884, -88.877373},
		{"466ad6729e861d87397ec2ff09d7a17b", -882.168884, 167.122627},
		{"8fb786e4c08b7a1ace2ccfbd46830715", -882.168884, 423.122627},
		{"d52640f5ad0b071f6e108ed203add7af", -626.168884, -88.877373},
		{"5781b553e9b260069040627e2e6fbdc4", -626.168884, 167.122627},
		{"5de218a3d0f2866a75c78f50c1a71dda", -513.149414, 97.045982},
		{"738c187ff3304579fb62da2c7c72a7e8", -478.704681, 224.850296},
		{"a40e2022767ca68363cbf35738cfef91", -222.704681, 224.850296},
	},
	["The Slave Pens"] = {
		{"914c16cbd752d4e2b4d54a57563ed760", -310.163116, -77.868187},
		{"d0e31986107e5611e9921ffebed7db29", -310.163116, 178.131813},
		{"ebef13e5c936c743705400bfad80b698", -54.163116, -77.868187},
		{"72476667c20c96edea8c170095bdfefb", -54.163116, 178.131813},
		{"d96d8b3de8db1182a19bd6d54a621bd8", 160.364700, -16.365501},
		{"12423ed74f986ecdc1b801ecd621c378", 243.271408, 1239.613159},
		{"4db80e871119d22a537c305ca75be258", 243.271408, 1495.613159},
		{"9651b2d9e2e08aec180a11f3071c4cfe", 499.271408, 1239.613159},
		{"904943b1656b6d28a98cd2816663938f", 127.031219, 1328.282104},
		{"463a5436d1b1a4cef34cb1e39172a7c4", -303.798645, 176.031372},
		{"8461fe827f4c7fc53d408a72a9113e66", -303.798645, 432.031372},
		{"6a921612f5b80e719e145a38c85680cd", -303.798645, 688.031372},
		{"f02b5fe7ba8194b15c5fb278d916a85d", -303.798645, 944.031372},
		{"f36cbbcfa7e3cba2e3a16503494c35a1", -47.798645, 176.031372},
		{"302bacf4f47d967980313c65a6a4d3da", -47.798645, 432.031372},
		{"4454cc381e32995bce3e7a8a5981e40d", -47.798645, 688.031372},
		{"f9e6c0de0475015d160a129e08f6bd15", -47.798645, 944.031372},
		{"65e8749c1e32eacc77091b769aae09f7", -47.798645, 1200.031372},
		{"a5a0c63aecf360fca48809470e0270ca", 208.201355, 176.031372},
		{"ce5a4601263e7130add0a3492694c0f9", 208.201355, 432.031372},
		{"5b353e3a7407dac27a820559d9e33a47", 208.201355, 688.031372},
		{"b8dc5563d87117d76c6655a256388843", 208.201355, 944.031372},
		{"7b56d58604ca36e3ee8aa30d157e12fd", 208.201355, 1200.031372},
		{"17d1ed72497a0b5de5871106d947dbfa", 464.201355, 432.031372},
		{"9d268cdd050d431d6039faaf6530c3d9", 464.201355, 688.031372},
		{"b8b4b04bcb6155b17e296c98b126b86b", 464.201355, 944.031372},
	},
	["The Temple of Atal'Hakkar"] = {
		{"cbc9c2cbea998eb3e49040b1ff16c066", 815.845276, -648.192444},
		{"8625883de0f4d32450d5959859d5f12c", 1225.039551, -73.737968},
		{"09d5c27328fff7e5575dcb82608bf6ae", 834.261597, 75.220505},
		{"d7e8211345562d5dadb89f21b4264453", 716.583984, -299.173370},
		{"04c7aace77f6fa892462a10688eb0856", 719.388123, -194.269501},
		{"159b6a0ff16e32e75e81889be6341c2a", 751.175537, -102.808815},
		{"caf427162706bf791452882eda8df553", 827.091309, -36.244389},
		{"03d88d81e4bde67d354fb5deed1cfc21", 931.953369, -34.540539},
		{"ababbf7dad288d4a90b93f4a751ea857", 1023.391846, -98.630943},
		{"10a7ad38cd0bed99a421469c454d9c36", 1091.289551, -188.590683},
		{"e298933f5ba35368cb427f0243ba5d92", 1089.061157, -295.019165},
		{"e704feddd21e8bb292d973c70611ff26", 1027.580566, -374.667511},
		{"22b267c652ba95e75afad9095d041a6d", 938.772278, -405.898163},
		{"6ec7c09f8bf7bd108130b16d954a2836", 831.276855, -405.056854},
		{"3c9b4616aa2bafcff96b57335a79a37f", 751.551514, -374.995056},
		{"8888731a3a53eaadf8c1d9d2b9847448", 711.298767, -294.081909},
		{"7464a5ec38b8698e5912c8d21aea556f", 718.867920, -186.519424},
		{"a135fbd009eced8dd1c835e6901742e4", 749.277832, -97.704521},
		{"ceafcc2d997e5bf55942fc4e1858703c", 828.926697, -33.549198},
		{"8d4d4b57276b9bc3bd84033b3229921b", 936.604614, -33.993641},
		{"8de515e748f23d0538008b4840e051d2", 1025.085327, -101.897972},
		{"2c37718c52360e0a444d5824901d5120", 1089.403687, -193.338318},
		{"6659ba029fa4be36c6749787e119c6d6", 1088.957031, -298.200531},
		{"eaf5485c6825c8e534eda3960c55570e", 929.676697, -404.010101},
		{"404feca9bdffe3a8a7d2c6d203dc0d08", 824.793335, -406.091705},
		{"af4d71925e65ea8d4ea02a13d8434290", 748.951050, -373.749176},
		{"7121bb5b2593a9b6c0809be24f1be2e2", 1021.135742, -374.112946},
		{"906df5ce6246aba886b9acbb3e418be4", 675.386414, -304.927490},
		{"2847e436baeb77d7a19e8184120204b4", 713.195923, -59.493134},
		{"765435d5ce34c0054b76b0ea60c72fbe", 1134.256348, -142.970123},
		{"060830deea29611b0f3b2d0fbbe7d725", 1086.745483, -385.213654},
		{"27422d6b7d0bd703fe8c49e020c61c04", 672.309753, -339.861328},
		{"9e85a5ccb27bdd2c39560aecf0392c2e", 753.148865, -362.888123},
		{"a8079cacadbddb726c037369c317d71b", 641.361084, -345.844452},
		{"bdad447c40eabc11a2d1c0a827b12353", 692.667847, -306.167114},
		{"0042ddb2ce7fbc616d2be1062094a346", 709.755432, -275.232941},
		{"6ca354fbb2ff15a912182f0d7c4a28c4", 672.443787, -270.344910},
		{"ce560c8be88c74e99792957540e83be6", 814.907715, -336.106049},
		{"0d4f9a8e1c94b576ca3bec7afd0b74df", 802.374084, -311.031769},
		{"f5e6f9ea6bd78a2bc3afe09479af9fad", 764.128418, -185.509583},
		{"83b7092544d1dd85a5e1f5835e882eb5", 770.850769, -165.583740},
		{"e3dee3b60b059681edc39f82017da400", 856.269409, -52.756557},
		{"669cef78f36b263809a70e832cce5ef2", 1020.094849, -81.646729},
		{"291bfc157bffb928b50ce495427df3c6", 1021.068604, -106.112816},
		{"19f8637f41a3ecc34805fe339e261914", 1083.866943, -233.620941},
		{"d33b7a463239c7e30970a371dcc230e6", 1053.474121, -254.766144},
		{"c72c5f6776d67f56198a441b96151bc2", 974.830627, -353.145599},
		{"a1232975d22118ca49ae63a21520b09e", 952.225403, -359.510498},
		{"baa04aa6bbcc806afb2d2057dd469267", 682.736755, -58.519676},
		{"2957cf0d70534a6d5b09d21c6596f3e2", 693.638245, -146.697952},
		{"aac906b479c0db4735e5d3ef409dfcf6", 751.839172, -91.577080},
		{"47fd21ad75525c1c69552ff6acc27e97", 693.640320, -147.665985},
		{"3a73a5bdf1e14c303cfc1cbc217c60de", 666.358826, -58.050850},
		{"290beb5e1048ab25f8d331ce440817d6", 716.867737, -78.683060},
		{"494c797ef95f51d9ebed99f2ee5ed566", 1167.123291, -126.288849},
		{"3c7c04231fd47bd32571a40ff7920329", 1153.839233, -98.953079},
		{"d29853204781e86594d8fd5d312dfcee", 1075.025024, -72.915886},
		{"c24f83467fddd979d85cf0b3913ab1cf", 1079.057617, -145.102066},
		{"e94353bf7a973e86babc587d7429ea5f", 1075.450806, -73.094231},
		{"869db83b9885dbd73f5a273e72a1fbf9", 1121.312256, -110.217270},
		{"3da00060b84be03f02fb0dd0a8da279e", 1121.107422, -403.675537},
		{"c7fd9c957842ff96d643303c0b0cebbd", 1123.158203, -360.917511},
		{"1883c7f8b4a572cdbfbaefa1f6b559dd", 1113.840820, -270.136780},
		{"b63db772b009abe0b1115f6eabf12270", 1051.380981, -350.223846},
		{"d1706bff9157a572744cf67ff7f6e0fc", 1113.903076, -270.594025},
		{"565dc2cc3f51976e58514e6cca7fc352", 1097.422119, -352.852570},
		{"ae844a312d4518018b557fa323dae1ae", 707.166809, -329.137970},
		{"1e0576984a415143d41ff78818fb3bd3", 753.166321, -364.870697},
		{"b5c65086249c35a399d9ca65e5e29ab3", 694.664185, -358.694366},
		{"68d77df6e9f8d64c7f139ace5b55ff41", 705.912842, -329.012238},
		{"620b4e1fcb6428c355ba7dff7df8c0ef", 694.949951, -358.740021},
		{"61dedba3592a0b0b18fd13795d3dda81", 888.267517, -71.411430},
		{"5a817ec291ebe603bccbede5b62b5c0f", 892.372375, -357.970734},
		{"3aabf5f28c7a0944987160caf47b7f61", 716.854126, -116.455406},
		{"297674e6252207f76bf027b50cc290ff", 685.007446, -121.128082},
		{"4b21b73371058dcb9f7e4a229257424f", 716.812317, -116.000015},
		{"50d92c60860e870fdcb6ce21bd3cfb97", 685.148560, -121.123116},
		{"a1d6d8c60ce761af5dce8f5447988022", 740.938049, -30.560961},
		{"3fd5088a898b77e492ae0c073d3c9adf", 1095.897827, -94.550034},
		{"26a0d54e7312817aa7f905ef025371bb", 1108.114868, -64.795280},
		{"4f60d74cbd2a6f6a859f850071ed7933", 1096.323975, -95.945793},
		{"7bbff6661b42428464659d4a98c981e0", 1108.308228, -64.412079},
		{"61f2dc575b27138e86cf2d80c9d49b6c", 1149.190186, -164.725143},
		{"f1ac2f036aee2c7f95e451ab4fc93658", 1116.140137, -332.643066},
		{"e3d62c79e0deb75bb1d05832b23ec4e6", 1147.830444, -329.253815},
		{"f42c475cebcd414cc891a18119bd0cdf", 1116.608765, -333.632294},
		{"33b95ac723d9395471b3f7d2dffe34bd", 1147.697998, -328.865143},
		{"b45703460fdb1ac86b943c0792f5a6b8", 1065.696411, -385.727753},
		{"7bb3df8b90a8028238ab27c9d95f6fd0", 953.140015, -38.796333},
		{"d34233d4d2993225d3353bd4c8fee7c7", 967.119141, -63.348785},
		{"c36650a935916d0879d3e7a5c9c362fc", 1011.025940, -66.690521},
		{"9c240e6c65ca708b1df84c0ca875f2f6", 757.789185, -362.197723},
		{"9f05f3b3868fee160d297b0c0953b221", 757.789185, -106.197723},
		{"db83f64cf2cf0ca9e3aee0c948180afd", 1013.789185, -362.197723},
		{"1b388ed71d479535e57c4a7df6b7d688", 1013.789185, -106.197723},
		{"65b4cefa902514b137f54bfbc05ab4f8", 554.336243, -206.535446},
		{"4eb08460af498345d8c8beb21e163fb4", 555.675537, -273.037628},
		{"205356a3d4570a7f4b36ff691ef08dd9", 1052.088257, 66.136742},
		{"857c72346c9864ac478d9416fb30be3f", 1052.234375, -608.320374},
		{"6edd07426b25b5bc8339cc0cf52850f6", 716.013062, -608.320374},
		{"b3a1cd9a9a1974eda4b888e2bf6927be", 1251.759644, -304.806305},
		{"8433359621005fa758cd2ab8d0387a12", 721.642212, -194.420044},
		{"21a3bc515d08d4a598370a7e9e519efb", 715.500427, -286.606934},
		{"d8834c47a7e3770c5bc21297ceb4dbfc", 759.274841, -319.036469},
		{"16a8717f17adb9cbe245817fa51d6da1", 799.109192, -335.240204},
		{"ca4aee04137d53a6820842fea04b5fb2", 799.109192, -79.240204},
		{"68ad7e1c5bdb2e0c205e41d65b3fa1d2", 1055.109192, -335.240204},
		{"f81da85d5f24f45bfe00d8bed5f19a1d", 646.687439, -148.227631},
		{"95de2a8304f35ec576db24ad2402a20b", 616.661438, -216.904541},
		{"8b96613272f9a977c4b239ed85372fcb", 620.778564, -207.157715},
		{"7e0ca2448c819567dfe967187da66963", 678.745667, -219.489929},
		{"915765d60521de7463a8b9179819a50d", 742.395813, -72.293091},
		{"7b67aec5828a9ee9cd4f9031cf075011", 978.678101, -71.772331},
		{"8792eea1b455e15156abb82691b58f7e", 1093.980469, -233.203079},
		{"a737f0714d32e5d7569308ce2628ba76", 978.845398, -485.426147},
		{"d74cd0cc101c8b96b686646931148ac3", 740.244690, -485.487518},
		{"8bed667b88f7838daad025cec0c2fbe5", 608.496155, -88.890144},
		{"fd63ffea373a62218f40daf2bfb8f56a", 573.404663, -121.003883},
		{"2a34c9021ee726b9e6acc8a040e3f561", 582.965515, -147.272339},
		{"d29f0ca237a883c99e1086328fc563ef", 635.713928, -132.942535},
		{"c2063d71670db5690839b67333dc7137", 569.647949, -116.963150},
		{"dd7cbcc1fac093f60e7d3585f4de3e08", 570.287598, -332.751770},
		{"47f9701ab7bb3977125c0b925acc51e3", 599.717407, -338.973724},
		{"bab999a197b9f0a96c1f3e5694994c41", 571.343506, -327.387512},
		{"826bcfc2e0632bcf3d647700bf3288ae", 592.389526, -339.030640},
		{"d9fcf5d4921f9fb17828db69e17f1f50", 490.332306, -211.492508},
		{"e91597a89f38becebe72e08ca746847b", 624.411377, -286.364319},
	},
	["The Deadmines"] = {
		{"3336ca47cde9c036c8b89effc495b63a", 482.372192, -15.067723},
		{"13b9c1d880c4c181981471ed6ac085c0", 270.737030, 43.129215},
		{"c4959ba08b22d08d5fb6734f439da670", 216.805588, -25.503174},
		{"f9895e19ba90a186c9f97ca87daec396", 270.844391, -8.249385},
		{"5361f4ad01887325857959bece3d8c90", 579.198120, -191.154999},
		{"f3d722fe643880035771b530ac85d39d", 394.289703, -112.883392},
		{"4ef6bc731a532c88c4ed535962cce522", 458.566254, 20.914680},
		{"e021c27e3714daad81225e53167f988a", 252.507080, 100.795197},
		{"430f47b91523836508278dd2e0e6ea9d", 477.953400, -227.584885},
		{"9f7f9ad87b765f9e454666dd5e5fa7eb", 474.370361, -143.723587},
		{"f795ca31e5fd49cbbed8ef2192e5a185", 353.137878, 36.787910},
		{"796a823279dd565c02ddbcb91636eca3", 528.559937, -203.686066},
		{"380b63b65a59817c91c07d309a75935d", 305.131042, 121.620590},
		{"f9ba5565d2cc56fce70bbf60c5dec228", 109.314079, -65.488937},
		{"86df045ed2e3b667a31522aebdce2252", 11.547643, -85.658669},
		{"4bf791ef9f430b322768b7c73c2e1bc0", 52.733494, -119.214317},
		{"48391476676da0249606f99cf32ec356", -37.615776, -131.877747},
		{"a828e50e7a44e10bfc529e39a081c8fc", -347.117096, -165.540054},
		{"f405cbf65dbdb81fef59e8940641bc7b", 90.526123, 171.927063},
		{"5187e56aecd5e9986b52718eb7ac2f5b", 63.624538, 248.248993},
		{"dea525f305818f23860699e63a9bedc8", 126.479248, 242.565216},
		{"6738bb214d1017d1c22aa9cdcebfba77", 67.629257, 23.007463},
		{"8cf347b92ab4745b73be49f5ac7ad153", 512.735596, -294.380188},
		{"b539ee6cb969df3b6cb8c799fbdd1b10", 303.490082, -210.640961},
		{"c3e73cdbc8e50970c38ddc39309bf91b", 392.355743, -344.586243},
		{"b50840df8f56545ec92fc3c111ee3b75", 340.712921, -262.039551},
		{"b4c502bf72a863b3a934fbbaf007d123", 401.925354, -297.859772},
		{"54f281d5f983da821be43e83b79ea9d0", 220.931580, 218.899338},
	},
	["The Stockade"] = {
		{"03d4f00485cd0b1f493bd88a9ec89939", -120.023209, -69.706444},
		{"782246bd935fd0d3991c03a60ab20963", -318.344452, 117.284950},
		{"d2b4133e90410e66415784e2a6883373", -326.185120, 71.391045},
		{"1815dd5b6f95c6f963b9a807ec8b31e3", -246.177765, 59.520699},
		{"6fbe22493487cf7d416bfaf9405898e9", -240.011810, 99.437943},
		{"cdd5dc09ecb19157dda8b3ebcd2a3be5", -348.692657, -18.828871},
		{"51e26a54611be6094ff50109fbf768d9", -231.052750, -70.119522},
		{"5e76419a9780a783f888f22d14f9a618", -231.052750, 9.831894},
		{"d4f775fd7f7bf1c5c52065faf9580656", -186.625397, 9.831894},
		{"b7411bf11a78bdb3d930127ff1f921fb", -186.625397, -70.119522},
		{"be7ef9750468eeb15ea0b266f70c1205", -245.642227, 176.843307},
		{"3dafa4d865f20ca6399be37e890887e5", -208.726761, 234.921310},
		{"13bddcd361da2a06c73c107ff60ee6ee", -298.585205, 213.758759},
		{"24a5f2fa9843468e1d73f4760b61b2d8", -187.564240, 154.727875},
		{"206ddf3da27334779d3030bb680ea3b1", -191.600647, -14.062093},
		{"4077c4e6767c801b85b9b78901f4b09e", -291.850555, -45.991348},
		{"426026727cbd94ad9d2553678188a905", -269.378387, 42.897472},
		{"28c4a0dd3711773b29eb9e8d65a36b8b", -278.418274, -172.998383},
		{"86e8fc44325184152a162e960f85fa33", -251.059738, -119.216599},
		{"fe7c41ed4d860bd76d9c0ba547886956", -330.067993, -104.649124},
		{"ab6cf7d875f7f7322064a55f1ab7d5c0", -338.731934, -145.598145},
		{"5412fd3e957575f6ed59962bfbe48d74", -341.654541, -250.699432},
		{"fc7c41d8360bc96bd7a9add91157f75b", -363.769958, -303.642395},
		{"f274fa50bf212fb70b965ece7607f936", -283.576538, -272.814850},
		{"e3ebaf6f5027d5b2870bcd42301fb08a", -394.597504, -213.783966},
		{"60ecc3bba638a6f9e3a93c43ed0ae84a", -299.158447, -189.157700},
	},
	["Uldaman"] = {
		{"ec0c4725e9f05f6f4e2db9a3e12e1da8", 403.590240, -297.407593},
		{"320c751f8af2fe2a17aadf4a1f7bd9dc", 590.897705, -275.356567},
		{"05da19b448fcb24b77165efbe89406c3", -283.670929, -616.515198},
		{"8e4d5b7eb931871a61a20676c75d8402", -3.298375, -582.904236},
		{"fef8f8ba603cbd29971c944173f490e7", 13.856285, -633.547180},
		{"84c4e3738ec088b29a4fc3b93369e601", -120.306847, -533.935120},
		{"e8bae133785fd92b2014eba62263f8fc", 515.382141, 45.282951},
		{"c963fe22b1024618dce10c0d62d0aef5", 48.883423, -567.190125},
		{"48d89c8f46c70ea9f4a97512e584a8f9", -283.649994, -620.015747},
		{"b8cd6e8f148cb3decabeff4ce6a3eb41", -124.754494, -680.383179},
		{"1ccb250983553b45ed03e9b0dc9b720a", -280.364838, -473.226288},
		{"a6822fdf1da1bb579822b075bdd34339", -149.653946, -533.172302},
		{"63edfd93cce1886d16ac33a1c8f9e90d", 237.849960, -690.247559},
		{"f4b325435169729bbf0e117bf536eade", 233.014893, -602.873718},
		{"537632138b607274ac677b44c488fa44", 197.342178, -735.184509},
		{"2511d5ba5901efcd6278d565031c93ff", 147.824203, -686.629089},
		{"5aefe4fdae85161cd812b1989d028c77", -30.429771, -766.165283},
		{"37a63d7360bd7f3e74e4e62147ae1349", 313.785034, -668.288147},
		{"a5af17bb143892b7505b0abe2a6e646f", 281.447632, -462.127167},
		{"2ec9c708c8dbb0a175228a5dfa1871e6", 75.201828, -781.249756},
		{"ffd961425aa104f1af45e45591278113", -16.721334, -723.718323},
		{"ce9c5f0bb8544b4e2d147d04e5066023", -64.523674, -602.209167},
		{"53f9b2f159a9be785ba385e5f6cbc0dc", 404.432007, -156.679825},
		{"eb639ab56acca0a1533b205fd6a3b34c", 404.432007, -374.330048},
		{"418f732a3b9706500a0db5744a0097f3", 141.300705, -596.496094},
		{"3c0e16365821e517221fe4c117275641", -352.192322, -640.332092},
		{"6a4ef5b3949427d2795edd1eaa57f0c3", 331.283936, -356.366699},
		{"d3c5a87bd701774202bd16ea48c79a41", -202.202301, -837.672241},
		{"77af292cd327ecf43f2cf97242b6952b", -368.612579, -545.392761},
		{"81218489cb91ab78980b4036ca3a63cc", -233.676895, -459.635040},
		{"9bd857310de21193c709b32e9976395e", 507.308441, -200.472977},
		{"c1c577bb370bf3eb8a6f00606493174c", -149.632965, -545.823975},
		{"da5209a393247852afadae74b1bfd691", 507.308441, -356.368683},
		{"fda310911803f6317592bbbc30cb68d7", 302.367523, -203.931641},
		{"2b4e63fba865268f5fcae273922770cf", 62.359360, -493.700134},
		{"f0babd7aef32abb3e45fdb0aefd8a9ce", -170.386902, -932.667419},
		{"30d5129bed25644f75ddf8b0ee8b0d0a", -60.876759, -854.800232},
		{"398c30542bb75e2fa79352d29de8bcfd", 250.896133, -820.367981},
		{"f44c7ff1f92c8c81652ff37bf91d6eed", -159.016907, -796.985046},
		{"5f4fea4ed3e17babd78cff47c4f694a0", 213.274704, -496.659607},
		{"870a238a901a32866e51e078f57f65d7", -333.300201, -631.580933},
		{"7e4ebcb611565fedf8042822cc2fdb38", 375.533020, -597.547729},
		{"08029e21254d020cde062bd1e0e9118f", 358.199738, 14.556746},
		{"ace673cd5fdd24e7c64f58d31e6eaa18", 366.556793, -84.530571},
		{"2b178d8a65591c816bd793ca09279748", 631.742188, -310.820435},
		{"9755db4866ffc9d35977e08a04fdf076", 428.735321, -664.914001},
		{"54724773cac5f24dda245a72edf05c92", 369.811646, -822.870117},
		{"a593c55cfd3249e8423b97feb6de9352", 457.093597, -767.183899},
		{"26a5f6446d395f8c6765438c0e7f89ad", 412.234650, -747.911316},
		{"abbd598e39cd34084c5aa8fc801b4046", 498.729523, -803.441895},
	},
	["Upper Blackrock Spire"] = {
		{"789f61c5e0a3560ede3cbf05752c3e6f", -51.506157, 473.146606},
		{"6e4e7a90bf2feb85dd285f9f55ababa1", -174.414185, 445.802917},
		{"b50f88c5c7e6488cd137259dadf970b3", -55.896702, 512.709229},
		{"61bc03e21a0cb668c325b6dc32e3effd", -96.214142, 573.227234},
		{"a733ae8fed153f69b34e06ed59206e1f", -114.428955, 497.524109},
		{"e9e46f8394c0c9ba6dc25108b0d1e43d", -88.962494, 683.413025},
		{"93a2d9405daf65feb940689e02d1fd5f", -55.858444, 679.818970},
		{"7d8bdda718265b5a6057430ca0935d4b", -218.112396, 508.502228},
		{"317846b047e0aa4d3f5f4c12257a87ea", -127.894966, 639.402771},
		{"5b7d465eb80cb0b2ed08b26702975191", -201.711548, 680.926147},
		{"d8ed3cc109faaa77789a13dab02c7884", -247.035324, 623.550354},
		{"c6bb29547d854ce6f5c15952b1edf0f1", -109.548271, 549.381775},
		{"f490cfe218f375a104aa2f6d4caf6021", -223.470215, 639.396790},
		{"931c6f35b811dd366e451566c988d744", -127.894966, 603.138550},
		{"d3542f41e19ae3d94f3d072192547138", -467.054413, 531.188660},
		{"f4de92bdc4559830c5e5c1e77daebf4c", -461.303375, 507.604340},
		{"0c1c7462d764ce66a19fcf8d8e87bd31", -352.912201, 456.619598},
		{"cdb7294ded1226330500519b6f5d0d71", -345.555573, 478.022430},
		{"6c2cf3ba1dc40348795acdad3e8f0ced", -261.533630, 504.899872},
		{"1c968761f5f6bccdf515b243532b788c", -261.406281, 610.209961},
		{"2cb8904c389ad5341392e20fe6fe516e", -225.060471, 463.272919},
		{"1f85384dc1ea2173e58f2229984f108b", -88.041603, 610.565002},
		{"74fc722af57ebcd6b16fa0239a2cbf95", -430.649780, 502.827393},
		{"3d31a44b43fca5984716f18ddafb8700", -389.504913, 720.120239},
		{"66b6b851786c4b5b4c26835c97b339df", -251.300995, 721.467224},
		{"8d14256101481c1408136505978d2da9", -217.072601, 702.381104},
		{"dd47e0b2d93a39337605c796dc982ca2", -154.645966, 719.901550},
		{"335a00a9b808aba03a28d63043c5bf60", -196.422867, 763.237793},
		{"898f40c852c56ef5f76ceae2644ccf95", -217.502930, 809.432312},
		{"034850edef9d80f52e7d0c07c21b9a52", -196.435028, 871.859009},
		{"462f35bce8181855e03885d177e9d079", -217.066742, 918.053650},
		{"dde85729b05685793aa0765f12e6c942", -251.295135, 938.644775},
		{"8fc1f216ea09874cca845dcdbd93595d", -223.470215, 602.564819},
		{"457438d5d0fdecdfc0dc5b6a00832174", -477.913940, 496.504639},
		{"9be79e522cdccf834eba2872c4e66c7b", -221.913940, 496.504639},
		{"82b9acdceb856293b1c242daaafd9718", -236.307617, 630.086548},
		{"e0f4e14027611497e6dc6ebc2748880a", -236.307617, 886.086548},
		{"fae7417f2232152259304b3d7a267782", 19.692383, 630.086548},
		{"a685c3de2b9c0c272151bf2208a99094", 19.692383, 886.086548},
		{"c7a1d4f5865145ee2aa7fe29cbb66f08", 275.692383, 630.086548},
		{"62ef876e99af5eefa65eeea3e22a7d5e", -154.640305, 938.558960},
		{"bf56e9502b4cd2741ed4f1f956385d3a", -203.969040, 983.345703},
		{"bca54ba0291cd0a96f3a57af56412c2a", 52.030960, 983.345703},
		{"d09b19ee6ac2182aacbd4b8801932a0f", 195.375397, 953.309937},
		{"0ab1088f60dbe0a80bb339f335b99417", 251.128098, 872.921204},
		{"adcdd0608efe8e53b7fc025ea0965c3e", 60.806705, 886.016418},
		{"5ac57926cd3fb936a62554753ee61320", 106.667763, 886.412537},
		{"88260e537a5e67c56a70ccab8ab46660", -11.060133, 1128.645020},
		{"95c1de6a7022b77fd45bcadb990505bf", -14.196160, 935.895935},
		{"02bfe50e633ac83a02bbe1a900664d49", 13.467258, 885.935303},
		{"58d0764e19e4745fe23cc034d6c5d061", 60.253368, 886.382812},
		{"d2943cb4470da1d0bab32624781225f7", 16.142115, 887.185913},
		{"a7ee1eeb19e078132c5e7171505d3c3e", 122.720810, 950.400635},
		{"faf7ef29c03cdc2ff835cd1e7a1f5226", 168.917465, 933.907471},
		{"83fdd7d1c619e965a3799d6d5046137f", 268.621338, 727.770081},
		{"944fcaad34951d1e8876f6d903f13994", 270.448822, 676.778381},
		{"e2b2a5730be2389b6b1c50b92703929d", 94.781311, 694.587463},
		{"bc3b295f634eb1d41934f7f9cbe4e8f5", -668.795593, 835.832458},
		{"063e28d7309a76ea3f390157b1df6247", 353.596710, 586.582153},
		{"ab00390b24b03209dab5b8b31be31730", 316.495422, 626.621216},
		{"ac9fc7066c6195cceb46a906fab3e266", 316.495422, 882.621216},
		{"b710d126aed7e9220522aee021870dbd", 17.988508, 586.214417},
		{"f916329e23e5ab27a1e6e24d72fe3da3", 41.675167, 720.753357},
		{"78a5975bee9819163bf0b906060330fd", -88.806473, 603.492554},
		{"f5aa4363573667defa92e74beea0204f", -88.863556, 494.914093},
		{"8b54e7997276fb6074340977060bb7e3", -84.896538, 711.662659},
		{"de55dee81a111b56621c667e9593aee9", -9.978590, 877.046936},
		{"987feb550a3cc0554da1dfaff511a83b", -108.445801, 878.870117},
		{"d9e6bf58bcb72b21210905eebdf4991a", 196.319733, 623.113586},
		{"57cd6e8347c115d1e56f54efc8de383b", 83.774292, 566.655884},
		{"c5a4f93de7eadfe3dae674ec2732f3ca", -298.453613, 1000.630432},
		{"2b4676e59c7735d2c53fe74cbc7e677c", -42.453613, 1000.630432},
		{"b83f1e5aaa7915a198f6bc9430dda4b5", -450.668884, 719.268738},
		{"0d3345ea38fe71f39787d96fdea1b1c2", -439.521088, 933.426758},
		{"c034d5fa3a5506abf11ef0402c363a4a", -322.988312, -251.841019},
		{"fb0406e2448a73266ededa381c1bb428", -322.988312, 4.158981},
		{"faa9d96f76ce998a7c268924bfdb03e2", -66.988312, -251.841019},
		{"af81996ba669f132479dc25ea7638ba8", -66.988312, 4.158981},
		{"fc9ff71f21b38409e256fcc8eb40d342", 189.011688, 4.158981},
		{"fc0cd7fa9cf8ee73c8e006a1aee819dd", -167.122421, 407.706085},
		{"03f1714e0f7d021a20b03089be944b3a", -333.601196, 146.224060},
		{"e3f75bd56d7e17799a2077cf121ea85a", -333.601196, 402.224060},
		{"2e8b82e308783f92b28061f3776561ee", -77.601196, 146.224060},
		{"63adb9969c34ef9e6ff8892f6d03ae91", -77.601196, 402.224060},
		{"87a842e2c8f473401d74c38a14dae1ae", 178.398804, 146.224060},
		{"da257ce85eb189559ca4ceb106bf0a7a", 360.124329, 889.059509},
	},
	["Wailing Caverns"] = {
		{"43ac71bfe8fbcecdbbc6cac42a29c6c2", -142.786057, -662.781433},
		{"23dda06d6ab6e5f4a2a2648165d26a0f", 113.213943, -662.781433},
		{"e2a2c250ac9cc5069c728f1cd3c848f2", -102.895569, -317.847534},
		{"361eca800f7eb88acc3b97c825a5facf", -102.895569, -61.847534},
		{"aaa663859d07c68ac58e8136967faed4", 153.104431, -317.847534},
		{"835ba3a000957578d8ae76c2bbd3ce13", -161.008026, -1108.722412},
		{"4c0516a385070a434092cbb77b9797d5", -161.008026, -852.722412},
		{"4dbc57bc257b10c3b27b15bfe6d377d3", 94.991974, -1108.722412},
		{"8aafe3de02b25bbe5abf712a8d697fc5", 94.991974, -852.722412},
		{"072048141d7700745f71820d3addd009", 50.668266, -200.952118},
		{"428a641f821bc7cb6c8aac2a14142a40", 50.668266, 55.047882},
		{"26991cd7841897d92014965f5fd9135f", 306.668266, -200.952118},
		{"4e14a9e0f179e66ead79bad2d49588ec", 306.668266, 55.047882},
		{"da2f307028e5e8b5d353e9e7f755d293", 562.668266, -200.952118},
		{"fccee2fe2a0bf03aaf4e6272b245bcb4", 562.668266, 55.047882},
		{"3deaa5a10a94029a1f6427d8d8df35b0", -375.007843, -610.311951},
		{"e5c37c1ba6d29a11fbb08576f7305e2d", -375.007843, -354.311951},
		{"387dc5f2ba358b1477181ef50aaa85a2", 195.497620, -313.519653},
		{"c13243bbbda89d2dff25266ebb8f5e87", 117.983734, -522.263611},
		{"7de11e29e6325904b2bf0bddaf814232", -131.282761, -474.089935},
		{"24381f64e5f050912ab8c35c61f18353", 124.717239, -474.089935},
		{"3ca7fb93b05b4aa0c3bf50c6dddfb118", 111.495514, -738.127441},
		{"621e7467c67b507054584ee9911aad5d", 373.142853, -186.282669},
		{"c754169fcb68f495b056cb22748739b4", 373.142853, 69.717331},
		{"54a31a5bb447f5822c780d2467ac856a", 373.142853, 325.717331},
		{"23432274d400da5c07579abd17daaa42", 629.142853, -186.282669},
		{"59dc2defac3d195f688735372684903b", 629.142853, 69.717331},
		{"fcc8f3f3ad9ac99aeba2f58a3b102a12", 629.142853, 325.717331},
		{"dd1210b173ed8b0cb9bc82f8793ca2aa", 373.142853, -671.337341},
		{"0e455ed2e6d048cfc371027d21feb183", 373.142853, -415.337341},
		{"89514ebfddac408da70ad43278f11435", 629.142853, -671.337341},
		{"55e93fe98ae4d0ed0570bfc6e43253e6", 629.142853, -415.337341},
		{"52c6279dca0fffe7d8aaac833e29b099", 295.171082, -674.577942},
		{"79486a44579b75c626032f485ac29a31", 295.171082, -418.577942},
		{"18e002d44ae790c78c498de9eea9b20d", 193.558044, -170.444275},
		{"9e236c69aa39aeff93c64486048a27e9", 443.118408, 277.707733},
		{"aa6d56ec7521f4b6ee680204146c7d3b", 443.118408, 533.707733},
		{"620e325ac857ebc832bb57faa6209bc1", 91.533630, 100.796501},
		{"9cb55ea823394d611efcee49c59949a3", 91.533630, 356.796501},
		{"d0b1b4653e591346d3fae501396ff3a4", 347.533630, 100.796501},
		{"2d5ab9f8c467bc7114159dda03d715e0", 347.533630, 356.796501},
		{"28615f2750b5452c6f02f687706a984d", 280.837677, 341.410461},
		{"210f69504d387e1e8636439d2274915d", -24.107286, 29.210423},
		{"e2039b7d3f9ebaca29483f855b666d8d", -167.110931, 205.266129},
		{"1c78503c02d32dd7116e654448d66106", 88.889069, 205.266129},
		{"ab36780e6bbe1fb7aab6d1584568ebab", -107.147789, 254.403000},
		{"38287a85c8835f6843a3c3acf6214cfe", -107.147789, 510.403000},
		{"25dff18f108e6ce666aabb24c880e578", 148.852211, 254.403000},
		{"1bb26b72bf715a065a1393f5a3349ef8", 172.327820, 472.769653},
		{"c8ccc04829163b3b8835b1ac955004f2", 172.327820, 728.769653},
		{"0ebfd059dfc46ffd5e0d45f5bf39af65", 428.327820, 472.769653},
		{"c71c3e3755bf8572d4aefe6042b006de", 214.635925, 410.471710},
		{"fd21aae822e23b1dd4f9d5d05118063a", 364.165405, 456.045929},
		{"294016725bbcda7dfc4010ef190e63a8", 19.047853, 353.535950},
	},
}
